@@ -4,6 +4,8 @@ function auth_failed($reason) {
 	header( "WWW-authenticate: basic realm=\"DTC Admin ".$_SERVER["HTTP_HOST"]."\"" );
 	header( "HTTP/1.0 401 Unauthorized" );
 	echo $reason;
+	// Log to SYSLOG
+	syslog(LOG_WARNING, "Failed login to DTC Admin from ".$_SERVER['REMOTE_ADDR']);
 	die();
 }
 
