@@ -1,6 +1,9 @@
 #!/usr/bin/env php
 <?php
 
+if(function_exists("date_default_timezone_set") and function_exists("date_default_timezone_get"))
+@date_default_timezone_set(@date_default_timezone_get());
+
 // 5 minute timeout for the cron.php run... if it runs longer, then we need to know about it!
 $_timelimit = 300;
 set_time_limit($_timelimit); 
@@ -138,17 +141,18 @@ function commitTriggerToRemoteInternal($a, $recipients){
 			echo "using lynx -source...";
 			$result = exec("lynx -source \"$url\"",$lines,$return_val);
 		}else{
-			$httprequest = new HTTPRequest("$url");
+			$httprequest = new dtc_HTTPRequest("$url");
 			$lines = $httprequest->DownloadToStringArray();
 		}
-		if ($recipients == 1){
-			if(strstr($lines[0],"Successfuly recieved trigger for MX!") != false){
-				$flag = true;
-			}
-
-		} else {
-			if(strstr($lines[0],"Successfuly recieved trigger!") != false){
-				$flag = true;
+		if($lines != FALSE){
+			if ($recipients == 1){
+				if(strstr($lines[0],"Successfuly recieved trigger for MX!") != false){
+					$flag = true;
+				}
+			} else {
+				if(strstr($lines[0],"Successfuly recieved trigger!") != false){
+					$flag = true;
+				}
 			}
 		}
 		$retry ++;
@@ -213,7 +217,7 @@ function updateAllDomainsStats(){
 			echo "Calculating usage of $domain_name:";
 			echo " disk...";
 			if($conf_unix_type == "bsd"){
-				$du_string = exec("du -sk $adm_path/$domain_name --exclude=access.log",$retval);
+				$du_string = exec("du -sk -I access.log $adm_path/$domain_name",$retval);
 				$du_state = explode("\t",$du_string);
 				$domain_du = $du_state[0] * 1024;
 			}else{
@@ -487,7 +491,7 @@ function cronMailSystem () {
 
                         // first stop queue processing in postfix
                         echo "Stopping postfix queue...\n";
-                        system("$PATH_POSTSUPER -h ALL 2&>1");
+                        system("$PATH_POSTSUPER -h ALL 2>&1");
 
 			echo "Reloading amavis\n";
 			if( file_exists ("/etc/init.d/amavis") ){
@@ -498,6 +502,9 @@ function cronMailSystem () {
 			// This one seems ok for slackware
 			}else if(file_exists("/etc/rc.d/rc.amavisd")){
 				system("/etc/rc.d/rc.amavisd restart");
+			// This is for FreeBSD
+			}else if(file_exists("/usr/local/etc/rc.d/amavisd")){
+				system("/usr/local/etc/rc.d/amavisd restart");
 			}
 
 			if( file_exists ("/etc/init.d/dkimproxy") ){
@@ -508,7 +515,7 @@ function cronMailSystem () {
 			}
 			
 			echo "Starting postfix queue...\n";
-                        system("$PATH_POSTSUPER -H ALL 2&>1");
+                        system("$PATH_POSTSUPER -H ALL 2>&1");
 
 			echo "Flushing the queue now, to make sure we have some mail delivery happening after amavisd restart...\n";
                         system("$PATH_POSTFIX_SCRIPT flush");
@@ -544,7 +551,7 @@ function checkNamedCronService () {
 	///////////////////////////////////////////////////////
 	// First, see if we have to regenerate deamons files //
 	///////////////////////////////////////////////////////
-	if($cronjob_table_content["gen_named"] == "yes"){
+	if($cronjob_table_content["gen_named"] == "yes" || $cronjob_table_content["gen_reverse"] == "yes" ){
 		echo "Generating Named zonefile ... this may take a while\n";
 		named_generate();
 		system("chgrp $conf_dtc_system_groupname $conf_generated_file_path/named.conf $conf_generated_file_path/named.slavezones.conf");
@@ -558,13 +565,20 @@ function checkNamedCronService () {
 	}
 	if($cronjob_table_content["reload_named"] == "yes"){
 		echo "Reloading name-server\n";
-		if(file_exists("/usr/sbin/rndc")){
-			system("/usr/sbin/rndc reload");
+		if (system("pgrep named") != ""){
+			if(file_exists("/usr/sbin/rndc")){
+				system("/usr/sbin/rndc reload");
+			}else{
+				system("killall -HUP named");
+			}
+			if($keep_dns_generate_flag == "no"){
+				markCronflagOk ("reload_named='no'");
+			}
 		}else{
-			system("killall -HUP named");
-		}
-		if($keep_dns_generate_flag == "no"){
-			markCronflagOk ("reload_named='no'");
+			echo "named NOT RUNNING\n";
+			if (system("uname -s") == "FreeBSD" ){
+				system("/etc/rc.d/named start");
+			}
 		}
 	}
 }
@@ -605,7 +619,10 @@ function checkNagiosCronService () {
 	if ( 	! $conf_nagios_host or
 		! $conf_nagios_username or  
 		! $conf_nagios_config_file_path or  
-		! $conf_nagios_restart_command ) return;
+		! $conf_nagios_restart_command ) {
+		markCronflagOk ("gen_nagios='no'");
+		return;
+	}
 
 	$cronjob_table_content = getCronFlags();
 	if($cronjob_table_content["gen_nagios"] == "yes"){
@@ -614,7 +631,9 @@ function checkNagiosCronService () {
 		$tmpfile = tempnam("/somedirthatdoesntexist","newnagiosconfig");
 		file_put_contents($tmpfile,$config);
 
-		// FIXME: To work, this code requires that 1) the nagios monitor host be in the SSH keyring for the DTC user 2) the destination file be writable for the user DTC uses to log into the nagios monitor host.  We cannot do that from here.
+		// FIXME: To work, this code requires that:
+		// 1) the nagios monitor host be in the SSH keyring for the DTC user
+		// 2) the destination file be writable for the user DTC uses to log into the nagios monitor host.  We cannot do that from here.
 
 		$returnvar = 0;
 
