@@ -35,10 +35,24 @@ function mail_account_generate_maildrop(){
 
 	if( file_exists("/etc/courier/userdb") ){
 		$path_userdb="/etc/courier/userdb";
+	}elseif( file_exists("/usr/local/etc/userdb") ){
+		$path_userdb="/usr/local/etc/userdb";
+	}elseif( file_exists("/usr/local/etc/authlib/userdb") ){
+		$path_userdb="/usr/local/etc/authlib/userdb";
+	}elseif( file_exists("/usr/local/etc/courier/userdb") ){
+		$path_userdb="/usr/local/etc/courier/userdb";
 	}else{
 		$path_userdb="/etc/authlib/userdb";
 	}
 
+	if( file_exists("/usr/bin/maildirmake") ){
+		$path_maildirmake="/usr/bin/maildirmake";
+	}elseif( file_exists("/usr/local/bin/maildirmake") ){
+		$path_maildirmake="/usr/local/bin/maildirmake";
+	}else{
+		$path_maildirmake="maildirmake";
+	}
+
 	if($panel_type == "cronjob"){
 		echo "Making maildrop userdb file\n";
 	}
@@ -79,15 +93,15 @@ function mail_account_generate_maildrop(){
 		for($i=0;$i<$n;$i++){
 			$a = mysql_fetch_array($r);
 			$boxpath = $a["path"]."/".$a["name"]."/Mailboxs/".$a["id"];
-			$userdb_file .= $a["id"]."@".$a2["name"]."\t".'home='.$boxpath.'|mail='.$boxpath."|uid=".$a["uid"].'|gid='.$a["gid"].'|quota='.$a["quota_size"]."\n";
+			$userdb_file .= $a["id"]."@".$a2["name"]."\t".'home='.$boxpath.'|mail='.$boxpath."|uid=".$a["uid"].'|gid='.$a["gid"].'|quota='.$a["quota_couriermaildrop"]."\n";
 			$quota_maildrop=$a["quota_couriermaildrop"];
 
 			$PATH = getenv('PATH');
 			putenv("PATH=/usr/lib/courier-imap/bin:$PATH");
 			system("/bin/mkdir -p $boxpath/Maildir");
-			system("maildirmake $boxpath/Maildir >/dev/null 2>&1");
-			if($quota_maildrop==0){
-				system("maildirmake -q $quota_maildrop $boxpath/Maildir");
+			system("$path_maildirmake $boxpath/Maildir >/dev/null 2>&1");
+			if($quota_maildrop!="0S,0C"){
+				system("$path_maildirmake -q $quota_maildrop $boxpath/Maildir >/dev/null 2>&1");
 			}
 			putenv("PATH=$PATH");
 			if($quota_maildrop=="0S,0C"){
@@ -95,7 +109,7 @@ function mail_account_generate_maildrop(){
 					system("rm $boxpath/Maildir/maildirsize");
 				}
 			}else{
-				if($panel_type == "cronjob"){
+				if($panel_type == "cronjob" && file_exists("$boxpath/Maildir/maildirsize")){
 					chown("$boxpath/Maildir/maildirsize",$conf_dtc_system_username);
 				}
 			}
@@ -122,7 +136,11 @@ function mail_account_generate_maildrop(){
 	fclose($fp);
 
 	// Create the binary database
-	system("/usr/sbin/makeuserdb");
+	if( file_exists("/usr/local/sbin/makeuserdb") ){
+		system("/usr/local/sbin/makeuserdb -f " . $path_userdb);
+	}else{
+		system("/usr/sbin/makeuserdb -f " . $path_userdb);
+	}
 	return;
 }
 
