@@ -15,15 +15,19 @@
  * add head to file
  *
  **/
+
+if(function_exists("date_default_timezone_set") and function_exists("date_default_timezone_get"))
+@date_default_timezone_set(@date_default_timezone_get());
+
 function get_remote_ns($a){
 	global $console;
 	global $keep_dns_generate_flag;
 	global $panel_type;
 	$retry = 0;
-	$flag = false;
+	$flag = FALSE;
 	$named_file = ""; //init $named_file var
 	$url = $a["server_addr"].'/dtc/list_domains.php?action=list_dns&login='.$a["server_login"].'&pass='.$a["server_pass"];
-	while($retry < 3 && $flag == false){
+	while($retry < 3 && $flag == FALSE){
 		$a_vers = explode(".",phpversion());
 		if($a_vers[0] <= 4 && $a_vers[1] < 3){
 			if( $panel_type == "cronjob"){
@@ -34,29 +38,34 @@ function get_remote_ns($a){
 			$result = exec("lynx -source \"$url\"",$lines,$return_val);
 		}else{
 			if( $panel_type == "cronjob"){
-				echo "\nUsing php HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"].".";
+				echo "\nUsing php dtc_HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"].".";
 			}else{
-				$console .= "<br>Using php HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"].".";
+				$console .= "<br>Using php dtc_HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"].".";
 			}
-			$httprequest = new HTTPRequest("$url");
+			$httprequest = new dtc_HTTPRequest("$url");
 			$lines = $httprequest->DownloadToStringArray();
-		}
-		$nline = sizeof($lines);
-
-		if(strstr($lines[0],"// Start of DTC generated slave zone file for backuping") &&
-			strstr($lines[$nline-1],"// End of DTC generated slave zone file for backuping")){
-			for($j=0;$j<$nline;$j++){
-				$named_file .= $lines[$j]."\n";
+			if($lines === FALSE){
+				$lines = array();
 			}
-			$flag = true;
-			if( $panel_type == "cronjob"){
-				echo "Success!\n";
-			}else{
-				$console .= "Success!<br>";
+		}
+		if($lines != FALSE){
+			$nline = sizeof($lines);
+
+			if(strstr($lines[0],"// Start of DTC generated slave zone file for backuping") &&
+				strstr($lines[$nline-1],"// End of DTC generated slave zone file for backuping")){
+				for($j=0;$j<$nline;$j++){
+					$named_file .= $lines[$j]."\n";
+				}
+				$flag = true;
+				if( $panel_type == "cronjob"){
+					echo "Success!\n";
+				}else{
+					$console .= "Success!<br>";
+				}
 			}
 		}
 		$retry ++;
-		if($flag == false){
+		if($flag == FALSE){
 			if( $panel_type == "cronjob"){
 				$console .= "Failed: delaying 3s!\n";
 			}else{
@@ -65,9 +74,9 @@ function get_remote_ns($a){
 			sleep(3);
 		}
 	}
-	if($flag == false){
+	if($flag == FALSE){
 		$keep_dns_generate_flag = "yes";
-		return false;
+		return FALSE;
 	}
 	else		return $named_file;
 }
@@ -176,6 +185,30 @@ function calculate_reverse_mask_and_cidr($ip_pool_ip,$ip_pool_netmask){
 
 	$netmask_exploded = explode(".",$ip_pool_netmask);
 	switch($ip_pool_netmask){
+	case "255.255.0.0":
+		$cird_mask = "/16";
+		break;
+	case "255.255.128.0":
+		$cird_mask = "/17";
+		break;
+	case "255.255.192.0":
+		$cird_mask = "/18";
+		break;
+	case "255.255.224.0":
+		$cird_mask = "/19";
+		break;
+	case "255.255.240.0":
+		$cird_mask = "/20";
+		break;
+	case "255.255.248.0":
+		$cird_mask = "/22";
+		break;
+	case "255.255.254.0":
+		$cird_mask = "/23";
+		break;
+	case "255.255.255.0":
+		$cird_mask = "/24";
+		break;
 	case "255.255.255.128":
 		$cird_mask = "/25";
 		break;
@@ -334,7 +367,7 @@ function rnds_generate(){
 	$tbl = array();
 
 	// Take only the zones for which a rdns_regen is set in the vps_ip table
-	$q = "SELECT DISTINCT $pro_mysql_ip_pool_table.id,$pro_mysql_ip_pool_table.ip_addr,$pro_mysql_ip_pool_table.netmask,$pro_mysql_ip_pool_table.zone_type,$pro_mysql_ip_pool_table.custom_part
+	$q = "SELECT DISTINCT $pro_mysql_ip_pool_table.id,$pro_mysql_ip_pool_table.ip_addr,$pro_mysql_ip_pool_table.netmask,$pro_mysql_ip_pool_table.zone_type,$pro_mysql_ip_pool_table.custom_part,$pro_mysql_ip_pool_table.location
 	FROM $pro_mysql_ip_pool_table,$pro_mysql_vps_ip_table
 	WHERE $pro_mysql_vps_ip_table.rdns_regen='yes'
 	AND $pro_mysql_ip_pool_table.id=$pro_mysql_vps_ip_table.ip_pool_id;";
@@ -350,7 +383,7 @@ function rnds_generate(){
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 
 	// Do same for the VPSes
-	$q = "SELECT DISTINCT $pro_mysql_ip_pool_table.id,$pro_mysql_ip_pool_table.ip_addr,$pro_mysql_ip_pool_table.netmask,$pro_mysql_ip_pool_table.zone_type,$pro_mysql_ip_pool_table.custom_part
+	$q = "SELECT DISTINCT $pro_mysql_ip_pool_table.id,$pro_mysql_ip_pool_table.ip_addr,$pro_mysql_ip_pool_table.netmask,$pro_mysql_ip_pool_table.zone_type,$pro_mysql_ip_pool_table.custom_part,$pro_mysql_ip_pool_table.location
 	FROM $pro_mysql_ip_pool_table,$pro_mysql_dedicated_ips_table
 	WHERE $pro_mysql_dedicated_ips_table.rdns_regen='yes'
 	AND $pro_mysql_ip_pool_table.id=$pro_mysql_dedicated_ips_table.ip_pool_id;";
@@ -450,6 +483,231 @@ $the_at	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_forma
 $allow_trans_str	allow-query { any; };
 };
 
+";*/
+			// FIXME: need to use the same kind of technique for the zonefile serial increment as bellow...
+			$zonefile_content = "\$TTL $conf_default_zones_ttl
+@	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_formated_webmaster_email_addr." (
+			$todays_serial; serial
+			$conf_named_soa_refresh ; refresh
+			$conf_named_soa_retry ; retry
+			$conf_named_soa_expire ; expire
+			$conf_named_soa_default_ttl ; default_ttl
+			)
+	IN	NS	".$conf_addr_primary_dns.".
+	IN	NS	".$conf_addr_secondary_dns.".
+";
+			unset($thiszoneIPs);
+			unset($thiszoneVPSIPs);
+			unset($thiszoneDEDIPs);
+			$thiszoneVPSIPs = array();
+			$thiszoneVPSIPs = array();
+			$thiszoneDEDIPs = array();
+			$q2 = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$num_vps = mysql_num_rows($r2);
+			for($j=0;$j<$num_vps;$j++){
+				$a = mysql_fetch_array($r2);
+				$thiszoneVPSIPs[] = $a;
+				$thiszoneIPs[] = $a;
+			}
+			$q2 = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$num_ded = mysql_num_rows($r2);
+			for($j=0;$j<$num_ded;$j++){
+				$a = mysql_fetch_array($r2);
+				$thiszoneVPSIPs[] = $a;
+				$thiszoneIPs[] = $a;
+			}
+			$num_ip = $num_vps + $num_ded;
+			for($j=0;$j<$num_ip;$j++){
+				$a2 = $thiszoneIPs[$j];
+				$the_ip_addr = $a2["ip_addr"];
+				$the_reverse = $a2["rdns_addr"];
+				// FIXME: works only for pool smaller than /24
+				switch($pool_netmask){
+				case "255.255.255.0":
+				case "255.255.255.128":
+				case "255.255.255.192":
+				case "255.255.255.224":
+				case "255.255.255.240":
+				case "255.255.255.248":
+				case "255.255.255.252":
+				case "255.255.255.254":
+					$the_ip_addr_exploded = explode(".",$the_ip_addr);
+					$ip_to_reverse = $the_ip_addr_exploded[3];
+					break;
+				default:
+					die("FIXME: works only for pool smaller than /24 line ".__LINE__." file ".__FILE__);
+				}
+				$zonefile_content .= "$ip_to_reverse	IN	PTR	".$the_reverse.".\n";
+			}
+			$zonefile_content .= $custom_part;
+			// Write $conf_generated_file_path/reverse_zones/$pool_ip_addr
+			$filep = fopen("$conf_generated_file_path/reverse_zones/$pool_ip_addr", "w+");
+			if( $filep == NULL){
+				die("Cannot open file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\" for writting");
+			}
+			fwrite($filep,$zonefile_content);
+			fclose($filep);
+			break;
+		case "one_zonefile_with_minus":
+			$zone_name = calculate_reverse_mask_and_cidr($pool_ip_addr,$pool_netmask);
+/*			$reverse_dns_file .= "zone \"$zone_name\" conmenos in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";*/
+			// FIXME: need to use the same kind of technique for the zonefile serial increment as bellow...
+			$zonefile_content = "\$TTL $conf_default_zones_ttl
+@	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_formated_webmaster_email_addr." (
+			$todays_serial; serial
+			$conf_named_soa_refresh ; refresh
+			$conf_named_soa_retry ; retry
+			$conf_named_soa_expire ; expire
+			$conf_named_soa_default_ttl ; default_ttl
+			)
+	IN	NS	".$conf_addr_primary_dns.".
+	IN	NS	".$conf_addr_secondary_dns.".
+";
+			unset($thiszoneIPs);
+			unset($thiszoneVPSIPs);
+			unset($thiszoneDEDIPs);
+			$thiszoneVPSIPs = array();
+			$thiszoneVPSIPs = array();
+			$thiszoneDEDIPs = array();
+			$q2 = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$num_vps = mysql_num_rows($r2);
+			for($j=0;$j<$num_vps;$j++){
+				$a = mysql_fetch_array($r2);
+				$thiszoneVPSIPs[] = $a;
+				$thiszoneIPs[] = $a;
+			}
+			$q2 = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$num_ded = mysql_num_rows($r2);
+			for($j=0;$j<$num_ded;$j++){
+				$a = mysql_fetch_array($r2);
+				$thiszoneVPSIPs[] = $a;
+				$thiszoneIPs[] = $a;
+			}
+			$num_ip = $num_vps + $num_ded;
+			for($j=0;$j<$num_ip;$j++){
+				$a2 = $thiszoneIPs[$j];
+				$the_ip_addr = $a2["ip_addr"];
+				$the_reverse = $a2["rdns_addr"];
+				// FIXME: works only for pool smaller than /24
+				switch($pool_netmask){
+				case "255.255.255.0":
+				case "255.255.255.128":
+				case "255.255.255.192":
+				case "255.255.255.224":
+				case "255.255.255.240":
+				case "255.255.255.248":
+				case "255.255.255.252":
+				case "255.255.255.254":
+					$the_ip_addr_exploded = explode(".",$the_ip_addr);
+					$ip_to_reverse = $the_ip_addr_exploded[3];
+					break;
+				default:
+					die("FIXME: works only for pool smaller than /24 line ".__LINE__." file ".__FILE__);
+				}
+				$zonefile_content .= "$ip_to_reverse	IN	PTR	".$the_reverse.".\n";
+			}
+			$zonefile_content .= $custom_part;
+			// Write $conf_generated_file_path/reverse_zones/$pool_ip_addr
+			$filep = fopen("$conf_generated_file_path/reverse_zones/$pool_ip_addr", "w+");
+			if( $filep == NULL){
+				die("Cannot open file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\" for writting");
+			}
+			fwrite($filep,$zonefile_content);
+			fclose($filep);
+			break;
+		case "one_zonefile_with_name":
+			$zone_name = $a["location"].".".calculate_reverse_end($pool_ip_addr,$pool_netmask);
+/*			$reverse_dns_file .= "zone \"$zone_name\" con nombre in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";*/
+			// FIXME: need to use the same kind of technique for the zonefile serial increment as bellow...
+			$zonefile_content = "\$TTL $conf_default_zones_ttl
+@	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_formated_webmaster_email_addr." (
+			$todays_serial; serial
+			$conf_named_soa_refresh ; refresh
+			$conf_named_soa_retry ; retry
+			$conf_named_soa_expire ; expire
+			$conf_named_soa_default_ttl ; default_ttl
+			)
+	IN	NS	".$conf_addr_primary_dns.".
+	IN	NS	".$conf_addr_secondary_dns.".
+";
+			unset($thiszoneIPs);
+			unset($thiszoneVPSIPs);
+			unset($thiszoneDEDIPs);
+			$thiszoneVPSIPs = array();
+			$thiszoneVPSIPs = array();
+			$thiszoneDEDIPs = array();
+			$q2 = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$num_vps = mysql_num_rows($r2);
+			for($j=0;$j<$num_vps;$j++){
+				$a = mysql_fetch_array($r2);
+				$thiszoneVPSIPs[] = $a;
+				$thiszoneIPs[] = $a;
+			}
+			$q2 = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$num_ded = mysql_num_rows($r2);
+			for($j=0;$j<$num_ded;$j++){
+				$a = mysql_fetch_array($r2);
+				$thiszoneVPSIPs[] = $a;
+				$thiszoneIPs[] = $a;
+			}
+			$num_ip = $num_vps + $num_ded;
+			for($j=0;$j<$num_ip;$j++){
+				$a2 = $thiszoneIPs[$j];
+				$the_ip_addr = $a2["ip_addr"];
+				$the_reverse = $a2["rdns_addr"];
+				// FIXME: works only for pool smaller than /24
+				switch($pool_netmask){
+				case "255.255.255.0":
+				case "255.255.255.128":
+				case "255.255.255.192":
+				case "255.255.255.224":
+				case "255.255.255.240":
+				case "255.255.255.248":
+				case "255.255.255.252":
+				case "255.255.255.254":
+					$the_ip_addr_exploded = explode(".",$the_ip_addr);
+					$ip_to_reverse = $the_ip_addr_exploded[3];
+					break;
+				default:
+					die("FIXME: works only for pool smaller than /24 line ".__LINE__." file ".__FILE__);
+				}
+				$zonefile_content .= "$ip_to_reverse	IN	PTR	".$the_reverse.".\n";
+			}
+			$zonefile_content .= $custom_part;
+			// Write $conf_generated_file_path/reverse_zones/$pool_ip_addr
+			$filep = fopen("$conf_generated_file_path/reverse_zones/$pool_ip_addr", "w+");
+			if( $filep == NULL){
+				die("Cannot open file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\" for writting");
+			}
+			fwrite($filep,$zonefile_content);
+			fclose($filep);
+			break;
+		case "one_zonefile_with_slash":
+			$zone_name = calculate_reverse_mask_and_cidr($pool_ip_addr,$pool_netmask);
+/*			$reverse_dns_file .= "zone \"$zone_name\" con slahs in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
 ";*/
 			// FIXME: need to use the same kind of technique for the zonefile serial increment as bellow...
 			$zonefile_content = "\$TTL $conf_default_zones_ttl
@@ -526,7 +784,7 @@ $allow_trans_str	allow-query { any; };
 	}
 
 
-	$q = "SELECT id,ip_addr,netmask,zone_type,custom_part FROM $pro_mysql_ip_pool_table;";
+	$q = "SELECT id,ip_addr,netmask,zone_type,custom_part,location FROM $pro_mysql_ip_pool_table;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	for($i=0;$i<$n;$i++){
@@ -601,6 +859,63 @@ $allow_trans_str	allow-query { any; };
 	allow-query { any; };
 };
 
+";
+			break;
+		case "one_zonefile_with_minus":
+			$zone_name = calculate_reverse_mask_and_cidr($pool_ip_addr,$pool_netmask);
+			$zone_name = preg_replace('/\//','-',$zone_name);
+			$zone_name = preg_replace('/^\./','',$zone_name);
+			$reverse_dns_file .= "zone \"$zone_name\" in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";
+			$slave_dns_file .= "zone \"$zone_name\" in {
+	type slave;
+	file \"$conf_generated_file_path/slave_reverse_zones/$pool_ip_addr\";
+	masters { $conf_ip_slavezone_dns_server; };
+	allow-query { any; };
+};
+
+";
+			break;
+		case "one_zonefile_with_name":
+			$zone_name = $a["location"].".".calculate_reverse_end($pool_ip_addr,$pool_netmask);
+			$reverse_dns_file .= "zone \"$zone_name\" in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";
+			$slave_dns_file .= "zone \"$zone_name\" in {
+	type slave;
+	file \"$conf_generated_file_path/slave_reverse_zones/$pool_ip_addr\";
+	masters { $conf_ip_slavezone_dns_server; };
+	allow-query { any; };
+};
+
+";
+			break;
+		case "one_zonefile_with_slash":
+			$zone_name = calculate_reverse_mask_and_cidr($pool_ip_addr,$pool_netmask);
+			$zone_name = preg_replace('/^\./','',$zone_name);
+			$reverse_dns_file .= "zone \"$zone_name\" in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";
+			$slave_dns_file .= "zone \"$zone_name\" in {
+	type slave;
+	file \"$conf_generated_file_path/slave_reverse_zones/$pool_ip_addr\";
+	masters { $conf_ip_slavezone_dns_server; };
+	allow-query { any; };
+};
+
 ";
 			break;
 		default:
@@ -653,8 +968,8 @@ function nodes_vps_generate(){
 	$nodes_named_conf = "// WARNING: Automatic regeneration of this file, do not edit!\n";
 	$nodes_named_conf_slave = "//WARNING: Automatic regeneration of this file, do not edit!\n";
 
-	$all_ip = "";
 	if(strlen($conf_ip_allowed_dns_transfer) > 4){
+		$all_ip = "";
 		$more_allowed = explode("|",$conf_ip_allowed_dns_transfer);
 		$v = sizeof($more_allowed);
 		for($k=0; $k<$v; $k++){
@@ -727,6 +1042,7 @@ zone \"$srv_hostname\" IN {
 		$filep = fopen("$conf_generated_file_path/nodes_zones/$srv_hostname","w+");
 		fwrite($filep,$node_zfile);
 		fclose($filep);
+		@chown("$conf_generated_file_path/nodes_zones/$srv_hostname",$conf_dtc_system_username);
 	}
 	if($n > 0){
 		$filep = fopen("$conf_generated_file_path/nodes_zones.conf","w+");
@@ -907,7 +1223,7 @@ function named_generate(){
 			$rp = mysql_query($qp)or die("Cannot query $qp line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 			$np = mysql_num_rows($rp);
 			if($np != 1){
-				echo "WARNING: error in your SQL table: target domain does not exists, will cancel domain parking!!!";
+				echo "WARNING: error in your SQL table: target domain $domain_parking for parking of $web_name does not exists, will cancel domain parking!!!<br>";
 				$domain_to_get = $web_name;
 				$domain_parking = "no-parking";
 			}else{
@@ -1080,7 +1396,11 @@ $more_mx_server
 
 				// if we have a srv_record here (ie a port, then we don't write the normal subdomain entry, just the SRV record
 			 	if (isset($subdomain["srv_record"]) && $subdomain["srv_record"] != ""){
-					$this_site_file .= "$web_subname	$sub_ttl	SRV	0	10	".$subdomain["srv_record"]."	".$subdomain["ip"]."\n";
+					$this_site_file .= "_$web_subname._".$subdomain["srv_record_protocol"]."	$sub_ttl	IN	SRV	0	10	".$subdomain["srv_record"]."	".$subdomain["ip"]."\n";
+				}elseif(isset($subdomain["nameserver_for"]) && $subdomain["nameserver_for"] != ""){
+					// add support for creating NS records
+					$nameserver_for = $subdomain["nameserver_for"];
+					$this_site_file .= "$web_subname	IN	NS	$nameserver_for.\n";
 				} else {	
 					// write TTL values into subdomain
 					if ($conf_use_cname_for_subdomains == "yes"){
@@ -1092,14 +1412,19 @@ $more_mx_server
 						$this_site_file .= "$web_subname	$sub_ttl	IN	$the_ip_writed\n";
 					}
 				}
+				if ($subdomain["ipv4_round_robin"] != ""){
+					$rr_expl = explode("|",$subdomain["ipv4_round_robin"]);
+					$nbr_rr = sizeof($rr_expl);
+					for($rr_i=0;$rr_i<$nbr_rr;$rr_i++){
+						$this_site_file .= "$web_subname\t$sub_ttl\tIN\tA\t".$rr_expl[$rr_i]."\n";
+					}
+				}
+				if ($subdomain["ip6"] != "" && $subdomain["ip6"] != "default") {
+                                        $this_site_file .= "$web_subname        $sub_ttl        IN      AAAA    ".$subdomain["ip6"]."\n";
+                                }
 				if($subdomain["associated_txt_record"] != "" && (isIP($subdomain["ip"]) || $subdomain["ip"] == "default")){
 					$this_site_file .= "$web_subname	IN	TXT	\"".$subdomain["associated_txt_record"]."\"\n";
 				}
-				if(isset($subdomain["nameserver_for"]) && $subdomain["nameserver_for"] != ""){
-					// add support for creating NS records
-					$nameserver_for = $subdomain["nameserver_for"];
-					$this_site_file .= "$nameserver_for	IN	NS	$web_subname.$web_name.\n";
-				}
 			}
 			if( $conf_autogen_default_subdomains == "yes" ){
 				// For each subdomains not yet defined, but in autogen, add an entry
@@ -1153,6 +1478,9 @@ $more_mx_server
 
 	$named_file .= get_remote_ns_domains();
 
+	// include the reverse zone file
+	$named_file .= "include \"$conf_generated_file_path/named.conf.reverse\";\n";
+
 	// include the slave zone file
 //	$named_file .= "include \"$conf_generated_file_path/$conf_named_slavefile_path\";\n";
 
