@@ -41,6 +41,7 @@ function mail_account_generate_postfix(){
 
 	global $conf_generated_file_path;
 	global $conf_addr_mail_server;
+	global $conf_dtcadmin_path;
 
 	global $conf_unix_type;
 
@@ -52,6 +53,7 @@ function mail_account_generate_postfix(){
 	global $conf_use_mail_alias_group;
 
 	global $conf_support_ticket_email;
+	global $conf_support_ticket_fw_email;
 	global $conf_support_ticket_domain;
 	global $conf_main_domain;
 
@@ -92,11 +94,11 @@ function mail_account_generate_postfix(){
 
 	$data = ""; // init var for use later on
 
-	#CL: Don create sasldb password when using cyrus. 
-	if($conf_use_cyrus != "yes")
-	{
-		genSasl2PasswdDBStart();
-	}
+//	#CL: Don create sasldb password when using cyrus. 
+//	if($conf_use_cyrus != "yes")
+//	{
+//		genSasl2PasswdDBStart();
+//	}
 	// go through each admin login and find the domains associated 
 	$query = "SELECT * FROM $pro_mysql_admin_table ORDER BY adm_login;";
 	$result = mysql_query ($query)or die("Cannot execute query : \"$query\"");
@@ -188,7 +190,7 @@ function mail_account_generate_postfix(){
 						$domain_parent = $alias["domain_parent"];
 						$ainc = $alias["autoinc"];
 						$mailbox_cleanup1 = str_replace("\r\n", "\n", $alias["delivery_group"]);
-						$mailbox_cleanup2 = split("\n", $mailbox_cleanup1);
+						$mailbox_cleanup2 = preg_split("/\n/", $mailbox_cleanup1);
 						$deliver_mailbox = '';
 						if ( $k==0 ) $domains_postmasters_file.= "# Mail Alias Groups for : ".$domain_parent."\n";
 						for($x=0;$x<count($mailbox_cleanup2);$x++)
@@ -253,11 +255,11 @@ function mail_account_generate_postfix(){
 					// Previously: only generate sasl logins for local accounts
 					// In fact, there is no reason to do so. We might want to create a mail account ONLY for sending
 					// some mail, and not receiving.
-					#CL: Not needed for cyrus
-					if($conf_use_cyrus != "yes")
-					{
-						genSasl2PasswdDBEntry($domain_full_name,$id,$passwdtemp,$conf_addr_mail_server);
-					}
+//					#CL: Not needed for cyrus
+//					if($conf_use_cyrus != "yes")
+//					{
+//						genSasl2PasswdDBEntry($domain_full_name,$id,$passwdtemp,$conf_addr_mail_server);
+//					}
 					
 					// setup a postfix mapping for local delivery or vacation flags
 					if ($localdeliver == "yes" || $localdeliver == "true" || $vacation_flag == "yes"){
@@ -337,7 +339,7 @@ function mail_account_generate_postfix(){
 			
 					$list_path = "$admin_path/$list_domain/lists";
 					$name = $list_domain . "_" . $list_name;
-					if (!ereg("\@", $list_owner)){
+					if (!preg_match("/\@/", $list_owner)){
 						$owner = $list_owner . "@" . $list_domain;
                                         } else {
 						$owner = $list_owner;
@@ -431,9 +433,13 @@ function mail_account_generate_postfix(){
 	}
 
 	// Add the support@ email
-	$aliases_file .= "dtc_support_ticket_messages: \"|/usr/share/dtc/admin/support-receive.php\"\n";
+	$aliases_file .= "dtc_support_ticket_messages: \"| ".$conf_dtcadmin_path."/support-receive.php\"\n";
 	$domains_postmasters_file .= $conf_support_ticket_email."@".$conf_support_ticket_domain." dtc_support_ticket_messages\n";
 
+	// Add the supportforward@ email
+	$aliases_file .= "dtc_support_forward_ticket_messages: \"| reformime -e -s 1.2 | ".$conf_dtcadmin_path."/support-receive.php\"\n";
+	$domains_postmasters_file .= $conf_support_ticket_fw_email."@".$conf_support_ticket_domain." dtc_support_ticket_messages\n";
+
 	//write out our config files
 	$fp = fopen ( "$conf_postfix_virtual_mailbox_domains_path", "w");
 	fwrite($fp, $domains_file);
@@ -483,7 +489,7 @@ function mail_account_generate_postfix(){
 	system("$POSTMAP_BIN $conf_postfix_vmailbox_path");
 	system("$POSTMAP_BIN $conf_postfix_virtual_uid_mapping_path");
 	system("$POSTMAP_BIN $conf_postfix_relay_recipients_path");
-	genSaslFinishConfigAndRights();
+//	genSaslFinishConfigAndRights();
 	system("chown  ".$conf_dtc_system_username.":postfix ".$conf_generated_file_path."/postfix_*");
 	//in case our relay_domains file hasn't been created correctly, we should touch it
 	system("touch $conf_postfix_relay_domains_path");
