@@ -109,7 +109,7 @@ function test_valid_local_ip($address){
 
 	if (!($ret = socket_bind($sock, $address, $port))) {
 		$error = socket_last_error();
-		if ($error == 98){
+		if ($error == 98 || $error == 48){
 			//echo "Address already in use!\n";
 			$console .= " already in use -> success\n";
 			return true;
@@ -201,7 +201,8 @@ function pro_vhost_generate(){
 
 	global $conf_autogen_webmail_alias;
 	global $conf_autogen_webmail_type;
-
+	
+	global $conf_use_shared_ssl;
 	$vhost_file = "";
 
 	$logrotate_file = "# Do not edit this file, it's generated
@@ -221,6 +222,12 @@ $vhost_file .= "# WARNING ! This file is automatically edited by the dtc cron
 # in your httpd.conf or apache.conf See your distribution manual to know where
 # to find this file (somewhere in /etc/httpd or /etc/apache2 or even in
 # /usr/local/etc/apache/httpd.conf ...).
+
+# Disabling TRACE (for security reasons)
+RewriteEngine on
+RewriteCond %{REQUEST_METHOD} ^(DELETE|TRACE|TRACK)
+RewriteRule .* - [F]
+
 ";
 
 	$vhost_file_listen = "";
@@ -276,7 +283,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 		$nbr_addrs = sizeof($all_site_addrs);
 		for($i=0;$i<$nbr_addrs;$i++){
 			// first write all config'ed IPs with the Listen
-			if (test_valid_local_ip($all_site_addrs[$i]) && !ereg("Listen ".$all_site_addrs[$i].":80", $vhost_file_listen))
+			if (test_valid_local_ip($all_site_addrs[$i]) && !preg_match("/Listen ".$all_site_addrs[$i].":80/", $vhost_file_listen))
 			{
 				$vhost_file_listen .= "Listen ".$all_site_addrs[$i].":80\n";
 			} else {
@@ -287,6 +294,9 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 			$num_rows2 = mysql_num_rows($result2);
 			if($num_rows2 > 0){
 				$vhost_file .= "NameVirtualHost ".$all_site_addrs[$i].":80\n";
+				if ($conf_use_shared_ssl == "yes") {
+					$vhost_file .= "NameVirtualHost ".$all_site_addrs[$i].":443\n";
+				}
 				if ($enable404feature == true){
 					$vhost_file .= "<VirtualHost ".$all_site_addrs[$i].":80>
 	ServerName $conf_404_subdomain.$conf_main_domain
@@ -310,7 +320,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 		$ip_for_404=$conf_main_site_ip;
 		if($conf_use_nated_vhost=="yes"){
 			$ip_for_404 = $conf_nated_vhost_ip;
-			if (test_valid_local_ip($conf_nated_vhost_ip) && !ereg("Listen ".$conf_nated_vhost_ip.":80", $vhost_file_listen))
+			if (test_valid_local_ip($conf_nated_vhost_ip) && !preg_match("/Listen ".$conf_nated_vhost_ip.":80/", $vhost_file_listen))
 			{
 				$vhost_file_listen .= "Listen ".$conf_nated_vhost_ip.":80\n";
 			} else {
@@ -318,13 +328,16 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 			}
 			$vhost_file .= "NameVirtualHost ".$conf_nated_vhost_ip.":80\n";
 		}else{
-			if (test_valid_local_ip($conf_main_site_ip) && !ereg("Listen ".$conf_main_site_ip.":80", $vhost_file_listen))
+			if (test_valid_local_ip($conf_main_site_ip) && !preg_match("/Listen ".$conf_main_site_ip.":80/", $vhost_file_listen))
 			{
 				$vhost_file_listen .= "Listen ".$conf_main_site_ip.":80\n";
 			} else {
 				$vhost_file_listen .= "#Listen ".$conf_main_site_ip.":80\n";
 			}
 			$vhost_file .= "NameVirtualHost ".$conf_main_site_ip.":80\n";
+			if ($conf_use_shared_ssl == "yes") {
+				$vhost_file .= "NameVirtualHost ".$conf_main_site_ip.":443\n";
+			}
 		}
 		if ($enable404feature == true){
 			$vhost_file .= "<VirtualHost ".$ip_for_404.":80>
@@ -338,8 +351,28 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
         LogSQLScoreTable $conf_mysql_db.http_accounting
         DirectoryIndex $conf_apache_directoryindex
 </VirtualHost>\n";
-			$logrotate_file .= "$path_404/logs/error.log ";
+
+		if ($conf_use_shared_ssl == "yes") {
+			
+		    $vhost_file .= "<VirtualHost ".$conf_main_site_ip.":443>
+        ServerName $conf_404_subdomain.$conf_main_domain
+        DocumentRoot $path_404/html
+        ScriptAlias /cgi-bin $path_404/cgi-bin
+        ErrorLog $path_404/logs/error.log
+        LogSQLTransferLogTable ".str_replace("-","A",str_replace(".","_",$conf_main_domain)).'$'.$conf_404_subdomain.'$'."xfer
+        LogSQLScoreDomain $conf_main_domain
+        LogSQLScoreSubdomain $conf_404_subdomain
+        LogSQLScoreTable $conf_mysql_db.http_accounting
+        DirectoryIndex $conf_apache_directoryindex
+	SSLEngine on
+	SSLCertificateFile ".$conf_generated_file_path."/ssl/new.cert.cert
+	SSLCertificateKeyFile ".$conf_generated_file_path."/ssl/new.cert.key
+</VirtualHost>\n\n";	
 		}
+
+    		$logrotate_file .= "$path_404/logs/error.log ";
+	    }
+	
 	}
 
 	$vhost_file .= "<Directory $conf_dtcadmin_path>
@@ -422,12 +455,12 @@ AND $pro_mysql_admin_table.id_client != '0'";
 		} 
 		// need to check if we have a NameVirtualHost entry for this backup IP, to support multiple backup sites on one IP
 		if (isset($backup_ip_addr)){
-			if (test_valid_local_ip($backup_ip_addr) && !ereg("Listen ".$backup_ip_addr.":80", $vhost_file_listen)){
+			if (test_valid_local_ip($backup_ip_addr) && !preg_match("/Listen ".$backup_ip_addr.":80/", $vhost_file_listen)){
 				$vhost_file_listen .= "Listen ".$backup_ip_addr.":80\n";
 			} else {
 				$vhost_file_listen .= "#Listen ".$backup_ip_addr.":80\n";
 			}
-			if (!ereg("NameVirtualHost $backup_ip_addr", $vhost_file)){
+			if (!preg_match("/NameVirtualHost $backup_ip_addr/", $vhost_file)){
 				$vhost_file .= "NameVirtualHost ".$backup_ip_addr.":80\n";
 			}
 		}
@@ -542,7 +575,7 @@ AND $pro_mysql_admin_table.id_client != '0'";
 				$log_tablename = str_replace("-","A",str_replace(".","_",$web_name)).'$'.str_replace("-","A",str_replace(".","_",$web_subname));
 				if($conf_use_ssl == "yes" && $k == 0){
 					# add the directive for SSL here
-					if (test_valid_local_ip($ip_to_write) && !ereg("Listen ".$ip_to_write.":".$conf_administrative_ssl_port, $vhost_file_listen))
+					if (test_valid_local_ip($ip_to_write) && !preg_match("/Listen ".$ip_to_write.":".$conf_administrative_ssl_port."/", $vhost_file_listen))
 					{
 						$vhost_file_listen .= "Listen ".$ip_to_write.":".$conf_administrative_ssl_port."\n";
 					} else {
@@ -617,15 +650,20 @@ AND $pro_mysql_admin_table.id_client != '0'";
 				vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/html");
 				vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/logs");
 				vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/cgi-bin");
-				$vhost_file .= "	Alias /phpmyadmin ".$conf_tools_prefix."/phpmyadmin
-	Alias /dtc $conf_dtcclient_path
+				if ( $conf_unix_type == "bsd" ) {
+					$vhost_file .= "	Alias /phpmyadmin ".$conf_tools_prefix."/phpMyAdmin\n";
+				}else{
+					$vhost_file .= "	Alias /phpmyadmin ".$conf_tools_prefix."/phpmyadmin\n";
+				}
+				$vhost_file .= "	Alias /dtc $conf_dtcclient_path
 	Alias /dtcdoc $conf_dtcdoc_path/html/en
 	Alias /dtcemail $conf_dtcemail_path
-	Alias /dtcadmin $conf_dtcadmin_path
+	Alias /dtcadmin $conf_dtcadmin_path/
 	Alias /stats $web_path/$web_name/subdomains/$web_subname/logs
 	Alias /awstats-icon $conf_tools_prefix/awstats/icon
 	Alias /squirrelmail ".$conf_tools_prefix."/squirrelmail
 	Alias /roundcube /var/lib/roundcube
+	Alias /extplorer /usr/share/extplorer
 	php_admin_value sendmail_from webmaster@$web_name
 	DocumentRoot $web_path/$web_name/subdomains/$web_subname/html
 	<Directory $web_path/$web_name/subdomains/$web_subname/html>
@@ -644,7 +682,14 @@ AND $pro_mysql_admin_table.id_client != '0'";
 	</IfModule>
 	<IfModule mod_security2.c>
 		SecRuleEngine Off
-        </IfModule>
+	</IfModule>";
+	if($conf_force_use_https == "yes" && $conf_use_ssl == "yes"){
+		$vhost_file .= "
+	RewriteEngine On
+	RewriteCond %{HTTPS} off
+	RewriteRule (.*) https://$conf_administrative_site$1 [R,L]";
+	}
+$vhost_file .= "
 </VirtualHost>
 
 ";
@@ -722,6 +767,31 @@ AND $pro_mysql_admin_table.id_client != '0'";
 					if($subdomain["register_globals"] == "yes"){
 						$vhost_more_conf .= "	php_admin_value register_globals 1\n";
 					}
+					if($subdomain["php_memory_limit"] != ""){
+						$vhost_more_conf .= "	php_admin_value memory_limit ".$subdomain["php_memory_limit"]."M\n";
+					}
+					if($subdomain["php_max_execution_time"] != ""){
+						$vhost_more_conf .= "	php_admin_value max_execution_time ".$subdomain["php_max_execution_time"]."\n";
+					}
+					if($subdomain["php_session_auto_start"] == "yes"){
+						$vhost_more_conf .= "	php_admin_flag session_autostart ".$subdomain["php_session_auto_start"]."\n";
+					}
+					if($subdomain["php_allow_url_fopen"] == "yes"){
+						$vhost_more_conf .= "	php_admin_flag allow_url_fopen on\n";
+					}
+					if($subdomain["php_post_max_size"] != ""){
+						$vhost_more_conf .= "	php_admin_value post_max_size ".$subdomain["php_post_max_size"]."M\n";
+					}
+					if($subdomain["php_upload_max_filesize"] != ""){
+						$vhost_more_conf .= "	php_admin_value upload_max_filesize ".$subdomain["php_upload_max_filesize"]."M\n";
+					}
+					
+					if($subdomain["use_shared_ssl"] == "yes" && $conf_use_shared_ssl == "yes"){
+						$iteration_table[]="shared_ssl";
+					}
+					if (preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $subdomain["redirect_url"])) {
+						$vhost_more_conf .= "Redirect / ".$subdomain["redirect_url"]."\n";
+					}
 					if($web_subname == "$web_default_subdomain"){
 						if ($domain_parking == "no-parking"){
 							// no domain parking
@@ -788,6 +858,12 @@ AND $pro_mysql_admin_table.id_client != '0'";
                 		                                $vhost_file .= "        SSLCertificateChainFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca\n";
                                 		        }
 							break;
+						case "shared_ssl":
+							$vhost_file .= "<VirtualHost ".$ip_to_write.":443>\n";
+							$vhost_file .= "	SSLEngine on\n";
+							$vhost_file .= "	SSLCertificateFile ".$conf_generated_file_path."/ssl/new.cert.cert\n";
+							$vhost_file .= "	SSLCertificateKeyFile ".$conf_generated_file_path."/ssl/new.cert.key\n";
+							break;
 						}
 						$vhost_file .= "	ServerName $web_subname.$web_name
 	Alias /stats $web_path/$web_name/subdomains/$web_subname/logs
