@@ -1,5 +1,38 @@
 <?php
 
+function deleteTicketThread($delete_me){
+	global $pro_mysql_tik_queries_table;
+
+	$a = array();
+	$a["in_reply_of_id"] = $delete_me;
+	while($a["in_reply_of_id"] != 0){
+		$q = "SELECT * FROM $pro_mysql_tik_queries_table WHERE id='".$a["in_reply_of_id"]."';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			die("Cannot find ticket ".$a["in_reply_of_id"]." when willing to search head thread line ".__LINE__." file ".__FILE__);
+		}
+		$a = mysql_fetch_array($r);
+	}
+	$head = $a["id"];
+	$next = $a["reply_id"];
+	$q = "DELETE FROM $pro_mysql_tik_queries_table WHERE id='$head';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	while($next != 0){
+		$q = "SELECT * FROM $pro_mysql_tik_queries_table WHERE id='$next';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			die("Cannot find ticket ".$a["in_reply_of_id"]." when willing to delete thread line ".__LINE__." file ".__FILE__);
+		}
+		$a = mysql_fetch_array($r);
+		$head = $next;
+		$next = $a["reply_id"];
+		$q = "DELETE FROM $pro_mysql_tik_queries_table WHERE id='$head';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	}
+}
+
 function calculateAge($date,$time){
 	$exp_date = explode("-",$date);
 	$exp_time = explode(":",$time);
@@ -38,6 +71,8 @@ function mailUserTicketReply($adm_email,$hash,$subject,$body,$closed="no",$adm_l
 
 	if($conf_support_ticket_domain == "default"){
 		$support_domain = $conf_main_domain;
+	} else {
+		$support_domain = $conf_support_ticket_domain;
 	}
 
 	$support_email = $conf_support_ticket_email.$conf_recipient_delimiter.$hash."@".$support_domain;
@@ -196,7 +231,7 @@ function drawNewAdminForm(){
 		}else{
 			$out .= "<font color=\"#FF0000\">"._("No")."</font><br>";
 		}
-		$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\" method=\"post\">
+		$out .= "<form action=\"?\" method=\"post\">
 		<input type=\"hidden\" name=\"subaction\" value=\"ticket_reply\">
 		<textarea cols=\"100\" rows=\"10\" wrap=\"physical\" name=\"ticketbody\"></textarea><br>
 		<input type=\"hidden\" name=\"tik_id\" value=\"".$_REQUEST["tik_id"]."\">
@@ -216,6 +251,11 @@ function drawNewAdminForm(){
  <div class=\"input_btn_left\"></div>
  <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"close\" value=\"". _("Close without reply") ."\"></div>
  <div class=\"input_btn_right\"></div>
+</div>
+		<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
+ <div class=\"input_btn_left\"></div>
+ <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"delete_thread\" value=\"". _("Delete thread silently") ."\"></div>
+ <div class=\"input_btn_right\"></div>
 </div>
 		</form>";
 		return $out;
@@ -240,19 +280,26 @@ function drawNewAdminForm(){
 			$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 			$n = mysql_num_rows($r);
 			if($n != 1){
-				return "Admin not found!";
+				return "Admin $adm_login not found line ".__LINE__." file ".__FILE__;
 			}
 			$admin = mysql_fetch_array($r);
+			if($admin["id_client"] == "0"){
+				return _("The virtual administrator for which you are trying to manage a support ticket has no client file. Go in the Customer management screen and create a client file for this administrator.");
+			}
 			$q = "SELECT * FROM $pro_mysql_client_table WHERE id='".$admin["id_client"]."';";
 			$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 			$n = mysql_num_rows($r);
 			if($n != 1){
-				return "Admin not found!";
+				return "Client id for admin $adm_login not found line ".__LINE__." file ".__FILE__;
 			}
 			$client = mysql_fetch_array($r);
 		}else{
 			$adm_login = "";
 		}
+		if( isset($_REQUEST["delete_thread"]) ){
+			deleteTicketThread($_REQUEST["tik_id"]);
+			$closed = "no";
+		}
 		if(isset($_REQUEST["answer"]) || isset($_REQUEST["answer_close"])){
 			$qps = "SELECT * FROM $pro_mysql_tik_admins_table WHERE pseudo='".$_SERVER["PHP_AUTH_USER"]."';";
 			$rps = mysql_query($qps)or die("Cannot query $qps line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -321,8 +368,8 @@ dtcFromOkDraw()."
 <tr><td>". _("Name") ."</td><td>". _("Login") ."</td><td>". _("Domain name / VPS server hostname") ."</td><td>". _("Product") ."</td><td>". _("Date") . "</td><td>". _("Bank validated") ."</td>$maxmindsays_th<td>". _("Action") ."</td></tr>";
 		for($i=0;$i<$n;$i++){
 			$a = mysql_fetch_array($r);
-			$waiting_new_users .= "<tr><td style=\"white-space:nowrap\"><u>".$a["comp_name"].":</u><br>";
-			$waiting_new_users .= $a["family_name"].", ".$a["first_name"]."</td>";
+			$waiting_new_users .= "<tr><td style=\"white-space:nowrap\"><u>".htmlspecialchars($a["comp_name"]).":</u><br>";
+			$waiting_new_users .= htmlspecialchars($a["family_name"]).", ".htmlspecialchars($a["first_name"])."</td>";
 			$waiting_new_users .= "<td>".$a["reqadm_login"]."</td>";
 			$prod_id = $a["product_id"];
 			$q2 = "SELECT * FROM $pro_mysql_product_table WHERE id='$prod_id';";
@@ -362,9 +409,9 @@ dtcFromOkDraw()."
 				$waiting_new_users .= "<td><pre style='width: 200px; height: 100px; overflow: scroll;'>".htmlspecialchars(
 					print_r(unserialize($a["maxmind_output"]),true))."</pre></td>";
 			}
-			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". _("View details") ."</a><br/>
-			<a href=\"".$_SERVER["PHP_SELF"]."?action=valid_waiting_user&reqadm_id=".$a["id"]."\">". _("Add") ."</a><br/>
-			<a href=\"".$_SERVER["PHP_SELF"]."?action=delete_waiting_user&reqadm_id=".$a["id"]."\">". _("Delete") ."</a></td>";
+			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". _("Edit") ."</a><br/>
+			<a href=\"?action=valid_waiting_user&reqadm_id=".$a["id"]."\">". _("Add") ."</a><br/>
+			<a href=\"?action=delete_waiting_user&reqadm_id=".$a["id"]."\">". _("Delete") ."</a></td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -383,8 +430,8 @@ dtcFromOkDraw()."
 			$a = mysql_fetch_array($r);
 			$waiting_new_users .= "<td>".$a["adm_login"]."</td>";
 			$waiting_new_users .= "<td>".$a["domain_name"]."</td>";
-			$waiting_new_users .= "<td><a href=\"".$_SERVER["PHP_SELF"]."?action=valid_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Add") ."</a>
-- <a href=\"".$_SERVER["PHP_SELF"]."?action=delete_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Delete") ."</a></td></tr>";
+			$waiting_new_users .= "<td><a href=\"?action=valid_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Add") ."</a>
+- <a href=\"?action=delete_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Delete") ."</a></td></tr>";
 		}
 		$waiting_new_users .= "</table>";
 	}
@@ -448,6 +495,12 @@ dtcFromOkDraw()."
 			case "ssl":
 				$heb_type = _("Shared");
 				break;
+			case "shared-upgrade":
+				$heb_type = _("Shared Upgrade");
+				break;
+			case "add-money":
+				$heb_type = _("Add Money to Account");
+				break;
 			case "ssl":
 				$heb_type = _("SSL Token purchase");
 				break;
@@ -470,7 +523,7 @@ dtcFromOkDraw()."
 				break;
 			}
 			$waiting_new_users .= "<td>$heb_type</td>";
-			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a href=\"".$_SERVER["PHP_SELF"]."?action=validate_renewal&id=".$a["id"]."\">Validate</a> <a href=\"".$_SERVER["PHP_SELF"]."?action=delete_renewal&id=".$a["id"]."\">Del</a></td>";
+			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a href=\"?action=validate_renewal&id=".$a["id"]."\">". _("Validate") ."</a> <a href=\"?action=delete_renewal&id=".$a["id"]."\">". _("Del") ."</a></td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -505,7 +558,7 @@ dtcFromOkDraw()."
 				$cat = $a2["catname"];
 			}
 			$age = calculateAge($a["date"],$a["time"]);
-			$waiting_new_users .= "<td style=\"white-space:nowrap;\">$age</td><td>$cat</td><td style=\"white-space:nowrap;\"><a href=\"".$_SERVER["PHP_SELF"]."?subaction=resolv_ticket&tik_id=".$a["id"]."\">".htmlspecialchars(stripslashes($a["subject"]))."</a></td>";
+			$waiting_new_users .= "<td style=\"white-space:nowrap;\">$age</td><td>$cat</td><td style=\"white-space:nowrap;\"><a href=\"?subaction=resolv_ticket&tik_id=".$a["id"]."\">".htmlspecialchars(stripslashes($a["subject"]))."</a></td>";
 			$next_reply_id = $a["reply_id"];
 			$last_reply_text = "<font color=\"green\">". _("Admin"). "</font>";
 			$last_message_date = $a["date"];
@@ -531,7 +584,7 @@ dtcFromOkDraw()."
 				}
 				$next_reply_id = $a3["reply_id"];
 				if($loop_num >= 49){
-					echo "Warning: loop_num exeeded 50, not displaying last ticket reply from line".__LINE__." file ".__FILE__;
+					echo "Warning: loop_num exeeded 50while reading ticket for $who and ID $next_reply_id, not displaying last ticket while reading ticket for $who: not displaying last ticket reply from line".__LINE__." file ".__FILE__;
 				}
 			}
 			if($last_guy_replied == "user"){
