@@ -110,7 +110,15 @@ function configEditorTemplate ($dsc,$conftype="config"){
 			if($i != 0){
 				$vals .= ", ";
 			}
-			$vals .= $keys[$i]."='".$_REQUEST[ $keys[$i] ]."'";
+			if( !isset($_REQUEST[ $keys[$i] ] ) ){
+				$_REQUEST[ $keys[$i] ] = "";
+			}
+			if( !is_array( $_REQUEST[ $keys[$i] ] ) ){
+				$my_value = $_REQUEST[ $keys[$i] ];
+			}else{
+				$my_value = join( ",",$_REQUEST[ $keys[$i] ] );
+			}
+			$vals .= $keys[$i]."='".$my_value."'";
 		}
 		$q = "UPDATE $sql_table SET $vals WHERE 1;";
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." mysql said: ".mysql_error());
@@ -138,7 +146,7 @@ function configEditorTemplate ($dsc,$conftype="config"){
 	}
 
 	$out .= dtcFormTableAttrs();
-	$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$out .= "<form action=\"?\">
 <input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."\">$fw";
 	for($i=0;$i<$n;$i++){
 		$fld = $prefix.$keys[$i];
@@ -184,6 +192,30 @@ function configEditorTemplate ($dsc,$conftype="config"){
 			}
 			$control = "<select class=\"$input_class\" name=\"".$keys[$i]."\">".$control."</select>";
 			break;
+		case "checkboxcomma":
+			$nb_choices = sizeof($dsc["cols"][ $keys[$i] ]["values"]);
+			$control = "";
+			$arr_values = preg_split("/,/",$$fld);
+			$cntchk = 0;
+			for($j=0;$j<$nb_choices;$j++){
+				if (in_array($dsc["cols"][ $keys[$i] ]["values"][$j], $arr_values)){
+					$selected = " checked ";
+				}else{
+					$selected = "";
+				}
+				if( isset($dsc["cols"][ $keys[$i] ]["display_replace"][$j]) ){
+					$text = $dsc["cols"][ $keys[$i] ]["display_replace"][$j];
+				}else{
+					$text = $dsc["cols"][ $keys[$i] ]["values"][$j];
+				}
+				$control .= "<input type=\"checkbox\" name=\"".$keys[$i]."[]\" value=\"".$dsc["cols"][ $keys[$i] ]["values"][$j]."\" $selected> $text\n";
+				if ($cntchk > 3){
+					$control .= "<br />";
+					$cntchk = 0;
+				}
+				$cntchk++;
+			}
+			break;
 		case "textarea":
 			if( isset($dsc["cols"][ $keys[$i] ]["cols"]) ){
 				$cols = " cols=\"".$dsc["cols"][ $keys[$i] ]["cols"]."\" ";
@@ -228,19 +260,35 @@ while others are made of a unique value. The message templates
 are stored in /etc/dtc, and if not present in: ").$conf_dtcadmin_path."/reminders_msg/",
 		"cols" => array(
 			"vps_renewal_before" => array(
-				"legend" => _("Warnings before expiration: "),
+				"legend" => _("Warnings before expiration for VPS: "),
 				"type" => "text",
 				"size" => "16"),
 			"vps_renewal_after" => array(
-				"legend" => _("Warnings after expiration: "),
+				"legend" => _("Warnings after expiration for VPS: "),
                                 "type" => "text",
                                 "size" => "16"),
 			"vps_renewal_lastwarning" => array(
-				"legend" => _("Last warning: "),
+				"legend" => _("Last warning for VPS: "),
                                 "type" => "text",
                                 "size" => "16"),
 			"vps_renewal_shutdown" => array(
-				"legend" => _("Shutdown warning: "),
+				"legend" => _("Shutdown warning for VPS: "),
+                                "type" => "text",
+                                "size" => "16"),
+			"shared_renewal_before" => array(
+				"legend" => _("Warnings before expiration for Shared Hosting: "),
+				"type" => "text",
+				"size" => "16"),
+			"shared_renewal_after" => array(
+				"legend" => _("Warnings after expiration for Shared Hosting: "),
+                                "type" => "text",
+                                "size" => "16"),
+			"shared_renewal_lastwarning" => array(
+				"legend" => _("Last warning for Shared Hosting: "),
+                                "type" => "text",
+                                "size" => "16"),
+			"shared_renewal_shutdown" => array(
+				"legend" => _("Shutdown warning for Shared Hosting: "),
                                 "type" => "text",
                                 "size" => "16"),
 			"message_subject_header" => array(
@@ -311,7 +359,7 @@ function drawDedicatedIPConfig(){
 	$my_pool_values = array();
 	$my_pool_text = array();
 	$my_pool_values[] = 0;
-	$my_pool_text[] = "Not set";
+	$my_pool_text[] = _("Not set");
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
 		$my_pool_values[] = $a["id"];
@@ -343,7 +391,11 @@ function drawDedicatedIPConfig(){
 			"dedicated_server_hostname" => array(
 				"type" => "popup",
 				"values" => $popup_vals,
-				"legend" => _("Dedicated server hostname"))
+				"legend" => _("Dedicated server hostname")),
+			"rdns_addr" => array(
+				"type" => "text",
+				"size" => "30",
+				"legend" => _("RDNS hostname"))
 			)
 	);
 	$out .= dtcDatagrid($dsc);
@@ -376,7 +428,7 @@ function drawIPPoolConfig(){
 				"text" => _("Customize") ),
 			"show_ip_pool_report" => array(
 				"type" => "hyperlink",
-				"legend" => _("show"),
+				"legend" => _("Show"),
 				"text" => _("Show") ),
 			"location" => array(
 				"type" => "text",
@@ -403,8 +455,8 @@ function drawIPPoolConfig(){
 			"zone_type" => array(
 				"type" => "popup",
 				"legend" => _("Type of zone generation"),
-				"values" => array("support_ticket", "ip_per_ip", "ip_per_ip_cidr", "one_zonefile"),
-				"display_replace" => array(_("Support ticket"),_("One zonefile per IP"),_("One zonefile per IP with net/cidr"),_("One zonefile per pool")))
+				"values" => array("support_ticket", "ip_per_ip", "ip_per_ip_cidr", "one_zonefile","one_zonefile_with_minus","one_zonefile_with_name","one_zonefile_with_slash"),
+				"display_replace" => array(_("Support ticket"),_("One zonefile per IP"),_("One zonefile per IP with net/cidr"),_("One zonefile per pool"),_("One zonefile per pool with net-cidr"),_("One zonefiele per pool with name"),_("One zonefile per pool with net/cidr")))
 			)
 		);
 	$out .= dtcDatagrid($dsc);
@@ -434,7 +486,7 @@ function drawIPPoolConfig(){
 			$a = mysql_fetch_array($r);
 			$out .= "<h3>"._("Custom RDNS entries for the IP pool")." " .$a["location"] . " (" . $a["ip_addr"] . " / " . $a["netmask"] . "):</h3>";
 			$out .= _("The following will be appened at the end of the reverse zone file.");
-			$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+			$out .= "<form action=\"?\">
 <input type=\"hidden\" name=\"rub\" value=\"$rub\">
 <input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
 <input type=\"hidden\" name=\"editpool\" value=\"".$_REQUEST["editpool"]."\">
@@ -603,7 +655,7 @@ function drawTicketConfig(){
 			}
 		}
 	}
-	$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$out .= "<form action=\"?\">
 <input type=\"hidden\" name=\"rub\" value=\"$rub\">
 <input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
 <input type=\"hidden\" name=\"action\" value=\"resubscript_all_users\">
@@ -626,6 +678,10 @@ function drawTicketConfig(){
 				"legend" => _("Support ticket email address: "),
 				"type" => "text",
 				"size" => "32"),
+			"support_ticket_fw_email" => array(
+				"legend" => _("Support ticket forward email address:"),
+				"type" => "text",
+				"size" => "32"),
 			"support_ticket_domain" => array(
 				"legend" => "@",
 				"type" => "popup",
@@ -637,7 +693,7 @@ function drawTicketConfig(){
 
 	$dsc = array(
 		"table_name" => $pro_mysql_tik_admins_table,
-		"title" => _("List of the administrators receiving request for support messages:"),
+		"title" => _("List of the administrators allowed to login and receiving support messages:"),
 		"action" => "tik_admins",
 		"forward" => array("rub","sousrub"),
 		"cols" => array(
@@ -659,7 +715,7 @@ function drawTicketConfig(){
 				"legend" => _("Password")),
 			"available" => array(
 				"type" => "radio",
-				"legend" => _("Available"),
+				"legend" => _("Available (will receive tickets)"),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No")))
 			)
@@ -720,7 +776,12 @@ function drawFTPBacupConfig(){
 			"ftp_backup_dest_folder" => array(
 				"legend" => _("Destination folder:"),
 				"type" => "text",
-				"size" => "30")));
+				"size" => "30"),
+			"ftp_active_mode" => array(
+				"legend" => _("Use active FTP connection to backup server:"),
+				"type"=>"radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No")))));
 	return configEditorTemplate ($dsc);
 }
 
@@ -809,7 +870,7 @@ function checkIPAssigned(){
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 0){
-			$a = mysql_array($r);
+			$a = mysql_fetch_array($r);
 			$action_error_txt = _("The IP address $test_ip is already assigned to a dedicated server: cannot assign this one!");
 			$action_error_txt .= "<br>". _("Server hostname: ") . $a["dedicated_server_hostname"];
 			$ret_val = false;
@@ -863,7 +924,7 @@ function drawVPSServerConfig(){
 			"edithost" => array(
 				"type" => "hyperlink",
 				"legend" => _("IPs addrs"),
-				"text" => "Edit IPs"),
+				"text" => _("Edit IPs")),
 			"dom0_ips" => array(
 				"type" => "text",
 				"size" => "8",
@@ -909,7 +970,7 @@ function drawVPSServerConfig(){
 		$my_pool_values = array();
 		$my_pool_text = array();
 		$my_pool_values[] = 0;
-		$my_pool_text[] = "Not set";
+		$my_pool_text[] = _("Not set");
 		for($i=0;$i<$n;$i++){
 			$a = mysql_fetch_array($r);
 			$my_pool_values[] = $a["id"];
@@ -944,6 +1005,10 @@ function drawVPSServerConfig(){
 					"legend" => _("IP Pool"),
 					"values" => $my_pool_values,
 					"display_replace" => $my_pool_text),
+				"rdns_addr" => array(
+					"type" => "text",
+					"size" => "30",
+					"legend" => _("RDNS hostname")),
 				"available" => array(
 					"type" => "radio",
 					"legend" => _("Available"),
@@ -956,13 +1021,13 @@ function drawVPSServerConfig(){
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n == 0){
-			$out .= "Create a mailing list @".$conf_main_domain." if you want to write to all users of this VPS server.";
+			$out .= _("Create a mailing list @").$conf_main_domain._(" if you want to write to all users of this VPS server.");
 		}else{
-			$out .= "<h3>Owners of the VPS of <i>".$a["hostname"]."</i> are subscribed automatically to the following mailing list:</h3>";
+			$out .= "<h3>" . _("Owners of the VPS of") . " <i>".$a["hostname"]."</i> " . _("are subscribed automatically to the following mailing list:") . "</h3>";
 			$q2 = "SELECT * FROM $pro_mysql_vps_server_lists_table WHERE hostname='".$a["hostname"]."' ORDER BY list_name;";
 			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
-			$out .= "Click on the list name to remove the list from the server:<br><br>";
+			$out .= _("Click on the list name to remove the list from the server:<br><br>");
 			$conditions = "";
 			for($i=0;$i<$n2;$i++){
 				$a2 = mysql_fetch_array($r2);
@@ -970,19 +1035,19 @@ function drawVPSServerConfig(){
 					$out .= " - ";
 				}
 				$conditions .= " AND name!='".$a2["list_name"]."'";
-				$out .= "<a href=\"".$_SERVER["PHP_SELF"]."?action=vps_server_list_remove&rub=".$_REQUEST["rub"]."&sousrub=".$_REQUEST["sousrub"]."&edithost=".$_REQUEST["edithost"]."&list_name=".$a2["list_name"]."\">".$a2["list_name"]."</a>";
+				$out .= "<a href=\"?action=vps_server_list_remove&rub=".$_REQUEST["rub"]."&sousrub=".$_REQUEST["sousrub"]."&edithost=".$_REQUEST["edithost"]."&list_name=".$a2["list_name"]."\">".$a2["list_name"]."</a>";
 			}
 			$out .= "<br><br>";
 			$q = "SELECT * FROM $pro_mysql_list_table WHERE domain='$conf_main_domain' $conditions ORDER BY name;";
 			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n = mysql_num_rows($r);
-			$out .= "Click on the list name to add the list to the server:<br><br>";
+			$out .= _("Click on the list name to add the list to the server:")."<br><br>";
 			for($i=0;$i<$n;$i++){
 				$a = mysql_fetch_array($r);
 				if($i != 0){
 					$out .= " - ";
 				}
-				$out .= "<a href=\"".$_SERVER["PHP_SELF"]."?action=vps_server_list_add&rub=".$_REQUEST["rub"]."&sousrub=".$_REQUEST["sousrub"]."&edithost=".$_REQUEST["edithost"]."&name=".$a["name"]."\">".$a["name"]."</a>";
+				$out .= "<a href=\"?action=vps_server_list_add&rub=".$_REQUEST["rub"]."&sousrub=".$_REQUEST["sousrub"]."&edithost=".$_REQUEST["edithost"]."&name=".$a["name"]."\">".$a["name"]."</a>";
 			}
 		}
 	}
@@ -993,7 +1058,7 @@ function drawRegistrySelection(){
 	global $pro_mysql_registry_table;
 	$out = "<h3>". _("Registry selection") ."</h3>";
 	$out .= "";
-	$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$out .= "<form action=\"?\">
 <input type=\"hidden\" name=\"rub\" value=\"".$_REQUEST["rub"]."\">
 <input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
 <input type=\"hidden\" name=\"action\" value=\"add_mx_trigger_backup\">
@@ -1016,11 +1081,12 @@ function generalDaemonCallback(){
 
 function drawGeneralConfig(){
 	global $cc_code_array;
-
+	global $dtcshared_path;
+	global $conf_skin;
+	global $allTLD;
 	global $conf_skin;
 	global $dtcshared_path;
 	$dir = $dtcshared_path."/gfx/skin/";
-
 	$out = "";
 
 	$dsc = array(
@@ -1033,11 +1099,26 @@ function drawGeneralConfig(){
 				"type" => "radio",
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+                        "send_passwords_in_emails" => array(
+                                "legend" => _("Send passwords in registration emails: "),
+                                "type" => "radio",
+                                "values" => array("yes","no"),
+                                "display_replace" => array(_("Yes"),_("No"))),
 			"use_ssl" => array(
 				"legend" => _("Use SSL: "),
 				"type" => "radio",
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+			"use_shared_ssl" => array(
+				"legend" => _("(<a href=\"http://dtcsupport.gplhost.com/PmWiki/Name-based-shared-SSL-vhosts\">Shared SSL warnings!</a>)Allow use of name based shared SSL vhosts: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"force_use_https" => array(
+				"legend" => _("Force HTTPS use: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
 			"domain_based_ftp_logins" => array(
 				"legend" => _("Use @domain.com ftp logins: "),
 				"type" => "radio",
@@ -1057,6 +1138,10 @@ function drawGeneralConfig(){
 				"legend" => _("This server location: "),
 				"values" => array_keys($cc_code_array),
 				"display_replace" => array_values($cc_code_array)),
+			"this_server_default_tld" => array(
+				"type" => "popup",
+				"legend" => _("Registration default TLD: "),
+				"values" => array_values($allTLD)),
 			"selling_conditions_url" => array(
 				"legend" => _("Selling conditions URL: "),
 				"type" => "text",
@@ -1070,7 +1155,7 @@ function drawGeneralConfig(){
                 "edit_callback" => "generalDaemonCallback",
 		"cols" => array (
 			"mta_type" => array(
-				"legend" => "MTA <a href=\"http://pl.wikipedia.org/wiki/MTA\" target=\"_blank\">*</a> : ",
+				"legend" => "MTA <a href=\"http://www.wikipedia.org/wiki/Mail_transfer_agent\" target=\"_blank\">*</a> : ",
 				"type" => "radio",
 				"values" => array("qmail","postfix")),
 			"use_cyrus" => array(
@@ -1095,7 +1180,7 @@ function drawGeneralConfig(){
 				"display_replace" => array(_("Yes"),_("No"))),
 			"use_awstats" => array(
 				"type" => "radio",
-				"legend" => "(<a href=\"http://dtcsupport.gplhost.com/PmWiki/Why-not-using-awstats\">AWStats armful?</a>) " . _("Use awstats: "),
+				"legend" => "(<a href=\"http://dtcsupport.gplhost.com/PmWiki/Why-not-using-awstats\">"._("AWStats harmful")."?</a>) " . _("Use awstats: "),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
 			"use_visitors" => array(
@@ -1135,7 +1220,10 @@ function drawGeneralConfig(){
 			"apache_directoryindex" => array(
 				"legend" => _("Apache DirectoryIndex: "),
 				"size" => "50",
-				"type" => "text")));
+				"type" => "text"),
+			"spam_keep_days" => array(
+				"legend" => _("Keep spams for n days"),
+				"type"	=> "text")));
 	$out .= configEditorTemplate ($dsc);
 
 	// Open a known directory, and proceed to read its contents
@@ -1155,6 +1243,22 @@ function drawGeneralConfig(){
 		"action" => "general_config_skin_chooser",
 		"forward" => array("rub"),
 		"cols" => array(
+			"panel_title" => array(
+				"type" => "text",
+				"legend" => _("Panel title: "),
+				"size" => "30"),
+			"panel_subtitle" => array(
+				"type" => "text",
+				"legend" => _("Panel subtitle: "),
+				"size" => "30"),
+			"panel_logo" => array(
+				"type" => "text",
+				"legend" => _("Panel logo path (relative to ").$dtcshared_path."/gfx/skin/".$conf_skin._(") :"),
+				"size" => "30"),
+			"panel_logolink" => array(
+				"type" => "text",
+				"legend" => _("Panel logo link: "),
+				"size" => "30"),
 			"skin" => array(
 				"legend" => _("Select the type of skin:"),
 				"type" => "popup",
@@ -1432,43 +1536,75 @@ function drawBackupConfig(){
 function drawRegistryApiConfig(){
 
 	global $pro_mysql_config_table;
+	global $pro_mysql_registrar_domains_table;
+	global $allTLD;
+	global $registry_api_modules;
 
+	$out = "";
+
+	// Load all registrar names
+	$all_registrar = array();
+	$nbr_registrar = sizeof($registry_api_modules);
+	for($i=0;$i<$nbr_registrar;$i++){
+		$all_registrar[] = $registry_api_modules[$i]["name"];
+	}
+
+	// Allow activation of the registrar API (not everyone is using it...)
 	$dsc = array(
-		"title" => _("Domain name registry API configuraiton"),
-		"action" => "domain_registry_config_editor",
+		"title" => _("Domain name registry API configuration"),
+		"action" => "domain_registry_config_yesno_editor",
 		"forward" => array("rub","sousrub"),
-		"desc" => "<img src=\"gfx/tucows.jpg\"><br>Note: you must have a Tucows reseller account.",
 		"cols" => array(
 			"use_registrar_api" => array(
 				"legend" => _("Use registrar API:"),
 				"type" => "radio",
 				"values" => array("yes","no"),
-				"display_replace" => array(_("Yes"),_("No"))),
-			"srs_crypt" => array(
-				"legend" => _("Type of encryption for connecting to Tucows server:"),
-				"type" => "radio",
-				"values" => array("DES","BLOWFISH")),
-			"srs_enviro" => array(
-				"legend" => _("Use the LIVE server (and not the test one) :"),
-				"type" => "radio",
-				"values" => array("LIVE","TEST")),
-			"srs_user" => array(
-				"legend" => _("Your SRS username:"),
+				"display_replace" => array(_("Yes"),_("No")))
+		)
+	);
+	$out .= configEditorTemplate ($dsc);
+
+	// Display a grid so the root admin can configure what registrar will be used for what TLD
+	$dsc = array(
+		"title" => _("Registrar selection and final customer pricing"),
+		"action" => "tld_vs_registrar_selection",
+		"forward" => array("rub","sousrub"),
+		"table_name" => $pro_mysql_registrar_domains_table,
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id",
+				),
+			"tld" => array(
+				"type" => "popup",
+				"legend" => _("TLD"),
+				"values" => $allTLD,
+				),
+			"price" => array(
 				"type" => "text",
-				"size" => "30"),
-			"srs_test_key" => array(
-				"legend" => _("Your key to access the test server:"),
-				"type" => "text",
-				"size" => "50"),
-			"srs_live_key" => array(
-				"legend" => _("Your key to access the LIVE server:"),
-				"type" => "text",
-				"size" => "50")));
-	return configEditorTemplate ($dsc);
+				"legend" => _("Price"),
+				),
+			"registrar" => array(
+				"type" => "popup",
+				"legend" => _("Registrar"),
+				"values" => $all_registrar
+				)
+		)
+	);
+	$out .= dtcDatagrid($dsc);
+
+	// Display the configurator for each registrar (configuration is in the main.php of each module)
+	for($i=0;$i<$nbr_registrar;$i++){
+		$dsc = $registry_api_modules[$i]["configure_descriptor"];
+		$out .= configEditorTemplate ($dsc);
+	}
+	return $out;
 }
 
 function drawDTCpayConfig(){
 	global $pro_mysql_secpayconf_table;
+	global $pro_mysql_custom_fld_table;
 
 	$out = "";
 
@@ -1510,6 +1646,54 @@ function drawDTCpayConfig(){
 				"size" => "6")));
 	$out .= configEditorTemplate ($dsc,"secpay");
 
+	$dsc = array(
+		"title" => _("Custom registration fields"),
+		"table_name" => $pro_mysql_custom_fld_table,
+		"action" => "custom_registration_field_editor",
+		"forward" => array("rub","sousrub"),
+		"order_by" => "widgetorder",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "Id"),
+			"widgetorder" => array(
+				"legend" => _("Display order"),
+				"type" => "text",
+				"size" => "4"),
+			"varname" => array(
+				"legend" => _("Variable name"),
+				"type" => "text",
+				"size" => "15"),
+			"question" => array(
+				"legend" => _("Question to the user"),
+				"type" => "text",
+				"size" => "30"),
+			"widgettype" => array(
+				"legend" => _("Widget type"),
+				"type" => "popup",
+				"values" => array( "text", "popup", "radio", "textarea")),
+			"widgetvalues" => array(
+				"legend" => _("Possible values"),
+				"type" => "text",
+				"size" => "20"),
+			"widgetdisplay" => array(
+				"legend" => _("Corresponding display"),
+				"type" => "text",
+				"size" => "30"),
+			"mandatory" => array(
+				"legend" => _("Mandatory field"),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No")),
+				"default" => "no")
+			)
+		);
+	$out .= dtcDatagrid($dsc);
+	$out .= _("On the above tables, the possible values are what is is going to be the internal value in the popup or radio buttons,
+which is what is going to be recorded in the database. Values are separated by \"|\". The corresponding display is what will actually
+be displayed to your users instead of the popup value.")."<br>";
+
 	$dsc = array(
 		"title" => _("Cheques and wire transfers:"),
 		"action" => "cheques_edit",
@@ -1622,7 +1806,7 @@ function drawDTCpayConfig(){
 	$out .= configEditorTemplate ($dsc,"secpay");
 
 	$dsc = array(
-		"title" => "MoneyBookers (currently in development):",
+		"title" => _("MoneyBookers (currently in development):"),
 		"action" => "payment_gateway_moneybookers_edit",
 		"forward" => array("rub","sousrub"),
 		"cols" => array(
@@ -1640,6 +1824,10 @@ function drawDTCpayConfig(){
 				"legend" => _("MoneyBookers business account email: "),
 				"type" => "text",
 				"size" => "30"),
+			"moneybookers_secret_word" => array(
+				"legend" => _("MoneyBookers secret word: "),
+				"type" => "text",
+				"size" => "10"),
 			"moneybookers_rate" => array(
 				"legend" => _("MoneyBookers fee rate: "),
 				"type" => "text",
@@ -1694,7 +1882,7 @@ function drawDTCpayConfig(){
 	$out .= configEditorTemplate ($dsc,"secpay");
 
 	$dsc = array(
-		"title" => "Maxmind API:",
+		"title" => _("Maxmind API:"),
 		"action" => "maxmind_api_conf_edit",
 		"forward" => array("rub","sousrub"),
 		"cols" => array(
@@ -1710,7 +1898,44 @@ function drawDTCpayConfig(){
 			"maxmind_license_key" => array(
 				"legend" => _("Maxmind license key: "),
 				"type" => "text",
-				"size" => "30")));
+				"size" => "30"),
+			"maxmind_threshold" => array(
+				"legend" => _("Maxmind fraud threshold: "),
+				"type" => "number",
+				"size" => "3"),
+
+			));
+	$out .= configEditorTemplate ($dsc,"secpay");
+
+	$dsc = array(
+		"title" => _("Dineromail:"),
+		"action" => "dineromail_gateway_dineromail_edit",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"use_dineromail" => array(
+				"legend" => _("Use dineromail: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"dineromail_nrocuenta" => array(
+				"legend" => _("Dineromail Account: "),
+				"type" => "text",
+				"size" => "20"),
+			"dineromail_tipospago" => array(
+				"legend" => _("Payments Accepted: "),
+				"type" => "checkboxcomma",
+				"values" => array("2","7","13","4","5","6","14","15","16","17","18"),
+				"display_replace" => array(_("Barcode"),_("DineroMail account funds"),_("Wiretransfer"),_("Credit card in one payment"),
+					_("Credit card in 3 installments"),_("Credit card in 6 installments"),_("Credit card in 9 installments"),
+					_("Credit card in 12 installments"),_("Credit card in 18 installments"),_("Credit card in 24 installments"),_("Credit card in Z plan"))),
+			"dineromail_cargocomision" => array(
+				"legend" => _("Fixed charge fee: "),
+				"type" => "text",
+				"size" => "6"),
+			"dineromail_porcentajecomision" => array(
+				"legend" => _("Percentage fee: "),
+				"type" => "text",
+				"size" => "6"), ));
 	$out .= configEditorTemplate ($dsc,"secpay");
 
 	return $out;
@@ -1718,15 +1943,21 @@ function drawDTCpayConfig(){
 
 function drawDTCradiusConfig(){
 	global $conf_dtcshared_path;
+	global $pro_mysql_nas_table;
+	global $pro_mysql_radgroup_table;
+	global $pro_mysql_radgroupcheck_table;
+	global $pro_mysql_radgroupreply_table;
+	global $pro_mysql_raduser_table;
+	global $pro_mysql_radcheck_table;
+	global $pro_mysql_radreply_table;
+	global $pro_mysql_product_table;
+	global $pro_mysql_dedicated_table;
 	global $lang;
 
-	$out = "";
+	$out = "WARNING!!! All parameteres (specially Attributes) set here have NO validation at all, so be careful.<BR>Freeradius will have unexpected behavoiurs if you do mistakes or errors here, and may be it can't start.";
 	$dsc = array(
 		"title" => _("NAS config"),
-		"new_item_title" => "Add new NAS:",
-		"new_item_link" => "Add new NAS",
-		"edit_item_title" => "Edit a NAS:",
-		"table_name" => "nas",
+		"table_name" => $pro_mysql_nas_table,
 		"action" => "nas_editor",
 		"forward" => array("rub","sousrub"),
 		"id_fld" => "id",
@@ -1739,29 +1970,252 @@ function drawDTCradiusConfig(){
 			"nasname" => array(
 				"type" => "text",
 				"disable_edit" => "yes",
-				"legend" => _("Name: ")),
+				"legend" => _("Name")),
 			"shortname" => array(
 				"type" => "text",
-				"legend" => _("Short name: ")),
+				"legend" => _("Short name")),
 			"type" => array(
 				"type" => "popup",
-				"legend" => _("Type:"),
+				"legend" => _("Type"),
 				"values" => array("cisco","computone","livingston","max40xx","multitech","netserver","pathras","patton","portslave","tc","usrhiper","other")),
 			"ports" => array(
 				"type" => "text",
-				"legend" => _("Port number: "),
+				"legend" => _("Port number"),
 				"check" => "number"),
 			"secret" => array(
 				"type" => "password",
-				"legend" => _("Password: "),
+				"legend" => _("Password"),
 				"check" => "dtc_pass"),
+			"server" => array(
+				"type" => "text",
+				"legend" => _("Virtual Radius Server")),
 			"community" => array(
 				"type" => "text",
-				"legend" => "SNMP community: "),
+				"legend" => _("SNMP community")),
 			"description" => array(
 				"type" => "text",
-				"legend" => _("Description: "))));
-	$out .= dtcListItemsEdit($dsc);
+				"legend" => _("Description"))));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
+	$dsc = array(
+		"title" => _("Group config"),
+		"table_name" => $pro_mysql_radgroup_table,
+		"action" => "group_editor",
+		"forward" => array("rub","sousrub"),
+		"id_fld" => "id",
+		"list_fld_show" => "GroupName",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id"),
+			"GroupName" => array(
+				"type" => "text",
+				"disable_edit" => "yes",
+				"legend" => _("Name")),
+			"Description" => array(
+				"type" => "text",
+				"legend" => _("Description"))));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
+        $q = "SELECT * FROM $pro_mysql_radgroup_table WHERE 1;";
+        $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+        $n = mysql_num_rows($r);
+        $group_names = array(_("Please select"));
+        $group_ids = array(0);
+        for($i=0;$i<$n;$i++){
+                $a = mysql_fetch_array($r);
+                $group_names[] = $a["GroupName"];
+//		echo $a["GroupName"];
+                $group_ids[] = $a["id"];
+        }
+
+	$dsc = array(
+		"title" => _("Group Attributes checking config"),
+		"table_name" => $pro_mysql_radgroupcheck_table,
+		"action" => "group_attribute_check_editor",
+		"forward" => array("rub","sousrub"),
+		"id_fld" => "id",
+		"list_fld_show" => "GroupName",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id"),
+			"GroupName" => array(
+				"type" => "popup",
+				"disable_edit" => "yes",
+				"legend" => _("Group"),
+				"values" => $group_ids,
+				"display_replace" => $group_names),
+			"Attribute" => array(
+				"type" => "text",
+				"legend" => _("Attribute")),
+			"op" => array(
+				"type" => "popup",
+				"legend" => _("Operation"),
+				"values" => array("==",":=","+=","!=",">=","<=",">","<","=~","!~","=*","!*")),
+			"Value" => array(
+				"type" => "text",
+				"legend" => _("Value"))));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
+
+	$dsc = array(
+		"title" => _("Group Reply Attributes config"),
+		"table_name" => $pro_mysql_radgroupreply_table,
+		"action" => "group_attribute_reply_editor",
+		"forward" => array("rub","sousrub"),
+		"id_fld" => "id",
+		"list_fld_show" => "GroupName",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id"),
+			"GroupName" => array(
+				"type" => "popup",
+				"disable_edit" => "yes",
+				"legend" => _("Group"),
+				"values" => $group_ids,
+				"display_replace" => $group_names),
+			"Attribute" => array(
+				"type" => "text",
+				"legend" => _("Attribute")),
+			"op" => array(
+				"type" => "popup",
+				"legend" => _("Operation"),
+				"values" => array("=",":=","+=")),
+			"Value" => array(
+				"type" => "text",
+				"legend" => _("Value")),
+			"prio" => array(
+				"type" => "text",
+				"legend" => _("Priority"),
+				"size" => 5)));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
+        $q = "SELECT * FROM $pro_mysql_raduser_table WHERE 1;";
+        $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+        $n = mysql_num_rows($r);
+        $user_names = array(_("Please select"));
+        $user_ids = array(0);
+        for($i=0;$i<$n;$i++){
+                $a = mysql_fetch_array($r);
+                $user_names[] = $a["UserName"];
+//		echo $a["UserName"];
+                $user_ids[] = $a["id"];
+        }
+
+        $q = "SELECT server_hostname,$pro_mysql_dedicated_table.id FROM $pro_mysql_dedicated_table,$pro_mysql_product_table WHERE $pro_mysql_dedicated_table.product_id=$pro_mysql_product_table.id and use_radius='yes';";
+        $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+        $n = mysql_num_rows($r);
+        $dedicated_names = array(_("None"));
+        $dedicated_ids = array(0);
+        for($i=0;$i<$n;$i++){
+                $a = mysql_fetch_array($r);
+                $dedicated_names[] = $a["server_hostname"];
+//		echo $a["server_hostname"];
+                $dedicated_ids[] = $a["id"];
+        }
+
+	$dsc = array(
+		"title" => _("Radius Users"),
+		"table_name" => $pro_mysql_raduser_table,
+		"action" => "raduser_editor",
+		"forward" => array("rub","sousrub"),
+		"id_fld" => "id",
+		"list_fld_show" => "UserName",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id"),
+			"UserName" => array(
+				"type" => "text",
+				"disable_edit" => "yes",
+				"legend" => _("Username")),
+			"Password" => array(
+				"type" => "password",
+				"legend" => _("Password")),
+			"GroupName" => array(
+				"type" => "popup",
+				"legend" => _("Group"),
+				"values" => $group_ids,
+				"display_replace" => $group_names),
+			"Dedicated_id" => array(
+				"type" => "popup",
+				"legend" => _("Associated Dedicated Service"),
+				"values" => $dedicated_ids,
+				"display_replace" => $dedicated_names)));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
+	$dsc = array(
+		"title" => _("User Attributes checking config"),
+		"table_name" => $pro_mysql_radcheck_table,
+		"action" => "user_attribute_check_editor",
+		"forward" => array("rub","sousrub"),
+		"id_fld" => "id",
+		"list_fld_show" => "UserName",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id"),
+			"UserName" => array(
+				"type" => "popup",
+				"disable_edit" => "yes",
+				"legend" => _("Username"),
+				"values" => $user_names),
+			"Attribute" => array(
+				"type" => "text",
+				"legend" => _("Attribute")),
+			"op" => array(
+				"type" => "popup",
+				"legend" => _("Operation"),
+				"values" => array("==",":=","+=","!=",">=","<=",">","<","<>","=~","!~","=*","!*")),
+			"Value" => array(
+				"type" => "text",
+				"legend" => _("Value"))));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
+
+	$dsc = array(
+		"title" => _("User Reply Attributes config"),
+		"table_name" => $pro_mysql_radreply_table,
+		"action" => "user_attribute_reply_editor",
+		"forward" => array("rub","sousrub"),
+		"id_fld" => "id",
+		"list_fld_show" => "UserName",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => "id"),
+			"UserName" => array(
+				"type" => "popup",
+				"disable_edit" => "yes",
+				"legend" => _("Username"),
+				"values" => $user_names),
+			"Attribute" => array(
+				"type" => "text",
+				"legend" => _("Attribute")),
+			"op" => array(
+				"type" => "popup",
+				"legend" => _("Operation"),
+				"values" => array("=",":=","+=")),
+			"Value" => array(
+				"type" => "text",
+				"legend" => _("Value"))));
+	$out .= dtcDatagrid($dsc);
+	$out .= "<BR><BR>";
+
 	return $out;
 }
 
@@ -1821,7 +2275,7 @@ Each of the following (qmail, apache and named) path will be concatened to this:
 
 
 	$dsc = array(
-		"title" => "<img src=\"gfx/dtc/generate_mail.gif\">Qmail path:",
+		"title" => "<img src=\"gfx/dtc/generate_mail.gif\">"._("Qmail path").":",
 		"action" => "qmail_path_editor",
 		"forward" => array("rub","sousrub"),
 		"cols" => array(
@@ -1964,7 +2418,7 @@ function drawInvoicingConfig(){
 	$q = "SELECT * FROM $pro_mysql_companies_table WHERE 1;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
-	$comp_names = array("Please select");
+	$comp_names = array(_("Please select"));
 	$comp_ids = array(0);
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
@@ -1989,7 +2443,7 @@ function drawInvoicingConfig(){
 	$country_codes = array_reverse($country_codes);
 	$country_fullnames = array_reverse($country_fullnames);
 	$country_codes[] = "00";
-	$country_fullnames[] = "none";
+	$country_fullnames[] = _("none");
 	$country_codes = array_reverse($country_codes);
 	$country_fullnames = array_reverse($country_fullnames);
 
