@@ -1,5 +1,72 @@
 <?php
 
+// Returns an array as follow:
+// $ret["text"] html code to display
+//     ["where_condition"] the SQL filter to user in your later queries.
+function dateSelector($table,$mysql_date_field,$http_query_field){
+	global $rub;
+	global $sousrub;
+	$out = array();
+	$out["text"] = "<h3>"._("Date selection")."</h3>";
+
+	if( !isset($_REQUEST[$http_query_field])){
+		$q = "SELECT DISTINCT(CONCAT_WS('-',YEAR($mysql_date_field),MONTH($mysql_date_field))) FROM `$table` WHERE 1 ORDER BY $mysql_date_field DESC LIMIT 1";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 0){
+			$a = mysql_fetch_array($r);
+			$exploded = explode("-",$a[0]);
+			$using_date = $exploded[0];
+			if(strlen($exploded[1]) < 2){
+				$using_date = $exploded[0] . "-0" . $exploded[1];
+			}else{
+				$using_date = $exploded[0] . "-" . $exploded[1];
+			}
+			$out["text"] .= "<a href=\"?rub=$rub&sousrub=$sousrub&$http_query_field=all\">" . _("all") . "</a>";
+			$date = $using_date;
+			$where_condition = " $mysql_date_field LIKE '$date%' ";
+		}else{
+			$out["text"] .= _("all");
+			$date = "all";
+			$where_condition = " 1 ";
+		}
+	}else if( $_REQUEST[$http_query_field] == "all"){
+		$out["text"] .= _("all");
+		$date = "all";
+		$where_condition = " 1 ";
+	}else{
+		$out["text"] .= "<a href=\"?rub=$rub&sousrub=$sousrub&$http_query_field=all\">" . _("all") . "</a>";
+		$date = $_REQUEST["$http_query_field"];
+		$where_condition = " $mysql_date_field LIKE '$date%' ";
+	}
+
+	$q = "SELECT DISTINCT(CONCAT_WS('-',YEAR($mysql_date_field),MONTH($mysql_date_field))) FROM `$table` WHERE 1 ORDER BY $mysql_date_field ";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$exploded = explode("-",$a[0]);
+		$using_date = $exploded[0];
+		if(strlen($exploded[1]) < 2){
+			$using_date = $exploded[0] . "-0" . $exploded[1];
+		}else{
+			$using_date = $exploded[0] . "-" . $exploded[1];
+		}
+		if($date != $using_date){
+			$out["text"] .= " - <a href=\"?rub=$rub&sousrub=$sousrub&$http_query_field=".$using_date."\">".$using_date."</a>";
+		}else{
+			$out["text"] .= " - $using_date";
+		}
+	}
+	$out["text"] .= "<br><br>";
+
+	$out["date"] = $date;
+	$out["where_condition"] = $where_condition;
+
+	return $out;
+}
+
+
 function drawRenewalTables (){	
 	global $pro_mysql_product_table;
 	global $pro_mysql_admin_table;
@@ -17,6 +84,8 @@ function drawRenewalTables (){
 	global $pro_mysql_spent_moneyout_table;
 	global $pro_mysql_companies_table;
 	global $pro_mysql_spent_bank_table;
+	global $pro_mysql_client_table;
+	global $pro_mysql_new_admin_table;
 
 	global $secpayconf_currency_letters;
 	global $rub;
@@ -57,62 +126,13 @@ function drawRenewalTables (){
 	}
 	$out .= "</ul>";
 
+
+
 	switch($sousrub){
 	case "spent":
-		$out .= "<h3>Date selection</h3>";
-
-		if( !isset($_REQUEST["date_selector"])){
-			// Check the last record to get the last entry by default.
-			$q = "SELECT DISTINCT(CONCAT_WS('-',YEAR(invoice_date),MONTH(invoice_date))) FROM `spent_moneyout` WHERE 1 ORDER BY invoice_date DESC LIMIT 1";
-			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
-			$n = mysql_num_rows($r);
-			if($n != 0){
-				$a = mysql_fetch_array($r);
-				$exploded = explode("-",$a[0]);
-				$using_date = $exploded[0];
-				if(strlen($exploded[1]) < 2){
-					$using_date = $exploded[0] . "-0" . $exploded[1];
-				}else{
-					$using_date = $exploded[0] . "-" . $exploded[1];
-				}
-				$out .= "<a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&sousrub=$sousrub&date_selector=all\">all</a>";
-				$date = $using_date;
-				$where_condition = " invoice_date LIKE '$date%' ";
-			}else{
-				$out .= "all";
-				$date = "all";
-				$where_condition = " 1 ";
-			}
-		}else if( $_REQUEST["date_selector"] == "all"){
-			$out .= "all";
-			$date = "all";
-			$where_condition = " 1 ";
-		}else{
-			$out .= "<a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&sousrub=$sousrub&date_selector=all\">all</a>";
-			$date = $_REQUEST["date_selector"];
-			$where_condition = " invoice_date LIKE '$date%' ";
-		}
-
-		$q = "SELECT DISTINCT(CONCAT_WS('-',YEAR(invoice_date),MONTH(invoice_date))) FROM `spent_moneyout` WHERE 1 ORDER BY invoice_date";
-		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
-		$n = mysql_num_rows($r);
-		for($i=0;$i<$n;$i++){
-			$a = mysql_fetch_array($r);
-			$exploded = explode("-",$a[0]);
-			$using_date = $exploded[0];
-			if(strlen($exploded[1]) < 2){
-				$using_date = $exploded[0] . "-0" . $exploded[1];
-			}else{
-				$using_date = $exploded[0] . "-" . $exploded[1];
-			}
-			if($date != $using_date){
-				$out .= " - <a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&sousrub=$sousrub&date_selector=".$using_date."\">".$using_date."</a>";
-			}else{
-				$out .= " - $using_date";
-			}
-		}
-
-		$out .= "<br><br>";
+		$ret = dateSelector("spent_moneyout","invoice_date","date_selector");
+		$out .= $ret["text"];
+		$where_condition = $ret["where_condition"];
 
 		$q = "SELECT * FROM $pro_mysql_spent_providers_table ";
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -314,9 +334,9 @@ function drawRenewalTables (){
 			"forward" => array("rub","sousrub"),
 			"id_fld" => "id",
 			"list_fld_show" => "quick_name",
-			"new_item_title" => "New upstream provider:",
-			"new_item_link" => "New upsream provider",
-			"edit_item_title" => "Edit upstream provider:",
+			"new_item_title" => _("New upstream provider").":",
+			"new_item_link" => _("New upsream provider"),
+			"edit_item_title" => _("Edit upstream provider").":",
 			"check_unique" => array( "quick_name" ),
 			"where_list" => array("always_yes" => "yes"),
 			"cols" => array(
@@ -408,14 +428,136 @@ function drawRenewalTables (){
 
 		// Display of each month payment list
 		if(isset($_REQUEST["date"])){
+			$ret = dateSelector($pro_mysql_pay_table,"date","date");
+			$out .= $ret["text"];
+			$where_condition = $ret["where_condition"];
+
+			$q = "SELECT id,name FROM $pro_mysql_product_table ";
+			$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			$prod_ids = array();
+			$prod_names = array();
+			for($i=0;$i<$n;$i++){
+				$a = mysql_fetch_array($r);
+				$prod_ids[] = $a["id"];
+				$prod_names[] = $a ["name"];
+			}
+
+			$out .= "<h3>"._("Payements for the period: ").$_REQUEST["date"]."</h3>";
+
+			$dsc = array(
+				"title" => _("Payment history"),
+				"table_name" => $pro_mysql_pay_table,
+				"action" => "payment_history_list_editor",
+				"forward" => array("rub","date"),
+				"order_by" => "date",
+				"skip_deletion" => "yes",
+				"skip_creation" => "yes",
+				"print_where_condition" => $where_condition,
+				"cols" => array(
+					"id" => array(
+						"type" => "id",
+						"display" => "no",
+						"legend" => "id"),
+					"date" => array(
+						"type" => "text",
+						"size" => "8",
+						"legend" => _("Date")),
+					"id_client" => array(
+						"type" => "double_forkey",
+						"forkey_type" => "info",
+
+						// payment_table ["id"] gives us a key to search in completed oders
+						// for the client_id. Then we use that client_id to find the customer infos.
+						"table_1st_ind" => $pro_mysql_completedorders_table,
+						"fldwhere_1st_ind_orig" => "id",
+						"fldwhere_1st_ind" => "payment_id",
+						"searchkey_1st_ind" => "id_client",
+						"table_2nd_ind" => $pro_mysql_client_table,
+						"display_flds_2nd_ind" => "CONCAT(company_name,': ',familyname,', ',christname)",
+						"link_start" => "?rub=crm&id=",
+
+						// If not found, we fall back to search in the new_admin table
+						"table_back" => $pro_mysql_new_admin_table,
+						"fldwhere_back_orig" => "id_client",
+						"fldwhere_back" => "id",
+						"display_flds_back" => "CONCAT(comp_name,': ',family_name,', ',first_name)",
+						"link_start" => "view_waitingusers.php?reqadm_id=",
+
+						"legend" => _("Customer name")),
+					/*"id_client" => array(
+						"type" => "forkey",
+						"forkey_type" => "info",
+						"table" => $pro_mysql_client_table,
+						"other_table_fld" => "CONCAT(company_name,': ',familyname,', ',christname)",
+						"other_table_key" => "id",
+						"this_table_field" => "id_client",
+						"link" => "?rub=crm&id=",
+
+						"bk_table" => $pro_mysql_new_admin_table,
+						"bk_other_table_fld" => "CONCAT(comp_name,': ',family_name,', ',first_name)",
+						"bk_other_table_key" => "id",
+						"bk_this_table_field" => "id_client",
+
+						"legend" => _("Customer name")),*/
+					"product_id" => array(
+						"type" => "popup",
+						"values" => $prod_ids,
+						"display_replace" => $prod_names,
+						"legend" => _("Product")),
+					"refund_amount" => array(
+						"type" => "text",
+						"size" => "8",
+						"legend" => _("Refund amount")),
+					"paiement_cost" => array(
+						"type" => "text",
+						"size" => "4",
+						"legend" => _("Gate cost")),
+					"vat_rate" => array(
+						"type" => "text",
+						"size" => "4",
+						"legend" => _("VAT rate")),
+					"vat_total" => array(
+						"type" => "text",
+						"size" => "4",
+						"legend" => _("VAT total")),
+					 "paiement_total" => array(
+						"type" => "text",
+						"size" => "6",
+						"legend" => _("Grand total")),
+					"paiement_type" => array(
+						"type" => "text",
+						"size" => "6",
+						"legend" => _("Type")),
+					"secpay_site" => array(
+						"type" => "text",
+						"size" => "4",
+						"legend" => _("Gate type")),
+					"new_account" => array(
+						"type" => "popup",
+						"values" => array("no","yes"),
+						"display_replace" => array( _("New account"), _("Renewal") ),
+						"legend" => _("Is renewal")),
+					"valid" => array(
+						"type" => "popup",
+						"values" => array("no","pending","yes"),
+						"display_replace" => array( _("No"), _("Pending"), _("Yes") ),
+						"legend" => _("Validated")),
+					"pending_reason" => array(
+						"type" => "text",
+						"size" => "6",
+						"legend" => _("Pending reason"))
+				));
+			$out .= dtcDatagrid($dsc);
+			return $out;
+
+			$ret = dateSelector($pro_mysql_completedorders_table,"date","date");
 			// Allow nuke of bad payment (hackers?) to have accounting done correctly
 			if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "nuke_payment"){
 				$q = "DELETE FROM $pro_mysql_completedorders_table WHERE id='".$_REQUEST["completedorders_id"]."';";
 				$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			}
-			$out .= "<h3>"._("Payements for the period: ").$_REQUEST["date"]."</h3>";
-			$q = "SELECT * FROM $pro_mysql_completedorders_table
-			WHERE date LIKE '".$_REQUEST["date"]."%' ORDER BY date;";
+
 			$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n = mysql_num_rows($r);
 			if($n < 1){
@@ -477,12 +619,14 @@ function drawRenewalTables (){
 					}else{
 						$last_expiry_date = $a["last_expiry_date"];
 					}
+					if($payment_type == 'wire') $pay=_("Wire"); else if ($payment_type == 'cheque') $pay=_("cheque");
+					else if ( $payment_type == 'online: none' ) $pay=_("online: none"); else $pay=$payment_type;
 					$new_expiry_date = calculateExpirationDate($last_expiry_date,$product_period_size);
 					$out .= "<tr><td>$product_txt</td><td>$client_id_txt</td><td>$client_name</td><td>".$a["country_code"]."</td>
 					<td>$client_country</td>
 					<td>$vat_collected</td><td>$last_expiry_date -> $new_expiry_date</td><td>".$a["date"]."</td><td>$payment_txt</td>
-					<td>$payment_type</td>
-					<td><a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&date=".$_REQUEST["date"]."&action=nuke_payment&completedorders_id=".$a["id"]."\">"._("Delete")."</a></tr>";
+					<td>$pay</td>
+					<td><a href=\"?rub=$rub&date=".$_REQUEST["date"]."&action=nuke_payment&completedorders_id=".$a["id"]."\">"._("Delete")."</a></tr>";
 				}
 				$out .= "</table>";
 			}
@@ -577,7 +721,7 @@ function drawRenewalTables (){
 				$papoum = explode('-',$period);
 				$months = $papoum[1];
 				if($months == 0){
-					echo "Dedicated server product ID $id has zero for the number of month to renew<br>";
+					echo _("Dedicated server product ID $id has zero for the number of month to renew")."<br>";
 				}else{
 					$total_dedicated += $price / $months;
 				}
@@ -598,6 +742,12 @@ function drawRenewalTables (){
 		$cur_year = $year - 2;
 		$cur_month = $month;
 		$p_history = "";
+		$selected_country="";
+		$country_array = array();
+		if(isset($_REQUEST["country"])){
+			$selected_country=$_REQUEST["country"];
+		        $p_history .= ("Selected Country:") . $selected_country;	
+		}
 		$p_history .= "<table cellspacing=\"1\" cellpadding=\"1\" border=\"1\">
 		<tr><td>". _("Period") ."</td><td>". _("Amount") ."</td><td>"._("VAT collected")."</td><td>"._("Payment gateway cost")."</td><td>"._("Profit")."</td></tr>";
 		for($i=0;$i<25;$i++){
@@ -605,12 +755,14 @@ function drawRenewalTables (){
 			FROM $pro_mysql_pay_table,$pro_mysql_completedorders_table
 			WHERE $pro_mysql_pay_table.vat_rate!='0.00'
 			AND $pro_mysql_completedorders_table.payment_id = $pro_mysql_pay_table.id
-			AND $pro_mysql_completedorders_table.date LIKE '".$cur_year."-".$cur_month."-%';";
+			AND $pro_mysql_completedorders_table.date LIKE '".$cur_year."-".$cur_month."-%'";
+			if ($selected_country != "") $q2 .= " AND $pro_mysql_completedorders_table.country_code='$selected_country'";
+			$q2 .= ";";
 			$r2 = mysql_query($q2)or die("Cannot querry $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
 			$vat_collected = 0;
-			$month_total = 0;
-			$cost_total = 0;
+			$month_total =0;
+			$cost_total=0;
 			for($j=0;$j<$n2;$j++){
 				$a2 = mysql_fetch_array($r2);
 				$tt = $a2["paiement_total"];
@@ -623,7 +775,9 @@ function drawRenewalTables (){
 			$q2 = "SELECT sum(paiement_total) as paiement_total, sum(paiement_cost) as paiement_cost FROM $pro_mysql_completedorders_table,$pro_mysql_pay_table
 			WHERE $pro_mysql_completedorders_table.date LIKE '".$cur_year."-".$cur_month."%'
 			AND $pro_mysql_completedorders_table.payment_id = $pro_mysql_pay_table.id
-			AND $pro_mysql_pay_table.vat_rate = '0.00';";
+			AND $pro_mysql_pay_table.vat_rate = '0.00'";
+			if ($selected_country != "") $q2 .= " AND $pro_mysql_completedorders_table.country_code='$selected_country'";
+			$q2 .= ";";
 			$r2 = mysql_query($q2)or die("Cannot querry $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
 			if($n2 > 0){
@@ -631,7 +785,7 @@ function drawRenewalTables (){
 				$cost_total += $a2["paiement_cost"];
 				$month_total += $a2["paiement_total"];
 				$profit = $month_total - $cost_total - $vat_collected;
-				$p_history .= "<tr><td style=\"text-align:right;\"><a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&date=".$cur_year."-".$cur_month."\">".$cur_year."-".$cur_month."</a></td>
+				$p_history .= "<tr><td style=\"text-align:right;\"><a href=\"?rub=$rub&date=".$cur_year."-".$cur_month."\">".$cur_year."-".$cur_month."</a></td>
 				<td style=\"text-align:right;\">".$month_total." $secpayconf_currency_letters</td>
 				<td style=\"text-align:right;\">".round($vat_collected,2)." $secpayconf_currency_letters</td>
 				<td style=\"text-align:right;\">".round($cost_total,2)." $secpayconf_currency_letters</td>
@@ -645,6 +799,18 @@ function drawRenewalTables (){
 			if($cur_month < 10)	$cur_month = "0".$cur_month;
 		}
 		$p_history .= "</table>";
+		$p_history .= _("Select country to report on:");
+		
+		$p_history .= "<a href=\"?rub=$rub\">ALL</a> ";	
+		$q2 = "SELECT distinct(country_code) from $pro_mysql_completedorders_table;";
+		$r2 = mysql_query($q2)or die("Cannot querry $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n2 = mysql_num_rows($r2);
+		for($j=0;$j<$n2;$j++){
+			$a2 = mysql_fetch_array($r2);
+			$country = $a2["country_code"];
+			$p_history .= "<a href=\"?rub=$rub&country=$country\">$country</a> ";	
+		}
+		
 
 		$p_active_prods = "<img src=\"active_prods_graph.php?graph=year\"><br>
 <img src=\"active_prods_graph.php?graph=month\">";
@@ -771,7 +937,7 @@ function drawRenewalTables (){
 							$r2 = mysql_query($q2)or die("Cannot querry ".$q2." line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 							$n2 = mysql_num_rows($r2);
 							if($n2 == 0){
-								$kill_owner_txt = "<a href=\"".$_SERVER["PHP_SELF"]."?action=kill_vps_and_owner&adm_login=".$admin["adm_login"]."&client_id=".$admin["id_client"]."&vps_name=".$a["vps_xen_name"]."&server_hostname=".$a["vps_server_hostname"]."&vps_id=".$a["id"]."\">"._("Kill VPS and owner")."</a>";
+								$kill_owner_txt = "<a href=\"?action=kill_vps_and_owner&adm_login=".$admin["adm_login"]."&client_id=".$admin["id_client"]."&vps_name=".$a["vps_xen_name"]."&server_hostname=".$a["vps_server_hostname"]."&vps_id=".$a["id"]."\">"._("Kill VPS and owner")."</a>";
 							}else{
 								$kill_owner_txt = _("Has some domains");
 							}
@@ -795,7 +961,7 @@ function drawRenewalTables (){
 				<td>".$a2["email"]."</td>
 				<td $bgcolor>".$a["expire_date"]."</td>
 				<td $bgcolor>". calculateAge($a["expire_date"],"00:00:00") ."</td>
-				<td><a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&action=shutdown_expired_vps&server_hostname=".$a["vps_server_hostname"]."&vps_name=".$a["vps_xen_name"]."\">"._("Shutdown")."</a> - $kill_owner_txt</td></tr>";
+				<td><a href=\"?rub=$rub&action=shutdown_expired_vps&server_hostname=".$a["vps_server_hostname"]."&vps_name=".$a["vps_xen_name"]."\">"._("Shutdown")."</a> - $kill_owner_txt</td></tr>";
 			}
 			$out .= "</table>";
 		}
