@@ -256,11 +256,15 @@ if(isset($_REQUEST["updateuserinfo"]) && $_REQUEST["updateuserinfo"] == "Ok"){
 	$adm_query = "UPDATE $pro_mysql_admin_table SET id_client='".$_REQUEST["changed_id_client"]."',
 		adm_pass='".$_REQUEST["changed_pass"]."',path='".$_REQUEST["changed_path"]."',
 		quota='".$_REQUEST["adm_quota"]."', bandwidth_per_month_mb='".$_REQUEST["bandwidth_per_month"]."',
-		expire='".$_REQUEST["expire"]."',allow_add_domain='".$_REQUEST["allow_add_domain"]."',
+		expire='".$_REQUEST["expire"]."',allow_add_domain='".$_REQUEST["allow_add_domain"]."',max_domain='".$_REQUEST["max_domain"]."',
 		nbrdb='".$_REQUEST["nbrdb"]."',prod_id='".$_REQUEST["heb_prod_id"]."',
 		resseller_flag='".$_REQUEST["resseller_flag"]."',
 		ssh_login_flag='".$_REQUEST["ssh_login_flag"]."',
 		ftp_login_flag='".$_REQUEST["ftp_login_flag"]."',
+		restricted_ftp_path='".$_REQUEST["restricted_ftp_path"]."',
+		allow_dns_and_mx_change='".$_REQUEST["allow_dns_and_mx_change"]."',
+		allow_mailing_list_edit='".$_REQUEST["allow_mailing_list_edit"]."',
+		allow_subdomain_edit='".$_REQUEST["allow_subdomain_edit"]."',
 		pkg_install_flag='".$_REQUEST["pkg_install_flag"]."'
 		WHERE adm_login='$adm_login';";
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" line ".__LINE__." file ".__FILE__." ".mysql_error());
@@ -286,8 +290,8 @@ if(isset($_REQUEST["newadminuser"]) && $_REQUEST["newadminuser"]=="Ok"){
 	if($conf_demo_version == "no"){
 		$oldumask = umask(0);
 		if(!file_exists($newadmin_path)){
-			mkdir("$newadmin_path", 0750);
-			$console .= "mkdir $newadmin_path;<br>";
+			mkdir("$newadmin_path", 0750,1);
+			$console .= "mkdir -p $newadmin_path;<br>";
 		}
 		umask($oldumask);
 	}
