@@ -3,33 +3,34 @@
 $panel_type="admin";
 require_once("../shared/autoSQLconfig.php");
 require_once("authme.php");
+require_once("../shared/vars/lang.php");
 
-$rrd = '/var/lib/dtc/etc/mailqueues.rrd';
+$rrd = $conf_generated_file_path.'/mailqueues.rrd';
 $xpoints = 800;
 $ypoints = 160;
-$vert_label = "Mail queue statistics";
+$vert_label = _("Mail queue statistics");
 
 if( isset($_REQUEST["graph"]) ){
 
 	switch($_REQUEST["graph"]){
 		case "hour":
-			$title = 'Hour graph';
+			$title = _('Hour graph');
 			$steps = 3600;
 			break;
 		case "day":
-			$title = 'Day Graph';
+			$title = _('Day Graph');
 			$steps = 3600*24;
 			break;
 		case "week":
-			$title = 'Week Graph';
+			$title = _('Week Graph');
 			$steps = 3600*24*7;
 			break;
 		case "month":
-			$title = 'Month Graph';
+			$title = _('Month Graph');
 			$steps = 3600*24*31;
 			break;
 		case "year":
-			$title = 'Year Graph';
+			$title = _('Year Graph');
 			$steps = 3600*24*365;
 			break;
 		default:
@@ -39,10 +40,10 @@ if( isset($_REQUEST["graph"]) ){
 	$range = - $steps;
 	$filename = tempnam("/tmp","dtc_mailgraph");
 //	$filename = "/tmp/mail_queue_usage_".$_REQUEST["graph"].".png";
-	$cmd = "rrdtool graph $filename --imgformat PNG --width $xpoints --height $ypoints --start $range --end now --vertical-label '$vert_label' --title '$title' --lazy --interlaced ";
+	$cmd = "rrdtool graph $filename --imgformat PNG --width $xpoints --height $ypoints --start $range --end now --vertical-label \"$vert_label\" --title \"$title\" --lazy --interlaced ";
 	$cmd .= "DEF:active=$rrd:active:AVERAGE DEF:deferred=$rrd:deferred:AVERAGE ";
-	$cmd .= "'LINE2:active#00ff00:Active+incoming+maildrop:' 'GPRINT:active:MAX:Maximum\: %0.0lf' 'GPRINT:active:AVERAGE:Average\: %0.0lf/min\\n' ";
-	$cmd .= "'LINE1:deferred#ff0000:Deferred:' 'GPRINT:deferred:MAX:Maximum\: %0.0lf' 'GPRINT:deferred:AVERAGE:Average\: %0.0lf/min\l' ";
+	$cmd .= "\"LINE2:active#00ff00:" . _("Active+incoming+maildrop") . ":\" \"GPRINT:active:MAX:" . _("Maximum") . "\: %0.0lf\" \"GPRINT:active:AVERAGE:" . _("Average") . "\: %0.0lf/min\\n\" ";
+	$cmd .= "\"LINE1:deferred#ff0000:" . _("Deferred") . ":\" \"GPRINT:deferred:MAX:" . _("Maximum") . "\: %0.0lf\" \"GPRINT:deferred:AVERAGE:" . _("Average") . "\: %0.0lf/min\l\" ";
 	exec($cmd,$output);
 
 	$filesize = filesize($filename);
@@ -66,7 +67,7 @@ if( isset($_REQUEST["graph"]) ){
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd">
 <HTML>
 <HEAD>
-<TITLE>Mail queue statistics for '.$_SERVER["SERVER_NAME"].'</TITLE>
+<TITLE>' . _("Mail queue statistics for") . ' '.$_SERVER["SERVER_NAME"].'</TITLE>
 <style type="text/css">
 body{
 	height:100%;
@@ -82,13 +83,13 @@ h1 {
 </style>
 </HEAD>
 <BODY BGCOLOR="#FFFFFF">
-<H1>Mail queue Statistics for '.$_SERVER["SERVER_NAME"].'</H1>
+<H1>' . _("Mail queue Statistics for") . ' '.$_SERVER["SERVER_NAME"].'</H1>
 <center>
-<IMG BORDER="0" SRC="'.$_SERVER["PHP_SELF"].'?graph=hour" ALT="Hour Mail Queue Graph" width="897" height="253"><br>
-<IMG BORDER="0" SRC="'.$_SERVER["PHP_SELF"].'?graph=day" ALT="Day Mail Queue Graph" width="897" height="253"><br>
-<IMG BORDER="0" SRC="'.$_SERVER["PHP_SELF"].'?graph=week" ALT="Week Mail Queue Graph" width="897" height="253"><br>
-<IMG BORDER="0" SRC="'.$_SERVER["PHP_SELF"].'?graph=month" ALT="Month Mail Queue Graph" width="897" height="253"><br>
-<IMG BORDER="0" SRC="'.$_SERVER["PHP_SELF"].'?graph=year" ALT="Year Mail Queue Graph" width="897" height="253">
+<IMG BORDER="0" SRC="?graph=hour" ALT="' . _("Hour Mail Queue Graph") . '" width="897" height="253"><br>
+<IMG BORDER="0" SRC="?graph=day" ALT="' . _("Day Mail Queue Graph") . '" width="897" height="253"><br>
+<IMG BORDER="0" SRC="?graph=week" ALT="' . _("Week Mail Queue Graph") . '" width="897" height="253"><br>
+<IMG BORDER="0" SRC="?graph=month" ALT="' . _("Month Mail Queue Graph") . '" width="897" height="253"><br>
+<IMG BORDER="0" SRC="?graph=year" ALT="' . _("Year Mail Queue Graph") . '" width="897" height="253">
 </center>
 </body>
 </html>';
