@@ -7,11 +7,17 @@ function register_user($adding_service="no"){
 	global $pro_mysql_vps_server_table;
 	global $conf_webmaster_email_addr;
 	global $conf_selling_conditions_url;
+	global $conf_main_domain;
+
+	global $pro_mysql_custom_fld_table;
 
 	global $conf_message_subject_header;
+	global $conf_send_passwords_in_emails;
 
 	global $secpayconf_currency_letters;
 
+	global $gettext_lang;
+
 	get_secpay_conf();
 
 	// Check if all fields are blank, in wich case don't display error
@@ -34,7 +40,7 @@ function register_user($adding_service="no"){
 	}
 
 	if(isset($_REQUEST["product_id"])){
-		$esc_product_id = addslashes($_REQUEST["product_id"]);
+		$esc_product_id = mysql_real_escape_string($_REQUEST["product_id"]);
 	}
 
 	if(!isRandomNum($esc_product_id)){
@@ -53,7 +59,7 @@ function register_user($adding_service="no"){
 	}
 
 	// Do field format checking and escaping for all fields
-	if( !ereg("^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)\$",$_REQUEST["reqadm_login"]) ){
+	if( !preg_match("/^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)\$/",$_REQUEST["reqadm_login"]) ){
 		$ret["err"] = 2;
 		$ret["mesg"] = _("User login format incorrect. Please use letters and numbers only and from 4 to 16 chars.") ;
 		return $ret;
@@ -74,7 +80,7 @@ function register_user($adding_service="no"){
 		return $ret;
 	}
 
-	if($_REQUEST["domain_name"] == "" || !isTLD($_REQUEST["domain_tld"])){
+	if($_REQUEST["domain_name"] == "" || ( !isTLD($_REQUEST["domain_tld"]) && ($_REQUEST["domain_tld"] != "." . $conf_main_domain))){
 		$domain_tld = "";
 	}else{
 		$domain_tld = $_REQUEST["domain_tld"];
@@ -104,7 +110,7 @@ function register_user($adding_service="no"){
 			$ret["mesg"] = _("VPS location not selected!") ;
 			return $ret;
 		}
-		$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE hostname='".addslashes($_REQUEST["vps_server_hostname"])."';";
+		$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE hostname='".mysql_real_escape_string($_REQUEST["vps_server_hostname"])."';";
 		$r = mysql_query($q)or die("Cannot query $q ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 1){
@@ -125,7 +131,7 @@ function register_user($adding_service="no"){
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
-			$esc_familyname = addslashes($_REQUEST["familyname"]);
+			$esc_familyname = mysql_real_escape_string($_REQUEST["familyname"]);
 		}else{
 			$esc_familyname = $_REQUEST["familyname"];
 		}
@@ -137,7 +143,7 @@ function register_user($adding_service="no"){
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
-			$esc_firstname = addslashes($_REQUEST["firstname"]);
+			$esc_firstname = mysql_real_escape_string($_REQUEST["firstname"]);
 		}else{
 			$esc_firstname = $_REQUEST["firstname"];
 		}
@@ -149,26 +155,26 @@ function register_user($adding_service="no"){
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
-			$esc_phone = addslashes($_REQUEST["phone"]);
+			$esc_phone = mysql_real_escape_string($_REQUEST["phone"]);
 		}else{
 			$esc_phone = $_REQUEST["phone"];
 		}
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_fax = addslashes($_REQUEST["fax"]);
+		$esc_fax = mysql_real_escape_string($_REQUEST["fax"]);
 	}else{
 		$esc_fax = $_REQUEST["fax"];
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_compname = addslashes($_REQUEST["compname"]);
+		$esc_compname = mysql_real_escape_string($_REQUEST["compname"]);
 	}else{
 		$esc_compname = $_REQUEST["compname"];
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_vat_num = addslashes($_REQUEST["vat_num"]);
+		$esc_vat_num = mysql_real_escape_string($_REQUEST["vat_num"]);
 	}else{
 		$esc_vat_num = $_REQUEST["vat_num"];
 	}
@@ -179,20 +185,20 @@ function register_user($adding_service="no"){
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
-			$esc_address1 = addslashes($_REQUEST["address1"]);
+			$esc_address1 = mysql_real_escape_string($_REQUEST["address1"]);
 		}else{
 			$esc_address1 = $_REQUEST["address1"];
 		}
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_address2 = addslashes($_REQUEST["address2"]);
+		$esc_address2 = mysql_real_escape_string($_REQUEST["address2"]);
 	}else{
 		$esc_address2 = $_REQUEST["address2"];
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_address3 = addslashes($_REQUEST["address3"]);
+		$esc_address3 = mysql_real_escape_string($_REQUEST["address3"]);
 	}else{
 		$esc_address3 = $_REQUEST["address3"];
 	}
@@ -203,7 +209,7 @@ function register_user($adding_service="no"){
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
-			$esc_zipcode = addslashes($_REQUEST["zipcode"]);
+			$esc_zipcode = mysql_real_escape_string($_REQUEST["zipcode"]);
 		}else{
 			$esc_zipcode = $_REQUEST["zipcode"];
 		}
@@ -215,25 +221,25 @@ function register_user($adding_service="no"){
 		return $ret;
 	}else{
 		if (!get_magic_quotes_gpc()){
-			$esc_city = addslashes($_REQUEST["city"]);
+			$esc_city = mysql_real_escape_string($_REQUEST["city"]);
 		}else{
 			$esc_city = $_REQUEST["city"];
 		}
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_state = addslashes($_REQUEST["state"]);
+		$esc_state = mysql_real_escape_string($_REQUEST["state"]);
 	}else{
 		$esc_state = $_REQUEST["state"];
 	}
 
 	if (!get_magic_quotes_gpc()){
-		$esc_custom_notes = addslashes($_REQUEST["custom_notes"]);
+		$esc_custom_notes = mysql_real_escape_string($_REQUEST["custom_notes"]);
 	}else{
 		$esc_custom_notes = $_REQUEST["custom_notes"];
 	}
 
-	if(!ereg("^([A-Z])([A-Z])\$",$_REQUEST["country"])){
+	if(!preg_match("/^([A-Z])([A-Z])\$/",$_REQUEST["country"])){
 		$ret["err"] = 2;
 		$ret["mesg"] = _("Country code seems incorrect.") ;
 		return $ret;
@@ -276,7 +282,7 @@ function register_user($adding_service="no"){
 	$vps_mail_add1 = "";
 	if($db_product["heb_type"] == "vps"){
 		if (!get_magic_quotes_gpc()){
-			$esc_vps_os = addslashes($_REQUEST["vps_os"]);
+			$esc_vps_os = mysql_real_escape_string($_REQUEST["vps_os"]);
 		}else{
 			$esc_vps_os = $_REQUEST["vps_os"];
 		}
@@ -289,6 +295,8 @@ function register_user($adding_service="no"){
 	get_secpay_conf();
 	global $secpayconf_maxmind_license_key;
 	global $secpayconf_use_maxmind;
+        global $secpayconf_maxmind_threshold;
+        $maxmind_score = 0;
 	if ($secpayconf_use_maxmind == "yes"){
 		// This has been done in dtc/shared/dtc_lib.php
 		// but could be removed from there... As you like!
@@ -299,7 +307,7 @@ function register_user($adding_service="no"){
 		$hash["city"] = $_REQUEST["city"];
 		$hash["postal"] = $_REQUEST["zipcode"];
 		$hash["country"] = $_REQUEST["country"];
-		$maildomain = split("@",$_REQUEST["email"],2);
+		$maildomain = preg_split("/@/",$_REQUEST["email"],2);
 		$hash["domain"] = $maildomain[1];
 		$hash["custPhone"] = $_REQUEST["phone"];
 		$hash["license_key"] = $secpayconf_maxmind_license_key;
@@ -308,18 +316,47 @@ function register_user($adding_service="no"){
 		$hash["emailMD5"] = md5($_REQUEST["email"]);
 		$hash["usernameMD5"] = md5($_REQUEST["reqadm_login"]);
 		$hash["passwordMD5"] = md5($_REQUEST["reqadm_pass"]);
-		trigger_error("MaxMind input: ".serialize($hash),E_USER_NOTICE);
+		// trigger_error("MaxMind input: ".serialize($hash),E_USER_NOTICE);
 		$ccfs = new CreditCardFraudDetection; $ccfs->isSecure = 1;
 		$ccfs->input($hash); $ccfs->query(); $maxmind_output = $ccfs->output();
-		trigger_error("MaxMind output: ".serialize($maxmind_output),E_USER_NOTICE);
+		// trigger_error("MaxMind output: ".serialize($maxmind_output),E_USER_NOTICE);
+		$maxmind_score = $maxmind_output["riskScore"];
 	} else {
 		$maxmind_output = "";
 	}
 	// end MaxMind
 
+	$q = "SELECT * FROM $pro_mysql_custom_fld_table ORDER BY widgetorder;";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n > 0){
+		$cust_fld_val = "";
+		for($i=0;$i<$n;$i++){
+			$a = mysql_fetch_array($r);
+			if( !isset($_REQUEST[ $a["varname"] ]) || $_REQUEST[ $a["varname"] ] == ""){
+				if($a["mandatory"] == "yes"){
+					$ret["err"] = 2;
+					$ret["mesg"] = _("Mandatory field")." ".$a["varname"]." "._("is empty or incorrect.") ;
+					return $ret;
+				}else{
+					$val = "";
+				}
+			}else{
+				$val = $_REQUEST[ $a["varname"] ];
+			}
+			if($i>0){
+				$cust_fld_val .= "|";
+			}
+			$cust_fld_val .= $a["varname"].":".mysql_real_escape_string($_REQUEST[ $a["varname"] ]);
+		}
+	}else{
+		$cust_fld_val = "";
+	}
+
 	$q = "INSERT INTO $pro_mysql_new_admin_table
 (reqadm_login,
 reqadm_pass,
+customfld,
 domain_name,
 family_name,
 first_name,
@@ -341,10 +378,12 @@ custom_notes,
 shopper_ip,
 date,
 time,
+last_used_lang,
 maxmind_output$vps_add1
 )
 VALUES('".$_REQUEST["reqadm_login"]."',
 '".$_REQUEST["reqadm_pass"]."',
+'$cust_fld_val',
 '".$_REQUEST["domain_name"].$domain_tld."',
 '$esc_familyname',
 '$esc_firstname',
@@ -366,6 +405,7 @@ VALUES('".$_REQUEST["reqadm_login"]."',
 '".$_SERVER["REMOTE_ADDR"]."',
 '".date("Y-m-d")."',
 '".date("H:i:s")."',
+'".$gettext_lang."',
 '".mysql_real_escape_string(serialize($maxmind_output))."'$vps_add2)";
 	$r = mysql_query($q)or die("Cannot query  \"$q\" !!! Line: ".__LINE__." File: ".__FILE__." MySQL said: ".mysql_error());
 	$id = mysql_insert_id();
@@ -384,11 +424,17 @@ VALUES('".$_REQUEST["reqadm_login"]."',
 		$the_prod = $a["name"]." (".$a["price_dollar"]." $secpayconf_currency_letters)";
 	}
 
+	if($conf_send_passwords_in_emails == "yes"){
+		$pass_for_email = $_REQUEST["reqadm_pass"];
+	}else{
+		$pass_for_email = _("- password removed for security reasons -");
+	}
+
 	$mail_content = "
 Somebody tried to register an account. Here is the details of the new user:
 
 login: ".$_REQUEST["reqadm_login"]."
-pass: ".$_REQUEST["reqadm_pass"]."
+pass: ".$pass_for_email."
 domain: ".$_REQUEST["domain_name"].$domain_tld."
 Company name: ".$_REQUEST["compname"]."
 First name: ".$_REQUEST["firstname"]."
@@ -406,6 +452,11 @@ Product id: $the_prod
 Customer note: ".$_REQUEST["custom_notes"]."
 $vps_mail_add1
 ";
+	if ($secpayconf_use_maxmind == "yes")
+	{
+		$mail_content .= "Maxmind Score: $maxmind_score\n";
+		$mail_content .= "Maxmind Output: " . serialize($maxmind_output) . "\n";	
+	}
 
 	$headers = "From: DTC Robot <$conf_webmaster_email_addr>";
 	mail($conf_webmaster_email_addr, "$conf_message_subject_header Somebody tried to register an account", $mail_content, $headers);
@@ -420,6 +471,7 @@ function registration_form(){
 	global $pro_mysql_product_table;
 	global $pro_mysql_vps_ip_table;
 	global $pro_mysql_vps_server_table;
+	global $pro_mysql_custom_fld_table;
 
 	global $conf_selling_conditions_url;
 	global $secpayconf_currency_symbol;
@@ -440,8 +492,19 @@ function registration_form(){
 		$heb_type_condition = " heb_type='".$a["heb_type"]."' ";
 		$heb_type = $a["heb_type"];
 	}else{
-		$heb_type_condition = " 1 ";
-		$heb_type = "all";
+		$heb_types = array('shared', 'ssl', 'vps', 'server');
+		if(isset($_REQUEST["heb_type"]) && preg_match("/[a-zA-Z0-9]/", $_REQUEST["heb_type"])){
+		    if(in_array(strtolower($_REQUEST["heb_type"]),$heb_types)){
+			$heb_type_condition = " heb_type='".strtolower($_REQUEST["heb_type"])."' ";
+			$heb_type = strtolower($_REQUEST["heb_type"]);
+		    }else{
+				$heb_type_condition = " 1 ";
+				$heb_type = "all";
+		    }
+		}else{
+			$heb_type_condition = " 1 ";
+			$heb_type = "all";
+		}
 	}
 
 	$prod_popup = "";
@@ -669,6 +732,73 @@ function registration_form(){
 		$conditions = "";
 	}
 
+	// Manage the output of custom fields.
+	$cust_out = "";
+	$q = "SELECT * FROM $pro_mysql_custom_fld_table ORDER BY widgetorder;";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n > 0){
+		$cust_out .= "<table>";
+		for($i=0;$i<$n;$i++){
+			$a = mysql_fetch_array($r);
+			$cust_out .= "<tr><td style=\"white-space: nowrap;text-align: right;\">";
+			$cust_out .= $a["question"];
+			if($a["mandatory"] == "yes"){
+				$cust_out .= $rek;
+			}
+			$cust_out .= " </td><td>";
+			switch($a["widgettype"]){
+			case "radio":
+				$explo_pop = explode("|",$a["widgetvalues"]);
+				$explo_pop2 = explode("|",$a["widgetdisplay"]);
+				$n_pop = sizeof($explo_pop);
+				for($j=0;$j<$n_pop;$j++){
+					if( isset($_REQUEST[ $a["varname"] ]) && $_REQUEST[ $a["varname"] ] == $explo_pop[$j]){
+						$selected = " checked ";
+					}else{
+						$selected = " ";
+					}
+					$cust_out .= "<input type=\"radio\" name=\"".$a["varname"]."\" value=\"".$explo_pop[$j]."\" $selected > ".$explo_pop2[$j];
+				}
+				break;
+			case "popup":
+				$cust_out .= "<select name=\"".$a["varname"]."\">";
+				$explo_pop = explode("|",$a["widgetvalues"]);
+				$explo_pop2 = explode("|",$a["widgetdisplay"]);
+				$n_pop = sizeof($explo_pop);
+				for($j=0;$j<$n_pop;$j++){
+					if( isset($_REQUEST[ $a["varname"] ]) && $_REQUEST[ $a["varname"] ] == $explo_pop[$j]){
+						$selected = " selected ";
+					}else{
+						$selected = " ";
+					}
+					$cust_out .= "<option value=\"".$explo_pop[$j]."\" $selected >".$explo_pop2[$j]."</option>";
+				}
+				$cust_out .= "</select>";
+				break;
+			case "textarea":
+				if( isset($_REQUEST[ $a["varname"] ])){
+					$val = htmlspecialchars($_REQUEST[ $a["varname"] ]);
+				}else{
+					$val = "";
+				}
+				$cust_out .= "<textarea name=\"".$a["varname"]."\">".$val."</textarea>";
+				break;
+			case "text":
+			default:
+				if( isset($_REQUEST[ $a["varname"] ])){
+					$val = htmlspecialchars($_REQUEST[ $a["varname"] ]);
+				}else{
+					$val = "";
+				}
+				$cust_out .= "<input type=\"text\" name=\"".$a["varname"]."\" value=\"$val\">";
+				break;
+			}
+			$cust_out .= "</td></tr>";
+		}
+		$cust_out .= "</table>";
+	}
+
 	$HTML_admin_edit_data = "<a href=\"/dtc\">". _("Go to login") ."</a>
 <script language=\"javascript\">
 
@@ -734,7 +864,7 @@ function hostingProductChanged(){
 </script><br>
 <br>
 <i>" . _("Feilds with a <font color=\"red\">*</font> are mandatory.") . "</i><br>
-<form name=\"newuser_form\" action=\"".$_SERVER["PHP_SELF"]."\" methode=\"post\">
+<form name=\"newuser_form\" action=\"?\" methode=\"post\">
 <input type=\"hidden\" name=\"action\" value=\"new_user_request\">
 <table>
 <tr>
@@ -749,6 +879,8 @@ function hostingProductChanged(){
 $conditions
 <table border=\"0\">
 <tr>
+	<td colspan=\"3\">$cust_out</td>
+</tr><tr>
 	<td>". _("Leave a message describing any specific requirements you might have for your account:") ."</td>
 	<td><textarea name=\"custom_notes\" cols=\"50\" rows=\"5\">$frm_custom_notes</textarea></td>
 	<td><input type=\"submit\" name=\"Login\" value=\"Register\"></td>
