@@ -8,7 +8,7 @@ $console = "";
 // This file automates the use of a mysql database. It creates connection
 // to it, and fetch all software config from the config table
 
-$dtcshared_path = "../shared";
+$dtcshared_path = dirname(__FILE__);
 $autoconf_configfile = "mysql_config.php";
 
 require("$dtcshared_path/dtc_version.php");
@@ -33,7 +33,7 @@ function createTableIfNotExists(){
 				$fp = fopen("tables/$file","r");
 				$table_create_query = fread($fp,filesize("tables/$file"));
 				fclose($fp);
-				$table_name = ereg_replace (".sql", "", $file);
+				$table_name = preg_replace ("/.sql/", "", $file);
 				$query = "SELECT * FROM $table_name WHERE 1 LIMIT 1;";
 				$result = @mysql_query($query);
 				if($result == false){
@@ -119,7 +119,8 @@ if(!isset($conf_db_version)){
 }
 
 if($conf_demo_version == 'yes'){
-	session_register("demo_version_has_started");
+	@session_start();
+	if(isset($demo_version_has_started)) $_SESSION["demo_version_has_started"]=$demo_version_has_started;
 	if(!isset($_SESSION["demo_version_has_started"]) || $_SESSION["demo_version_has_started"] != "started"){
 		$_SESSION["demo_version_has_started"] = "started";
 		$query = "DELETE FROM admin;";
@@ -139,7 +140,7 @@ if($conf_demo_version == 'yes'){
 
 		die("Welcom to DTC demo version. In demo version, all tables are erased at
 		launch time.<br><br>
-		<a href=\"".$_SERVER["PHP_SELF"]."\">Ok, let's try !</a>
+		<a href=\"?\">Ok, let's try !</a>
 		");
 	}
 }
