@@ -36,47 +36,47 @@ function anotherLanguageSelection(){
 <div align=\"right\">
 <table cellpadding=\"0\" cellspacing=\"4\">
 <tr><td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=fr&rub=$rub\">FR
+	<a href=\"?change_language=fr&rub=$rub\">FR
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/fr.gif\"></a></td>
 <td valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=en&rub=$rub\">
+	<a href=\"?change_language=en&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/en.gif\">&nbsp;EN</a></td>
 <td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=nl&rub=$rub\">NL
+	<a href=\"?change_language=nl&rub=$rub\">NL
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/nl.gif\"></a></td>
 <td valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=ru&rub=$rub\">
+	<a href=\"?change_language=ru&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/ru.gif\">&nbsp;RU</a></td>
 <td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=pt&rub=$rub\">PT
+	<a href=\"?change_language=pt&rub=$rub\">PT
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/pt.gif\"></a></td>
 <td valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=hu&rub=$rub\">
+	<a href=\"?change_language=hu&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/hu.gif\">&nbsp;HU</a></td>
 <td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=pt_BR&rub=$rub\">BR
+	<a href=\"?change_language=pt_BR&rub=$rub\">BR
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/pt_br.gif\"></a></td>
 </tr><tr><td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=es&rub=$rub\">ES
+	<a href=\"?change_language=es&rub=$rub\">ES
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/es.gif\"></a></td>
 <td valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=de&rub=$rub\">
+	<a href=\"?change_language=de&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/de.gif\">&nbsp;DE</a></td>
 <td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=it&rub=$rub\">IT
+	<a href=\"?change_language=it&rub=$rub\">IT
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/it.gif\"></a></td>
 <td valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=zh&rub=$rub\">
+	<a href=\"?change_language=zh&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/zh.gif\">&nbsp;ZH</a></td>
 <td valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=zh_TW&rub=$rub\">
+	<a href=\"?change_language=zh_TW&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/tw.gif\">&nbsp;TW</a></td>
 <td align=\"right\" valign=\"center\" nowrap>
-	<a href=\"".$_SERVER["PHP_SELF"]."?change_language=pl&rub=$rub\">PL
+	<a href=\"?change_language=pl&rub=$rub\">PL
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/pl.png\"></a></td>
-<td><a href=\"".$_SERVER["PHP_SELF"]."?change_language=fi&rub=$rub\">
+<td><a href=\"?change_language=fi&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/fi.gif\">&nbsp;FI</a></td>
-<td><a href=\"".$_SERVER["PHP_SELF"]."?change_language=lv&rub=$rub\">
+<td><a href=\"?change_language=lv&rub=$rub\">
 	<img width=\"16\" height=\"11\" alt=\"*\" border=\"0\" src=\"gfx/language/lv.gif\">&nbsp;LV</a></td>
 </tr></table>
 </div>
@@ -129,6 +129,11 @@ function anotherTopBanner($inside,$drawLanguageSelect="no"){
 	global $adm_email_login;
 	global $panel_type;	
 
+	global $conf_panel_title;
+	global $conf_panel_subtitle;
+	global $conf_panel_logo;
+	global $conf_panel_logolink;
+	
 	global $conf_skin;
 	global $dtcshared_path;
 	
@@ -137,7 +142,7 @@ function anotherTopBanner($inside,$drawLanguageSelect="no"){
 		$zeLanguage = "
 	<td valign=\"top\">&nbsp;</td>
 	<td $nowrap width=\"1\">".anotherLanguageSelection()."</td>";
-		$links = "<a target=\"_blank\" href=\"/dtcdoc/\">". _("Documentation") ."</a> <a target=\"_blank\" href=\"/phpmyadmin/\">PhpMyAdmin</a>";
+		$links = "<a target=\"_blank\" href=\"/dtcdoc/\">". _("Documentation") ."</a> <a target=\"_blank\" href=\"/phpmyadmin/\">". _("PhpMyAdmin") . "</a>";
 	}else{
 		$links = "";
 		$zeLanguage = "";
@@ -159,11 +164,39 @@ function anotherTopBanner($inside,$drawLanguageSelect="no"){
 		$fp = fopen($pagetop_filename,"r");
 		$inside = fread($fp,filesize($pagetop_filename));
 		fclose($fp);
-		$inside = str_replace("__DTC_SUBTITLE__", _("Take control of your domain name") ,$inside);
+		// Enable possible customization of the title and logos
+		if($conf_panel_title == "default"){
+			$inside = str_replace("__DTC_TITLE__", _("Domain Technologie Control") ,$inside);
+		}else{
+			$inside = str_replace("__DTC_TITLE__", $conf_panel_title ,$inside);
+		}
+		if($conf_panel_subtitle == "default"){
+			$inside = str_replace("__DTC_SUBTITLE__", _("Take control of your domain name") ,$inside);
+		}else{
+			$inside = str_replace("__DTC_SUBTITLE__", $conf_panel_subtitle ,$inside);
+		}
+		if($conf_panel_logo == "default"){
+			// Prefer a default logo in PNG format
+			$panel_logo = "gfx/skin/".$conf_skin."/gfx/logo_dtc.png";
+			if (!file_exists($dtcshared_path."/".$panel_logo)) {
+				// fall-back to GIF format
+				$panel_logo = "gfx/skin/".$conf_skin."/gfx/logo_dtc.gif";
+			}
+			$inside = str_replace("__DTC_LOGO__", $panel_logo ,$inside);
+		}else{
+			$inside = str_replace("__DTC_LOGO__", "gfx/skin/".$conf_skin."/gfx/". $conf_panel_logo ,$inside);
+		}
+		if($conf_panel_logolink == "default"){
+			$inside = str_replace("__DTC_LOGOLINK__", "http://www.gplhost.com/software-dtc.html", $inside);
+		}else{
+			$inside = str_replace("__DTC_LOGOLINK__", $conf_panel_logolink, $inside);
+		}
 		$inside = str_replace("__DTC_LANGUAGES_LINKS__",$zeLanguage,$inside);
 		$inside = str_replace("__DTC_VERSION__","V$conf_dtc_version R$conf_dtc_release - $conf_unix_type",$inside);
 		$inside = str_replace("__DTC_LINK__",$links,$inside);
 		$inside = str_replace("__AUTH_USER__",_("Logged as:") . " " . $display_user,$inside);
+		$inside = str_replace("__DOCUMENTATION__",_("Documentation"),$inside);
+		$inside = str_replace("__PHPMYADMIN__",_("PhpMyAdmin"),$inside);
 		$inside .= "<script language=\"JavaScript\" type=\"text/javascript\" src=\"gfx/wz_tooltip.js\"></script>";
 		return $inside;
 	}else{
