@@ -175,8 +175,9 @@ function dtcDatagrid($dsc){
 	$nbr_forwards = sizeof($dsc["forward"]);
 	$keys_fw = array_keys($dsc["forward"]);
 
+	// Process the "forward" parameter of the grid widget, so that $rub and $sousrub and so on are forwarded
 	$fw = "";
-	$fw_link = $_SERVER["PHP_SELF"]."?";
+	$fw_link = "?";
 	for($i=0;$i<$nbr_forwards;$i++){
 		if($dsc["forward"][$i] == "adm_pass"){
 			$fw .= "<input type=\"hidden\" name=\"".$dsc["forward"][$i]."\" value=\"".$adm_pass."\">";
@@ -193,6 +194,7 @@ function dtcDatagrid($dsc){
 		}
 	}
 
+	// Get a list of fields in sql and build a "field1, field2" string
 	$nbr_fld = sizeof($dsc["cols"]);
 	$flds = "";
 	$keys = array_keys($dsc["cols"]);
@@ -203,6 +205,7 @@ function dtcDatagrid($dsc){
 		$flds .= $keys[$i];
 	}
 
+	// Start of performing actions (new, update, delete)
 	$action_error_txt = "";
 
 	if(isset($_REQUEST["action"])){
@@ -243,6 +246,7 @@ function dtcDatagrid($dsc){
 					}
 					$qflds .= $keys[$i];
 					$vals .= "'".$dsc["cols"][ $keys[$i] ]["values"][$index_val]."'";
+					$added_one = "yes";
 					break;
 				default:
 					break;
@@ -402,7 +406,7 @@ function dtcDatagrid($dsc){
 	$n = mysql_num_rows($r);
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
-		$out .= "<tr><form name=\"".$dsc["action"]."_edit_frm_$i\" action=\"".$_SERVER["PHP_SELF"]."\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_edit\">";
+		$out .= "<tr><form name=\"".$dsc["action"]."_edit_frm_$i\" action=\"?\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_edit\">";
 		if(($i % 2) == 1 && isset($gfx_form_entry_label_background)){
 			$tdclass = "dtcDatagrid_table_flds_alt";
 			$input_class = "dtcDatagrid_input_alt_color";
@@ -410,111 +414,200 @@ function dtcDatagrid($dsc){
 			$tdclass = "dtcDatagrid_table_flds";
 			$input_class = "dtcDatagrid_input_color";
 		}
+		// Get the primary key of the table raw before anything else.
 		for($j=0;$j<$nbr_fld;$j++){
-			$the_fld = $dsc["cols"][ $keys[$j] ];
-			switch($the_fld["type"]){
+			if($dsc["cols"][ $keys[$j] ]["type"] == "id"){
+				$id = $a[ $keys[$j] ];
+			}
+		}
+		for($j=0;$j<$nbr_fld;$j++){
+			$the_name = $keys[$j];
+			$the_fld = $dsc["cols"][$the_name];
+			if($the_fld["type"] ==  "double_forkey"){
+				unset($dbl_forkey_link);
+				$fk_found = 0;
+				$the_type = $the_fld["forkey_type"];
+				// Query the 1st indirection table
+				$qrent = "SELECT ".$the_fld["searchkey_1st_ind"]." FROM ".$the_fld["table_1st_ind"]." WHERE ".$the_fld["fldwhere_1st_ind"]."='".$a[ $the_fld["fldwhere_1st_ind_orig"] ]."';";
+				$rrent = mysql_query($qrent)or die("Cannot query $qrent in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
+				$nrent = mysql_num_rows($rrent);
+				if($nrent == 1){
+					$arent = mysql_fetch_array($rrent);
+					$cid = $arent[ $the_fld["searchkey_1st_ind"] ];
+					$qcli = "SELECT ".$the_fld["display_flds_2nd_ind"]." FROM ".$the_fld["table_2nd_ind"]." WHERE ".$the_fld["fldwhere_1st_ind_orig"]."='$cid';";
+					$rcli = mysql_query($qcli)or die("Cannot query $qcli in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
+					$ncli = mysql_num_rows($rrent);
+					if($ncli == 1){
+						$acli = mysql_fetch_array($rcli);
+						$db_value = $acli[ $the_fld["display_flds_2nd_ind"] ];
+						$fk_found = 1;
+						$fk_link_more = $cid;
+						$dbl_forkey_link = $the_fld["link_start"].$cid;
+					}else{
+						$db_value = "Not found";
+					}
+				}else{
+					$qnrent = "SELECT ".$the_fld["display_flds_back"]." FROM ".$the_fld["table_back"]." WHERE ".$the_fld["fldwhere_back"]."='".$a[ $the_fld["fldwhere_back_orig"] ]."';";
+					$rnrent = mysql_query($qnrent)or die("Cannot query $qnrent in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
+					$nnrent = mysql_num_rows($rnrent);
+					if($nnrent == 1){
+						$ancli = mysql_fetch_array($rnrent);
+						$db_value = $ancli[ $the_fld["display_flds_back"] ];
+						$fk_found = 1;
+						$dbl_forkey_link = $the_fld["link_start"].$a[ $the_fld["fldwhere_back_orig"] ];
+					}else{
+						$db_value = "Not found";
+					}
+				}
+			}else if($the_fld["type"] == "forkey"){
+				$fk_found = 0;
+				$the_type = $the_fld["forkey_type"];
+				$forkey_table = $the_fld["table"];
+				$forkey_other_table_fld = $the_fld["other_table_fld"];
+				$forkey_other_table_key = $the_fld["other_table_key"];
+				$forkey_this_table_field = $the_fld["this_table_field"];
+				$qfk = "SELECT $forkey_other_table_fld AS dtcfkfld FROM $forkey_table WHERE $forkey_other_table_key='". $a[ $forkey_this_table_field ] ."';";
+				$rfk = mysql_query($qfk)or die("Cannot query $qfk in ".__FILE__." line ".__LINE__." sql said: ".mysql_error()." when getting foreign key $forkey_fld value in table ".$the_fld["table"]);
+				$nfk = mysql_num_rows($rfk);
+				if($nfk == 1){
+					// afk means array foreign key, not away from keyboard... :)
+					$afk = mysql_fetch_array($rfk);
+					$db_value = $afk["dtcfkfld"];
+					$fk_found = 1;
+				}else{
+					if( isset($the_fld["bk_table"]) && isset($the_fld["bk_other_table_fld"]) && isset($the_fld["bk_other_table_key"]) && isset($the_fld["bk_this_table_field"]) ){
+						$forkey_table = $the_fld["bk_table"];
+						$forkey_other_table_fld = $the_fld["bk_other_table_fld"];
+						$forkey_other_table_key = $the_fld["bk_other_table_key"];
+						$forkey_this_table_field = $the_fld["bk_this_table_field"];
+						$qfk = "SELECT $forkey_other_table_fld AS dtcfkfld FROM $forkey_table WHERE $forkey_other_table_key='". $a[ $forkey_this_table_field ] ."';";
+						$rfk = mysql_query($qfk)or die("Cannot query $qfk in ".__FILE__." line ".__LINE__." sql said: ".mysql_error()." when getting foreign key $forkey_fld value in table ".$the_fld["table"]);
+						$nfk = mysql_num_rows($rfk);
+					}else{
+						$nfk = 0;
+					}
+					if($nfk == 1){
+						$afk = mysql_fetch_array($rfk);
+						$db_value = $afk["dtcfkfld"];
+						$fk_found = 2;
+					}else{
+						$db_value = "Foreign key N/A";
+					}
+				}
+			}else{
+				$the_type = $the_fld["type"];
+				if($the_type != "hyperlink"){
+					$db_value = $a[ $the_name ];
+				}
+			}
+			switch($the_type){
 			case "text":
-				if( isset($dsc["cols"][ $keys[$j] ]["size"])){
-					$size = " size=\"".$dsc["cols"][ $keys[$j] ]["size"]."\" ";
+				if( isset($the_fld["size"])){
+					$size = " size=\"".$the_fld["size"]."\" ";
 				}else{
 					$size = "";
 				}
 				$out .= "<td class=\"$tdclass\">";
-				$out .= "<input class=\"$input_class\" type=\"text\" $size name=\"".$keys[$j]."\" value=\"".$a[ $keys[$j] ]."\">";
+				$out .= "<input class=\"$input_class\" type=\"text\" $size name=\"".$the_name."\" value=\"".$db_value."\">";
 				$out .= "</td>";
 				break;
 			case "password":
-				if( isset($dsc["cols"][ $keys[$j] ]["size"])){
-					$size = " size=\"".$dsc["cols"][ $keys[$j] ]["size"]."\" ";
+				if( isset($the_fld["size"])){
+					$size = " size=\"".$the_fld["size"]."\" ";
 				}else{
 					$size = "";
 				}
 				$out .= "<td class=\"$tdclass\" style=\"white-space:nowrap;\">";
-				$genpass = autoGeneratePassButton($dsc["action"]."_edit_frm_$i",$keys[$j]);
-				$out .= "<input class=\"$input_class\" type=\"password\" $size name=\"".$keys[$j]."\" value=\"".$a[ $keys[$j] ]."\">$genpass";
+				$genpass = autoGeneratePassButton($dsc["action"]."_edit_frm_$i",$the_name);
+				$out .= "<input class=\"$input_class\" autocomplete=\"off\" type=\"password\" $size name=\"".$the_name."\" value=\"".$db_value."\">$genpass";
 				$out .= "</td>";
 				break;
 			case "radio":
 				$out .= "<td class=\"$tdclass\">";
-				$nbr_choices = sizeof( $dsc["cols"][ $keys[$j] ]["values"] );
+				$nbr_choices = sizeof( $the_fld["values"] );
 				for($x=0;$x<$nbr_choices;$x++){
-					if($a[ $keys[$j] ] == $dsc["cols"][ $keys[$j] ]["values"][$x]){
+					if($db_value == $the_fld["values"][$x]){
 						$selected = " checked ";
 					}else{
 						$selected = "";
 					}
-					$out .= " <input class=\"$input_class\" type=\"radio\" name=\"".$keys[$j]."\" value=\"".$dsc["cols"][ $keys[$j] ]["values"][$x]."\" $selected> ";
-					if( isset($dsc["cols"][ $keys[$j] ]["display_replace"][$x]) ){
-						$out .= $dsc["cols"][ $keys[$j] ]["display_replace"][$x];
+					$out .= " <input class=\"$input_class\" type=\"radio\" name=\"".$the_name."\" value=\"".$the_fld["values"][$x]."\" $selected> ";
+					if( isset($the_fld["display_replace"][$x]) ){
+						$out .= $the_fld["display_replace"][$x];
 					}else{
-						$out .= $dsc["cols"][ $keys[$j] ]["values"][$x];
+						$out .= $the_fld["values"][$x];
 					}
 				}
 				$out .= "</td>";
 				break;
 			case "checkbox":
 				$out .= "<td class=\"$tdclass\">";
-				if($a[ $keys[$j] ] == $dsc["cols"][ $keys[$j] ]["values"][0]){
+				if($db_value == $the_fld["values"][0]){
 					$selected = " checked ";
 				}else{
 					$selected = "";
 				}
-				$out .= " <input class=\"$input_class\" type=\"checkbox\" name=\"".$keys[$j]."\" value=\"".$dsc["cols"][ $keys[$j] ]["values"][0]."\" $selected> ";
+				$out .= " <input class=\"$input_class\" type=\"checkbox\" name=\"".$the_name."\" value=\"".$the_fld["values"][0]."\" $selected> ";
 				$out .= "</td>";
 				break;
 			case "textarea":
-				if( isset($dsc["cols"][ $keys[$j] ]["cols"])){
-					$cols = " cols=\"".$dsc["cols"][ $keys[$j] ]["cols"]."\" ";
+				if( isset($the_fld["cols"])){
+					$cols = " cols=\"".$the_fld["cols"]."\" ";
 				}else{
 					$cols = "";
 				}
-				if( isset($dsc["cols"][ $keys[$j] ]["rows"])){
-					$rows = " cols=\"".$dsc["cols"][ $keys[$j] ]["rows"]."\" ";
+				if( isset($the_fld["rows"])){
+					$rows = " rows=\"".$the_fld["rows"]."\" ";
 				}else{
 					$rows = "";
 				}
 				$out .= "<td class=\"$tdclass\">";
-				$out .= "<textarea $cols $rows name=\"".$keys[$j]."\">".$a[ $keys[$j] ]."</textarea>";
+				$out .= "<textarea $cols $rows name=\"".$the_name."\">".$db_value."</textarea>";
 				$out .= "</td>";
 				break;
 			case "hyperlink":
 				$out .= "<td class=\"$tdclass\">";
-				$out .= "<a href=\"$fw_link&".$keys[$j]."=".$id."\">";
-				$out .= $dsc["cols"][ $keys[$j] ]["text"]."</a>";
+				$out .= "<a href=\"$fw_link&".$the_name."=".$id."\">";
+				$out .= $the_fld["text"]."</a>";
 				$out .= "</td>";
 				break;
 			case "info":
 				$out .= "<td class=\"$tdclass\">";
-				$out .= $a[ $keys[$j] ];
+				if($the_fld["type"] == "forkey" && isset($the_fld["link"]) && $fk_found == 1){
+					$out .= "<a href=\"".$the_fld["link"]. $a[ $the_name ] ."\" style=\"white-space:nowrap;\">".$db_value."</a>";
+				}else if($the_fld["type"] == "double_forkey" && $fk_found == 1){
+					$out .= "<a href=\"".$dbl_forkey_link."\" target=\"_blank\" style=\"white-space:nowrap;\">".$db_value."</a>";
+				}else{
+					$out .= "<span style=\"white-space:nowrap;\">".$db_value."</span>";
+				}
 				$out .= "</td>";
 				break;
 			case "popup":
 				$out .= "<td class=\"$tdclass\">";
-				$out .= "<select class=\"$input_class\" name=\"".$keys[$j]."\">";
-				$nbr_values = sizeof($dsc["cols"][ $keys[$j] ]["values"]);
+				$out .= "<select class=\"$input_class\" name=\"".$the_name."\">";
+				$nbr_values = sizeof($the_fld["values"]);
 				for($x=0;$x<$nbr_values;$x++){
-					if($dsc["cols"][ $keys[$j] ]["values"][$x] == $a[ $keys[$j] ]){
+					if($the_fld["values"][$x] == $db_value){
 						$selected = " selected ";
 					}else{
 						$selected = "";
 					}
-					if( isset($dsc["cols"][ $keys[$j] ]["display_replace"][$x]) ){
-						$display_value_popup = $dsc["cols"][ $keys[$j] ]["display_replace"][$x];
+					if( isset($the_fld["display_replace"][$x]) ){
+						$display_value_popup = $the_fld["display_replace"][$x];
 					}else{
-						$display_value_popup = $dsc["cols"][ $keys[$j] ]["values"][$x];
+						$display_value_popup = $the_fld["values"][$x];
 					}
-					$out .= "<option value=\"".$dsc["cols"][ $keys[$j] ]["values"][$x]."\" $selected>".$display_value_popup."</option>";
+					$out .= "<option value=\"".$the_fld["values"][$x]."\" $selected>".$display_value_popup."</option>";
 				}
 				$out .= "</select>";
 				$out .= "</td>";
 				break;
 			case "id":
-				$id = $a[ $keys[$j] ];
-				$id_hidden = "<input type=\"hidden\" name=\"".$keys[$j]."\" value=\"".$a[ $keys[$j] ]."\">";
-				if($dsc["cols"][ $keys[$j] ]["display"] == "yes"){
+				$id_hidden = "<input type=\"hidden\" name=\"".$the_name."\" value=\"".$db_value."\">";
+				if($dsc["cols"][ $the_name ]["display"] == "yes"){
 					$out .= "<td class=\"$tdclass\">";
 					$out .= $id_hidden;
-					$out .= $a[ $keys[$j] ];
+					$out .= $db_value;
 					$out .= "</td>";
 				}else{
 					$out .= $id_hidden;
@@ -526,7 +619,7 @@ function dtcDatagrid($dsc){
 		if(isset($dsc["skip_deletion"]) && $dsc["skip_deletion"] == "yes"){
 			$out .= "<td class=\"$tdclass\">&nbsp;</td></tr>";
 		}else{
-			$out .= "<td class=\"$tdclass\"><form action=\"".$_SERVER["PHP_SELF"]."\">$fw$id_hidden
+			$out .= "<td class=\"$tdclass\"><form action=\"?\">$fw$id_hidden
 			<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_delete\">".dtcDeleteButton()."</form></td>";
 			$out .= "</form></tr>";
 		}
@@ -540,7 +633,7 @@ function dtcDatagrid($dsc){
 			$input_class = "dtcDatagrid_input_color";
 		}
 		// Write the NEW stuff...
-		$out .= "<tr><form name=\"".$dsc["action"]."_new_frm\" id=\"".$dsc["action"]."_new_frm\" action=\"".$_SERVER["PHP_SELF"]."\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_new\">";
+		$out .= "<tr><form name=\"".$dsc["action"]."_new_frm\" id=\"".$dsc["action"]."_new_frm\" action=\"?\">$fw<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_new\">";
 		for($j=0;$j<$nbr_fld;$j++){
 			$the_fld = $dsc["cols"][ $keys[$j] ];
 			switch($the_fld["type"]){
@@ -562,7 +655,7 @@ function dtcDatagrid($dsc){
 				}
 				$out .= "<td class=\"$tdclass\" style=\"white-space:nowrap;\">";
 				$genpass = autoGeneratePassButton($dsc["action"]."_new_frm",$keys[$j]);
-				$out .= "<input class=\"$input_class\" type=\"password\" $size name=\"".$keys[$j]."\" value=\"\">$genpass";
+				$out .= "<input class=\"$input_class\" autocomplete=\"off\" type=\"password\" $size name=\"".$keys[$j]."\" value=\"\">$genpass";
 				$out .= "</td>";
 				break;
 			case "radio":
@@ -695,7 +788,7 @@ function dtcListItemsEdit($dsc){
 	$keys_fw = array_keys($dsc["forward"]);
 
 	$fw = "";
-	$fw_link = $_SERVER["PHP_SELF"]."?";
+	$fw_link = "?";
 	for($i=0;$i<$nbr_forwards;$i++){
 		if($dsc["forward"][$i] == "adm_pass"){
 			$fw .= "<input type=\"hidden\" name=\"".$dsc["forward"][$i]."\" value=\"".$adm_pass."\">";
@@ -782,6 +875,21 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "list_of_ip":
+					if( isset($dsc["cols"][ $keys[$i] ]["can_be_empty"]) &&
+						$dsc["cols"][ $keys[$i] ]["can_be_empty"] == "yes" &&
+						$_REQUEST[ $keys[$i] ] == ""){
+						break;
+					}
+					$mylist_of_ip = explode("|",$_REQUEST[ $keys[$i] ]);
+					$number_of_ip = sizeof($mylist_of_ip);
+					for($g=0;$g<$number_of_ip;$g++){
+						if( !isIP($mylist_of_ip[$g]) ){
+							$commit_flag = "no";
+							$commit_err .= $keys[$i].": invalid IP list<br>";
+						}
+					}
+					break;
 				case "subdomain_or_ip":
 					if( !checkSubdomainFormat($_REQUEST[ $keys[$i] ]) && !isIP($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -792,6 +900,20 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "ip6":
+					if( !isIP6($_REQUEST[ $keys[$i] ]) ){
+						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
+									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
+									|| $_REQUEST[ $keys[$i] ] != ""){
+							if ( !isset($dsc["cols"][ $keys[$i] ]["empty_makes_default"])
+										|| $dsc["cols"][ $keys[$i] ]["empty_makes_default"] != "yes"
+										|| $_REQUEST[ $keys[$i] ] != "default"){
+								$commit_flag = "no";
+								$commit_err .= $keys[$i].": not an IPv6 address<br>";
+							}
+						}
+					}
+					break;
 				case "ip_addr":
 					if( !isIP($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -835,7 +957,7 @@ function dtcListItemsEdit($dsc){
 				case "mail_alias_group":
 					$mail_alias_group_raw = trim($_REQUEST[ $keys[$i] ],"\r\n");
 					$mail_alias_nocr = str_replace("\r", "", $mail_alias_group_raw);
-					$mail_alias_array = split("\n", $mail_alias_nocr);
+					$mail_alias_array = preg_split("/\n/", $mail_alias_nocr);
 					for($x=0;$x<count($mail_alias_array);$x++)
 					{
 						if ( ! isValidEmail($mail_alias_array[$x]) )
@@ -946,9 +1068,9 @@ function dtcListItemsEdit($dsc){
 					$values .= "'default'";
 				}else{
 					if(isset($dsc["cols"][ $keys[$i] ]["happen_domain"])){
-						$values .= "'".addslashes($_REQUEST[ $keys[$i] ]).$dsc["cols"][ $keys[$i] ]["happen_domain"]."'";
+						$values .= "'".mysql_real_escape_string($_REQUEST[ $keys[$i] ]).$dsc["cols"][ $keys[$i] ]["happen_domain"]."'";
 					}else{
-						$values .= "'".addslashes($_REQUEST[ $keys[$i] ])."'";
+						$values .= "'".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."'";
 					}
 					// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
 					if(isset($dsc["cols"][ $keys[$i] ]["cryptfield"])){
@@ -975,9 +1097,9 @@ function dtcListItemsEdit($dsc){
 					$values .= "'default'";
 				}else{
 					if(isset($dsc["cols"][ $keys[$i] ]["happen_domain"])){
-						$values .= "'".addslashes($_REQUEST[ $keys[$i] ]).$dsc["cols"][ $keys[$i] ]["happen_domain"]."'";
+						$values .= "'".mysql_real_escape_string($_REQUEST[ $keys[$i] ]).$dsc["cols"][ $keys[$i] ]["happen_domain"]."'";
 					}else{
-						$values .= "'".addslashes($_REQUEST[ $keys[$i] ])."'";
+						$values .= "'".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."'";
 					}
 				}
 				$added_one = "yes";
@@ -1002,7 +1124,7 @@ function dtcListItemsEdit($dsc){
 					$values .= ",";
 				}
 				$fld_names .= $keys[$i];
-				$values .= "'".addslashes($_REQUEST[ $keys[$i] ])."'";
+				$values .= "'".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."'";
 				$added_one = "yes";
 				break;
 			}
@@ -1060,6 +1182,21 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "list_of_ip":
+					if( isset($dsc["cols"][ $keys[$i] ]["can_be_empty"]) &&
+						$dsc["cols"][ $keys[$i] ]["can_be_empty"] == "yes" &&
+						$_REQUEST[ $keys[$i] ] == ""){
+						break;
+					}
+					$mylist_of_ip = explode("|",$_REQUEST[ $keys[$i] ]);
+					$number_of_ip = sizeof($mylist_of_ip);
+					for($g=0;$g<$number_of_ip;$g++){
+						if( !isIP($mylist_of_ip[$g]) ){
+							$commit_flag = "no";
+							$commit_err .= $keys[$i].": invalid IP list<br>";
+						}
+					}
+					break;
 				case "subdomain_or_ip":
 					if( !checkSubdomainFormat($_REQUEST[ $keys[$i] ]) && !isIP($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -1070,6 +1207,20 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "ip6":
+					if( !isIP6($_REQUEST[ $keys[$i] ]) ){
+						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
+									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
+									|| $_REQUEST[ $keys[$i] ] != ""){
+							if ( !isset($dsc["cols"][ $keys[$i] ]["empty_makes_default"])
+										|| $dsc["cols"][ $keys[$i] ]["empty_makes_default"] != "yes"
+										|| $_REQUEST[ $keys[$i] ] != "default"){
+								$commit_flag = "no";
+								$commit_err .= $keys[$i].": not an IPv6 address<br>";
+							}
+						}
+					}
+					break;
 				case "ip_addr":
 					if( !isIP($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -1113,7 +1264,7 @@ function dtcListItemsEdit($dsc){
 				case "mail_alias_group":
 					$mail_alias_group_raw = trim($_REQUEST[ $keys[$i] ],"\r\n");
 					$mail_alias_nocr = str_replace("\r", "", $mail_alias_group_raw);
-					$mail_alias_array = split("\n", $mail_alias_nocr);
+					$mail_alias_array = preg_split("/\n/", $mail_alias_nocr);
 					for($x=0;$x<count($mail_alias_array);$x++)
 					{
 						if ( ! isValidEmail($mail_alias_array[$x]) )
@@ -1181,7 +1332,7 @@ function dtcListItemsEdit($dsc){
 			switch($dsc["cols"][ $keys[$i] ]["type"]){
 			case "id":
 				$id_fldname = $keys[$i];
-				$id_fld_value = addslashes($_REQUEST[ $keys[$i] ]);
+				$id_fld_value = mysql_real_escape_string($_REQUEST[ $keys[$i] ]);
 				break;
 			case "readonly":
 				break;
@@ -1202,7 +1353,7 @@ function dtcListItemsEdit($dsc){
 					}else if( isset($dsc["cols"][ $keys[$i] ]["empty_makes_default"]) && $dsc["cols"][ $keys[$i] ]["empty_makes_default"] == "yes" && $_REQUEST[ $keys[$i] ] == ""){
 						$reqs .= $keys[$i]."='default'";
 					}else{
-						$reqs .= $keys[$i]."='".addslashes($_REQUEST[ $keys[$i] ]).$happen."'";
+						$reqs .= $keys[$i]."='".mysql_real_escape_string($_REQUEST[ $keys[$i] ]).$happen."'";
 						// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
 						if(isset($dsc["cols"][ $keys[$i] ]["cryptfield"])){
 							if($added_one == "yes"){
@@ -1219,7 +1370,7 @@ function dtcListItemsEdit($dsc){
 				if($added_one == "yes"){
 					$reqs .= ",";
 				}
-				$reqs .= $keys[$i]."='".addslashes($_REQUEST[ $keys[$i] ])."'";
+				$reqs .= $keys[$i]."='".mysql_real_escape_string($_REQUEST[ $keys[$i] ])."'";
 				$added_one = "yes";
 				break;
 			case "checkbox":
@@ -1252,7 +1403,7 @@ function dtcListItemsEdit($dsc){
 		for($i=0;$i<$nbr_fld;$i++){
 			if($dsc["cols"][ $keys[$i] ]["type"] == "id"){
 				$id_fldname = $keys[$i];
-				$id_fld_value = addslashes($_REQUEST[ $keys[$i] ]);
+				$id_fld_value = mysql_real_escape_string($_REQUEST[ $keys[$i] ]);
 			}
 		}
 		if( isset($id_fldname) && isset($id_fld_value) ){
@@ -1301,9 +1452,9 @@ function dtcListItemsEdit($dsc){
 		$out .= $dsc["new_item_link"]."<br><br>";
 		$out .= "<h3>".$dsc["new_item_title"]."</h3><br>";
 		if(isset($dsc["max_item"]) && $current_num_items >= $dsc["max_item"]){
-			$out .= "<font color=\"red\">Maximum number reached!</font><br>";
+			$out .= "<font color=\"red\">". _("Maximum number reached") ."!</font><br>";
 		}else{
-			$out .= "<form name=\"".$dsc["action"]."_new_item_frm\" action=\"".$_SERVER["PHP_SELF"]."\">$fw
+			$out .= "<form name=\"".$dsc["action"]."_new_item_frm\" action=\"?\">$fw
 				<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_new_item\">".dtcFormTableAttrs();
 			for($i=0;$i<$nbr_fld;$i++){
 				if( isset($dsc["cols"][ $keys[$i] ]["help"])){
@@ -1317,7 +1468,7 @@ function dtcListItemsEdit($dsc){
 					break;
 				case "password":
 					$genpass = autoGeneratePassButton($dsc["action"]."_new_item_frm",$keys[$i]);
-					$ctrl = "<input type=\"password\" name=\"".$keys[$i]."\" value=\"\">$genpass";
+					$ctrl = "<input type=\"password\" autocomplete=\"off\" name=\"".$keys[$i]."\" value=\"\">$genpass";
 					$out .= dtcFormLineDraw($dsc["cols"][ $keys[$i] ]["legend"],$ctrl,$i%2,$help);
 					break;
 				case "text":
@@ -1432,12 +1583,12 @@ function dtcListItemsEdit($dsc){
 	}else{
 		$out .= "<a href=\"$fw_link&subaction=".$dsc["action"]."_new_item\">".$dsc["new_item_link"]."</a><br><br>";
 		$out .= "<h3>".$dsc["edit_item_title"]."</h3><br>";
-		$q = "SELECT * FROM ".$dsc["table_name"]." $where AND ".$dsc["id_fld"]."='".addslashes($_REQUEST["item"])."';";
+		$q = "SELECT * FROM ".$dsc["table_name"]." $where AND ".$dsc["id_fld"]."='".mysql_real_escape_string($_REQUEST["item"])."';";
 		$r = mysql_query($q)or die("Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n == 1){
 			$a = mysql_fetch_array($r);
-			$out .= "<form name=\"".$dsc["action"]."_save_item_frm\" action=\"".$_SERVER["PHP_SELF"]."\">$fw";
+			$out .= "<form name=\"".$dsc["action"]."_save_item_frm\" action=\"?\">$fw";
 			$out .= "<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_save_item\">";
 			$out .= "<input type=\"hidden\" name=\"subaction\" value=\"".$dsc["action"]."_edit_item\">";
 			$out .= "<input type=\"hidden\" name=\"item\" value=\"".$a[ $dsc["id_fld"] ]."\">";
@@ -1482,7 +1633,7 @@ function dtcListItemsEdit($dsc){
 					}else{
 						$size = "";
 					}
-					if( isset($dsc["cols"][ $keys[$j] ]["happen_domain"]) && ereg($dsc["cols"][ $keys[$j] ]["happen_domain"]."$",$a[ $keys[$j] ])){
+					if( isset($dsc["cols"][ $keys[$j] ]["happen_domain"]) && preg_match("/".$dsc["cols"][ $keys[$j] ]["happen_domain"]."\$/",$a[ $keys[$j] ])){
 						$input_disp_value = substr($a[ $keys[$j] ],0,strlen($a[ $keys[$j] ]) - strlen($dsc["cols"][ $keys[$j] ]["happen_domain"]));
 						$happen = $dsc["cols"][ $keys[$j] ]["happen_domain"];
 					}else{
@@ -1566,7 +1717,7 @@ function dtcListItemsEdit($dsc){
 					break;
 				}
 			}
-			$delete_button = "<form action=\"".$_SERVER["PHP_SELF"]."\">$fw
+			$delete_button = "<form action=\"?\">$fw
 			<input type=\"hidden\" name=\"action\" value=\"".$dsc["action"]."_delete_item"."\">
 			<input type=\"hidden\" name=\"$id_fldname\" value=\"$id_fld_value\">
 			".dtcDeleteButton()."</form>";
