@@ -7,6 +7,9 @@ function drawAdminTools_AddDomain($admin){
 
 	global $registration_added_price;
 
+	global $conf_addr_primary_dns;
+	global $conf_addr_secondary_dns;
+
 	global $form_enter_dns_infos;
 	global $form_enter_domain_name;
 	global $whois_forwareded_params;
@@ -18,6 +21,8 @@ function drawAdminTools_AddDomain($admin){
 	global $pro_mysql_client_table;
 	global $pro_mysql_product_table;
 
+	global $registry_api_modules;
+
 	global $secpayconf_currency_letters;
 	global $pro_mysql_handle_table;
 
@@ -26,7 +31,7 @@ function drawAdminTools_AddDomain($admin){
 	$out = "";
 
 $form_start = "
-<form action=\"".$_SERVER["PHP_SELF"]."\">
+<form action=\"?\">
 <input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
@@ -71,8 +76,8 @@ $form_start = "
 <input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
 <input type=\"hidden\" name=\"product_id\" value=\"".$_REQUEST["product_id"]."\">
 <input type=\"hidden\" name=\"action\" value=\"add_new_service\">".$added1."
-Special notes for the setup:<textarea name=\"custom_notes\" cols=\"50\" rows=\"5\"></textarea><br>
-<input type=\"submit\" value=\""._("Register")."\">
+" . _("Special notes for the setup") . ":<textarea name=\"custom_notes\" cols=\"50\" rows=\"5\"></textarea><br>
+".submitButtonStart(). _("Register") .submitButtonEnd()."
 ";
 		
 		return $out;
@@ -91,7 +96,7 @@ $form_start";
 			$add_domain_type_checked = " checked ";
 		}
 		$out .= "<input type=\"radio\" name=\"add_domain_type\" value=\"hosting\" checked>". _("Hosting only") ."<br>
-<input type=\"submit\" value=\"Ok\">
+".submitButtonStart(). _("Ok") .submitButtonEnd()."
 </form>
 ";
 
@@ -110,13 +115,13 @@ $form_start";
 //			if($i > 0){
 //				$out .= " - ";
 //			}
-			$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+			$out .= "<form action=\"?\">
 			<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 			<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
 			<input type=\"hidden\" name=\"action\" value=\"add_new_service\">
 			<input type=\"hidden\" name=\"product_id\" value=\"".$a["id"]."\">
 			<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
-			<input type=\"submit\" value=\"".$a["name"]."\"></form>";
+			".submitButtonStart().$a["name"].submitButtonEnd()."</form>";
 //			$out .= "<a href=\"/dtc/new_account.php?action=add_new_service&adm_login=$adm_login&product_id=".$a["id"]."\">".$a["name"]."</a>";
 		}
 		return $out;
@@ -130,10 +135,21 @@ $form_start";
 			return _("You curently don't have enough privileges to add domain names. If you often add domain names, you can ask the administrator to do so. To request hosting for a new domain without domain name registration, please write to:")."<br>".
 "<a href=\"mailto:$conf_webmaster_email_addr?subject=[DTC] More domains\">$conf_webmaster_email_addr</a>.";
 		}
+		if($admin["info"]["max_domain"] != 0){
+			$maxdomq = "SELECT COUNT(name) AS numofdomains FROM $pro_mysql_domain_table WHERE owner='$adm_login';";
+			$maxdomr = mysql_query($maxdomq)or die("Cannot query $maxdomq line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$maxdoma = mysql_fetch_array($maxdomr);
+			$num_of_installed_domains = $maxdoma["numofdomains"];
+			if($num_of_installed_domains >= $admin["info"]["max_domain"]){
+				return _("You have reached the maximum number of domains that you are allowed to run with this type of account.
+If you want to add more domain names, you should get in touch by opening a new support ticket.");
+			}
+		}
 		if(!isset($_REQUEST["domain_name"]) || $_REQUEST["domain_name"] == ""){
 			return "<br><b><u>". _("Please enter the domain name you wish to add:") ."</u></b><br>
 $form_start<input type=\"text\" name=\"domain_name\" value=\"\">
-<input type=\"submit\" value=\"ok\"></form>";
+".submitButtonStart(). _("Ok") .submitButtonEnd()."
+</form>";
 		}
 		if(!isHostname($_REQUEST["domain_name"])){
 			return _("Domain name is not in correct format. Please enter another name.") ;
@@ -153,28 +169,30 @@ $form_start<input type=\"text\" name=\"domain_name\" value=\"\">
 <br>
 ". _("You can add another domain name:") ."
 $form_start<input type=\"text\" name=\"domain_name\" value=\"\">
-<input type=\"submit\" value=\"ok\"></form>
+".submitButtonStart(). _("Ok") .submitButtonEnd()."
+</form>
 ";
 		}
 		addDomainToUser($adm_login,$adm_pass,$_REQUEST["domain_name"]);
 		return "<br><u><b>". _("Your domain name is now ready:") ."</b></u><br>
 ". _("Now you can go to check its configuration by clicking here:") ."<br>
-<a href=\"".$_SERVER["PHP_SELF"]."?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=".$_REQUEST["domain_name"]."\">".$_REQUEST["domain_name"]."</a><br>
+<a href=\"?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=".$_REQUEST["domain_name"]."\">".$_REQUEST["domain_name"]."</a><br>
 <br>
 ". _("Alternatively, you can add another domain name:") ."
 $form_start<input type=\"text\" name=\"domain_name\" value=\"\">
-<input type=\"submit\" value=\"ok\"></form>
+".submitButtonStart(). _("Ok") .submitButtonEnd()."
+</form>
 ";
 	}
 
 	// Registration or domain transfer ?
 	if(!isset($_REQUEST["add_regortrans"]) || ($_REQUEST["add_regortrans"] != "register" &&
 		$_REQUEST["add_regortrans"] != "transfer")){
-		$out .= "<b><u>". _("Do you want to transfer an existing domain or register a new domain?") ."</u></b><br>
+		$out .= "<br><h3>". _("Do you want to transfer an existing domain or register a new domain?") ."</h3>
 $form_start
 <input type=\"radio\" name=\"add_regortrans\" value=\"register\" checked>". _("Register a new domain") ."<br>
 <input type=\"radio\" name=\"add_regortrans\" value=\"transfer\">". _("Transfer an existing domain from another registrar") ."<br>
-<input type=\"submit\" value=\"Ok\">
+".submitButtonStart(). _("Ok") .submitButtonEnd()."
 </form>
 ";
 		return $out;
@@ -184,12 +202,12 @@ $form_start
 
 	// Start registration procedure (with or without hosting)
 
-	$out .= "<b><u>". _("Register a domain name") ."</u></b><br>";
+	$out .= "<br><h3>". _("Register a domain name") ."</h3>";
 	$out .= "<i><u>". _("Step 1: Verify availability") ."</u></i><br>";
 	if(!isset($_REQUEST["toreg_domain"]) || $_REQUEST["toreg_domain"] == "" ||
 	!isset($_REQUEST["toreg_extention"]) || $_REQUEST["toreg_extention"] == ""){
 		$out .= "<br>". _("Enter the domain name you want to register:") ."<br>
-$form_start $form_enter_domain_name</form>";
+$form_start ".make_registration_tld_popup()."</form>";
 		return $out;
 	}
 
@@ -206,12 +224,22 @@ $form_start $form_enter_domain_name</form>";
 ". _("Sorry, the domain name ") ." <b>$fqdn</b> ". _("is NOT available for registration. The registration server returned: ") 
 ."<br><font color=\"red\">" . $domlookup["response_text"] . "</font>
 <br><br>
-Have another try:<br>$form_start $form_enter_domain_name</form>";
+Have another try:<br>$form_start ".make_registration_tld_popup()."</form>";
 		return $out;
 	}
 	$form_start .= "<input type=\"hidden\" name=\"toreg_domain\" value=\"".$_REQUEST["toreg_domain"]."\">
 <input type=\"hidden\" name=\"toreg_extention\" value=\"".$_REQUEST["toreg_extention"]."\">";
 
+	$q = "SELECT * FROM $pro_mysql_domain_table WHERE name='$fqdn';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n != 0){
+		$out .= "<br>
+". _("The domain name") . " <b>$fqdn</b> ". _("is already in use in this server: you can't register that domain name.")."<br>".
+_("Have another try:") . "<br>$form_start ".make_registration_tld_popup()."</form>";
+		return $out;
+	}
+
 	// DOMAIN IS AVAILABLE, PROCEED DO REGISTRATION
 	$out .= "Domain name <b>$fqdn</b> is available for registration.<br><br>
 <i><u>". _("Step 2: Enter whois information") ."</u></i><br>
@@ -226,29 +254,36 @@ Have another try:<br>$form_start $form_enter_domain_name</form>";
 	if(!isset($_REQUEST["dtcrm_owner_hdl"]) || $_REQUEST["dtcrm_owner_hdl"] == "" ||
 		!isset($_REQUEST["dtcrm_admin_hdl"]) || $_REQUEST["dtcrm_admin_hdl"] == "" ||
 		!isset($_REQUEST["dtcrm_billing_hdl"]) || $_REQUEST["dtcrm_billing_hdl"] == "" ||
+		!isset($_REQUEST["dtcrm_teck_hdl"]) || $_REQUEST["dtcrm_teck_hdl"] == "" ||
 		!isset($_REQUEST["toreg_dns1"]) || $_REQUEST["toreg_dns1"] == "" ||
 		!isset($_REQUEST["toreg_dns2"]) || $_REQUEST["toreg_dns2"] == "" ||
 		$_REQUEST["toreg_period"] < 1 || $_REQUEST["toreg_period"] > 10){
 
 		$year = _("year") ;
 		$years = _("years") ;
-		$out .= _("Please select the 3 contact handles you want to use for registering that domain name.") ."<br><br>$form_start";
+		$out .= _("Please select registran and the 3 contact handles you want to use for registering that domain name.") ."<br><br>$form_start";
 		$out .= whoisHandleSelection($admin);
+		if ( isset($domlookup["attributes"]["minperiod"]) )
+                     $minreg = str_replace("Y", "", $domlookup["attributes"]["maxperiod"]);
+                else
+                     $minreg = 1;
+                if ( isset($domlookup["attributes"]["maxperiod"]) )
+                     $maxreg = str_replace("Y", "", $domlookup["attributes"]["maxperiod"]);
+		else
+		     $maxreg = 10;
 		$out .= "<br>$form_enter_dns_infos<br><br>
 ". _("Select how long you want to register this domain name:") ."<br>
-<select name=\"toreg_period\">
-<option value=\"1\">1 $year</option>
-<option value=\"2\">2 $years</option>
-<option value=\"3\">3 $years</option>
-<option value=\"4\">4 $years</option>
-<option value=\"5\">5 $years</option>
-<option value=\"6\">6 $years</option>
-<option value=\"7\">7 $years</option>
-<option value=\"8\">8 $years</option>
-<option value=\"9\">9 $years</option>
-<option value=\"10\">10 $years</option>
-</select><br><br>
-<input type=\"submit\" value=\"Ok\">
+<select name=\"toreg_period\"><option value=\"1\">1 $year</option>";
+		for ($p=2;$p<=$maxreg;$p++) {
+                   $out .= "<option value=\"$p\"";
+                   if ($p == $minreg)
+                      $out .= " selected>Minimum";
+		   else
+		      $out .= ">";
+                   $out .= " $p $years</option>";
+                }
+                $out .= "</select><br><br>
+".submitButtonStart(). _("Ok") .submitButtonEnd()."
 </form>
 ";
 		return $out;
@@ -265,7 +300,7 @@ $form_start
 
 	// Check if paiement has just occured !
 	if(isset($_REQUEST["inner_action"]) && $_REQUEST["inner_action"] == "return_from_paypal_domain_add"){
-		$ze_refund = isPayIDValidated(addslashes($_REQUEST["pay_id"]));
+		$ze_refund = isPayIDValidated(mysql_real_escape_string($_REQUEST["pay_id"]));
 		if($ze_refund == 0){
 			$out .= "<font color=\"red\">The transaction failed, please try again!</font>";
 		}else{
@@ -277,8 +312,8 @@ $form_start
 	}
 
 	// Check billing to know if user has enough money on his account
-	$price = registry_get_domain_price($fqdn,$_REQUEST["toreg_period"]);
-	$fqdn_price = $price["attributes"]["price"] + $registration_added_price;
+	$price = find_domain_price($_REQUEST["toreg_extention"]);
+	$fqdn_price = $price;
 	$fqdn_price *= $_REQUEST["toreg_period"];
 
 	if($admin["info"]["id_client"] != 0){
@@ -289,17 +324,18 @@ $form_start
 		return $out;
 	}
 	$out .= _("Remaining on your account: ") ." $secpayconf_currency_letters" . $remaining . "<br>
-". _("Total price: ") ." \$". $fqdn_price . "<br><br>";
+". _("Total price: ") ." ".$secpayconf_currency_letters."". $fqdn_price . "<br><br>";
 	if($fqdn_price > $remaining){
 		$to_pay = $fqdn_price - $remaining;
 
 		$payid = createCreditCardPaiementID($to_pay,$admin["info"]["id_client"],
 				"Domain name registration ".$_REQUEST["toreg_extention"],"no");
-		$return_url = $_SERVER["PHP_SELF"]."?adm_login=$adm_login&adm_pass=$adm_pass"
+		$return_url = htmlentities($_SERVER["PHP_SELF"])."?adm_login=$adm_login&adm_pass=$adm_pass"
 		."&addrlink=$addrlink&action=dtcrm_add_domain&add_domain_type=".$_REQUEST["add_domain_type"]
 		."&add_regortrans=".$_REQUEST["add_regortrans"]."&toreg_domain=".$_REQUEST["toreg_domain"]
 		."&toreg_extention=".$_REQUEST["toreg_extention"]."&dtcrm_owner_hdl=".$_REQUEST["dtcrm_owner_hdl"]
 		."&dtcrm_admin_hdl=".$_REQUEST["dtcrm_admin_hdl"]."&dtcrm_billing_hdl=".$_REQUEST["dtcrm_billing_hdl"]
+		."&dtcrm_teck_hdl=".$_REQUEST["dtcrm_teck_hdl"]
 		."&toreg_dns1=".$_REQUEST["toreg_dns1"]."&toreg_dns2=".$_REQUEST["toreg_dns2"]
 		."&toreg_dns3=".$_REQUEST["toreg_dns3"]."&toreg_dns4=".$_REQUEST["toreg_dns4"]
 		."&toreg_dns5=".$_REQUEST["toreg_dns5"]."&toreg_dns6=".$_REQUEST["toreg_dns6"]
@@ -309,7 +345,8 @@ $form_start
 
 		$out .= _("You currently don't have enough funds on your account. You will be redirected to our payment system. Please click on the button below to pay.") ."<br>
 <br><br>
-$form_start<input type=\"submit\" value=\"". _("Payment complete. Proceed to checkout") ."\">
+$form_start
+".submitButtonStart(). _("Payment complete. Proceed to checkout") .submitButtonEnd()."
 </form> $paybutton";
 		return $out;
 	}
@@ -319,7 +356,7 @@ $form_start<input type=\"submit\" value=\"". _("Payment complete. Proceed to che
 		$out .= _("You have enough funds on your account to proceed with registration. Press the confirm button to proceed.") ."<br><br>
 $form_start
 <input type=\"hidden\" name=\"toreg_confirm_register\" value=\"yes\">
-<input type=\"submit\" value=\"". _("Proceed to name-registration") ."\">
+".submitButtonStart(). _("Proceed to name-registration") .submitButtonEnd()."
 </form>";
 		return $out;
 	}
@@ -328,8 +365,28 @@ $form_start
 	$owner_id = $_REQUEST["dtcrm_owner_hdl"];
 	$billing_id = $_REQUEST["dtcrm_billing_hdl"];
 	$admin_id = $_REQUEST["dtcrm_admin_hdl"];
-	$contacts = getContactsArrayFromID($owner_id,$billing_id,$admin_id);
-	$regz = registry_register_domain($adm_login,$adm_pass,$fqdn,$_REQUEST["toreg_period"],$contacts,$dns_servers);
+	$teck_id = $_REQUEST["dtcrm_teck_hdl"];
+	$contacts = getContactsArrayFromID($owner_id,$billing_id,$admin_id,$teck_id);
+	$dns_servers = array();
+	for($i=1;$i<7;$i++){
+		if(isset($_REQUEST["toreg_dns$i"]) && isHostname($_REQUEST["toreg_dns$i"])){
+			$dns_servers[] = $_REQUEST["toreg_dns$i"];
+		}else if($i == 1){
+			$dns_servers[] = $conf_addr_primary_dns;
+		}else if($i == 2){
+			$dns_servers[] = $conf_addr_secondary_dns;
+		}
+	}
+	$q = "SELECT * FROM $pro_mysql_domain_table WHERE owner='$adm_login' AND whois='here';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n > 0){
+		$new_user = "no";
+	}else{
+		$new_user = "yes";
+	}
+//	sleep(2);
+	$regz = registry_register_domain($adm_login,$adm_pass,$fqdn,$_REQUEST["toreg_period"],$contacts,$dns_servers,$new_user);
 
 	if($regz["is_success"] != 1){
 		$out .= "<font color=\"red\"><b>". _("Registration failed") ."</b></font><br>
@@ -344,22 +401,32 @@ Server said: <i>" . $regz["response_text"] . "</i><br>";
 	mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
 
 	addDomainToUser($adm_login,$adm_pass,$fqdn,$adm_pass);
-	unset($ns_ar);
-	$ns_ar[] = $_REQUEST["toreg_dns1"];
-	$ns_ar[] = $_REQUEST["toreg_dns2"];
-	if(isset($_REQUEST["toreg_dns3"]) && $_REQUEST["toreg_dns3"] != "")
-		$ns_ar[] = $_REQUEST["toreg_dns3"];
-	if(isset($_REQUEST["toreg_dns4"]) && $_REQUEST["toreg_dns4"] != "")
-		$ns_ar[] = $_REQUEST["toreg_dns4"];
-	if(isset($_REQUEST["toreg_dns5"]) && $_REQUEST["toreg_dns5"] != "")
-		$ns_ar[] = $_REQUEST["toreg_dns5"];
-	if(isset($_REQUEST["toreg_dns6"]) && $_REQUEST["toreg_dns6"] != "")
-		$ns_ar[] = $_REQUEST["toreg_dns6"];
-	newWhois($fqdn,$owner_id,$billing_id,$admin_id,$period,$ns_ar);
+
+	if($regz["is_success"] == 1){
+		$id = find_registry_id($fqdn);
+		$q = "UPDATE $pro_mysql_domain_table SET registrar='".$registry_api_modules[$id]["name"]."' WHERE name='$fqdn';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+
+		unset($ns_ar);
+		$ns_ar = array();
+		$ns_ar[] = $_REQUEST["toreg_dns1"];
+		$ns_ar[] = $_REQUEST["toreg_dns2"];
+		if(isset($_REQUEST["toreg_dns3"]) && $_REQUEST["toreg_dns3"] != "")
+			$ns_ar[] = $_REQUEST["toreg_dns3"];
+		if(isset($_REQUEST["toreg_dns4"]) && $_REQUEST["toreg_dns4"] != "")
+			$ns_ar[] = $_REQUEST["toreg_dns4"];
+		if(isset($_REQUEST["toreg_dns5"]) && $_REQUEST["toreg_dns5"] != "")
+			$ns_ar[] = $_REQUEST["toreg_dns5"];
+		if(isset($_REQUEST["toreg_dns6"]) && $_REQUEST["toreg_dns6"] != "")
+			$ns_ar[] = $_REQUEST["toreg_dns6"];
+		newWhois($fqdn,$owner_id,$billing_id,$admin_id,$teck_id,$_REQUEST["toreg_period"],$ns_ar,$registry_api_modules[$id]["name"]);
+	}
+
+
 
 	$out .= "<font color=\"green\"><b>". _("Successfully added your domain name to the hosting database") ."</b></font><br>";
 
-	$out .= _("Click") ."<a href=\"". $_SERVER["PHP_SELF"] ."?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=$addrlink\">". _("here") ."</a>". _("to refresh the menu or add another domain name.") ;
+	$out .= _("Click") . " " ."<a href=\"?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=$addrlink\">". _("here") ."</a>". " " . _("to refresh the menu or add another domain name.") ;
 
 // END OF DOMAIN NAME REGISTRATION //
 /////////////////////////////////////
