@@ -9,6 +9,7 @@ function drawAdminTools_Dedicated($admin,$dedicated_server_hostname){
 	global $pro_mysql_product_table;
 	global $pro_mysql_dedicated_table;
 	global $pro_mysql_dedicated_ips_table;
+	global $pro_mysql_raduser_table;
 
 	global $secpayconf_currency_letters;
 
@@ -68,12 +69,49 @@ function drawAdminTools_Dedicated($admin,$dedicated_server_hostname){
 	}
 
 //	$out .= "Dedicated server content!";
-	$out .= "<br><br><h3>"._("IP addresses: ")."</h3>";
-	$frm_start = "<form action=\"?\">
+
+	$frm_start = "<form name=\"radius\" action=\"?\">
 <input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">";
 
+	if ( $server_prod["use_radius"] == 'yes' ) {
+		$out .= '<BR><BR>';
+		$q = "SELECT * FROM $pro_mysql_raduser_table WHERE dedicated_id='".$dedicated["id"]."';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		$user_ok = 'no';
+		if($n == 1){
+			$radius_user = mysql_fetch_array($r);
+			$user_ok = 'yes';
+			$edit_user = $radius_user["UserName"];
+			$edit_password = $radius_user["Password"];
+		}else{
+			if($n == 0){
+				$user_ok = 'yes';
+				$edit_user = '';
+				$edit_password = '';
+			}else{
+				$out .= _("Error Getting Radius Username. Please Contact Support.");
+			}
+		}
+		if( $user_ok == 'yes' ){
+		$out .= dtcFormTableAttrs();
+		$genpass = autoGeneratePassButton("radius","radius_password");
+		$out .= dtcFormLineDraw("","$frm_start<input type=\"hidden\" name=\"action\" value=\"set_radius_user\">
+<input type=\"hidden\" name=\"dedicated_id\" value=\"".$dedicated["id"]."\">
+" . _("Radius User:") . " <input type=\"text\" name=\"radius_user\" value=\"".$edit_user."\">
+" . _("Password:") . " <input type=\"password\" name=\"radius_password\" value=\"".$edit_password."\">".$genpass."
+</td><td><div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
+<div class=\"input_btn_left\"></div>
+<div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" value=\""._("Update Radius User")."\"></div>
+<div class=\"input_btn_right\"></div>
+</div></form>",0);
+		$out .= "</table>";
+		}
+	}
+	$out .= "<br><br><h3>"._("IP addresses: ")."</h3>";
+
 	$q = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE dedicated_server_hostname='$dedicated_server_hostname'";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
@@ -87,6 +125,12 @@ function drawAdminTools_Dedicated($admin,$dedicated_server_hostname){
 		}else{
 			$alt_color = 1;
 		}
+
+		$frm_start = "<form name=\"iprdns\" action=\"?\">
+<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
+<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">";
+
 		$out .= dtcFormLineDraw($a["ip_addr"],"$frm_start<input type=\"hidden\" name=\"action\" value=\"set_dedicated_ip_rdns\">
 <input type=\"hidden\" name=\"ip_addr\" value=\"".$a["ip_addr"]."\">
 <input type=\"text\" name=\"rdns\" value=\"".$a["rdns_addr"]."\">
