@@ -69,92 +69,6 @@ function drawImportedMail($mailbox){
 		);
         $out = dtcListItemsEdit($dsc);
 	return $out;
-
-
-/*	$out = "";
-
-	if(isset($errTxt) && $errTxt != ""){
-		$out .= "<font color=\"red\">$errTxt</font><br>";
-	}
-
-	$url_start = "<a href=\"".$_SERVER["PHP_SELF"]."?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
-	$form_start = "<form action=\"".$_SERVER["PHP_SELF"]."\">
-<input type=\"hidden\" name=\"adm_email_login\" value=\"$adm_email_login\">
-<input type=\"hidden\" name=\"adm_email_pass\" value=\"$adm_email_pass\">
-<input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">";
-
-	$q = "SELECT * FROM $pro_mysql_fetchmail_table WHERE domain_user='".$mailbox["data"]["id"]."' AND domain_name='".$mailbox["data"]["mbox_host"]."';";
-	$r = mysql_query($q)or die("Cannot query $q ! line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-	$n = mysql_num_rows($r);
-	$out .= "<table border=\"1\">
-	
-	<!-- to translate -->
-<tr><td>". _("Address email") ."</td><td>". _("Mailbox type") ."</td><td>". _("Server address :") . "</td><td>". _("Login") ."</td><td>". _("Password:") ."</td><td>". _("Use") ."</td><td>". _("Action") ."</td></tr>";
-	for($i=0;$i<$n;$i++){
-		$a = mysql_fetch_array($r);
-		$pop3_selected = "";
-		$imap4_selected = "";
-		$msn_selected = "";
-		$hotmail_selected = "";
-		$yahoo_selected = "";
-		$gmail_selected = "";
-		switch($a["mailbox_type"]){
-		case "POP3":
-			$pop3_selected = " selected ";
-			break;
-		case "IMAP4":
-			$imap4_selected = " selected ";
-			break;
-		case "MSN":
-			$msn_selected = " selected ";
-			break;
-		case "HOTMAIL":
-			$hotmail_selected = " selected ";
-			break;
-		case "GMAIL":
-			$yahoo_selected = " selected ";
-		default:
-			break;
-		}
-		$popup_boxtype = "<select name=\"mailbox_type\">
-			<option value=\"POP3\"$pop3_selected>POP3</option>
-			<option value=\"IMAP4\"$imap4_selected>IMAP4</option>
-			<option value=\"MSN\"$msn_selected>MSN</option>
-			<option value=\"HOTMAIL\"$hotmail_selected>HOTMAIL</option>
-			<option value=\"GMAIL\"$yahoo_selected>GMAIL</option></select>";
-		if($a[""] == "yes"){
-			$useit = "";
-		}
-		$popup_boxtype = $a["mailbox_type"]."<input type=\"hidden\" name=\"mailbox_type\" value=\"".$a["mailbox_type"]."\">";
-		$out .= "<tr>
-			<td>$form_start<input type=\"hidden\" name=\"action\" value=\"modify_fetchmail\"><input type=\"hidden\" name=\"boxid\" value=\"".$a["id"]."\"><input type=\"text\" name=\"email_addr\" value=\"".$a["pop3_email"]."\"></td>
-			<td>$popup_boxtype</td>
-			<td><input type=\"text\" name=\"server_addr\" value=\"".$a["pop3_server"]."\"></td>
-			<td><input type=\"text\" name=\"login\" value=\"".$a["pop3_login"]."\"></td>
-			<td><input type=\"text\" name=\"pass\" value=\"".$a["pop3_pass"]."\"></td>
-			<td>Use</td>
-			<td><input type=\"submit\" value=\"Save\"></form>$form_start<input type=\"hidden\" name=\"action\" value=\"del_fetchmail\">
-			<input type=\"hidden\" name=\"boxid\" value=\"".$a["id"]."\"><input type=\"submit\" value=\"delete\"></form></td></tr>";
-	}
-	$out .= "<tr>
-		<td>$form_start<input type=\"hidden\" name=\"action\" value=\"add_fetchmail\"><input type=\"text\" name=\"email_addr\" value=\"\"></td>
-		<td><select name=\"mailbox_type\">
-			<option value=\"POP3\">POP3</option>
-			<option value=\"IMAP4\">IMAP4</option>
-			<option value=\"MSN\">MSN</option>
-			<option value=\"HOTMAIL\">HOTMAIL</option>
-			<option value=\"GMAIL\">GMAIL</option>
-		</select></td>
-		<td><input type=\"text\" name=\"server_addr\" value=\"\"></td>
-		<td><input type=\"text\" name=\"login\" value=\"\"></td>
-		<td><input type=\"text\" name=\"pass\" value=\"\"></td>
-		<td><input type=\"checkbox\" name=\"use\" value=\"yes\" checked\"></td>
-		<td><input type=\"submit\" value=\"Add\"></form></td></tr>";
-	$out .= "</table>";
-
-	return $out;
-*/
-
 }
 
 function drawAntispamRules($mailbox){
@@ -163,7 +77,7 @@ function drawAntispamRules($mailbox){
 	global $pro_mysql_whitelist_table;
 	global $pro_mysql_whitelist_table;
 
-	$bnc_msg = "Hello,
+	$bnc_msg = _("Hello,
 You have tried to write an email to me, and because of the big amount
 of spam I recieved, I use an antispam software that require a message
 confirmation. This is very easy, and you will have to do it only once.
@@ -179,22 +93,22 @@ Thank you for your understanding.
 Antispam software:
 Grey listing+SPF, only available with Domain Technologie Control
 http://www.gplhost.com/software-dtc.html
-";
+");
 
 	$out = "";
 
-	$url_start = "<a href=\"".$_SERVER["PHP_SELF"]."?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
-	$form_start = "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$url_start = "<a href=\"?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
+	$form_start = "<form action=\"?\">
 <input type=\"hidden\" name=\"adm_email_login\" value=\"$adm_email_login\">
 <input type=\"hidden\" name=\"adm_email_pass\" value=\"$adm_email_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">";
 
 	if($mailbox["data"]["iwall_protect"] == "yes")	$checked = " checked "; else $checked = "";
-	$out = $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_antispam\"><input type=\"checkbox\" name=\"iwall_on\" value=\"yes\"$checked>Activate iGlobalWall protection
+	$out = $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_antispam\"><input type=\"checkbox\" name=\"iwall_on\" value=\"yes\"$checked>" . _("Activate iGlobalWall protection") . "
 	". drawSubmitButton( _("Ok") ) ."</form>";
 
 	if($mailbox["data"]["iwall_protect"] == "yes"){
-		$frm_start = "<form action=\"".$_SERVER["PHP_SELF"]."\">
+		$frm_start = "<form action=\"?\">
 <input type=\"hidden\" name=\"adm_email_login\" value=\"".$_REQUEST["adm_email_login"]."\">
 <input type=\"hidden\" name=\"adm_email_pass\" value=\"".$_REQUEST["adm_email_pass"]."\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">";
@@ -205,19 +119,19 @@ http://www.gplhost.com/software-dtc.html
 			$zebounce = $mailbox["data"]["bounce_msg"];
 		}
 
-		$out .= "<br><h3>Your bounce message:</h3>
+		$out .= "<br><h3>" . _("Your bounce message") . ":</h3>
 		
 		$frm_start<input type=\"hidden\" name=\"action\" value=\"edit_bounce_msg\">
 		<textarea cols=\"80\" rows=\"16\" name=\"bounce_msg\">$zebounce</textarea><br><br>
-		<input type=\"submit\" value=\"Save\"></form>";
+		<input type=\"submit\" value=\"" . _("Save") . "\"></form>";
 
-		$out .= "<h3>Your white list:</h3>";
+		$out .= "<h3>" . _("Your white list") . ":</h3>";
 
 		$q = "SELECT * FROM $pro_mysql_whitelist_table";
 		$r = mysql_query($q)or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$n = mysql_num_rows($r);
 		$out .= "<table cellpadding=\"0\" cellspacing=\"0\" border=\"1\">
-<tr><td>Mail user from</td><td>&nbsp;</td><td>Mail user domain</td><td>Mail user to (mailling list)</td><td>Action</td></tr>";
+<tr><td>" . _("Mail user from") . "</td><td>&nbsp;</td><td>" . _("Mail user domain") . "</td><td>" . _("Mail user to (mailling list)") . "</td><td>" . _("Action") . "</td></tr>";
 		for($i=0;$i<$n;$i++){
 			$a = mysql_fetch_array($r);
 			$out .= "<tr>$frm_start
@@ -227,10 +141,10 @@ http://www.gplhost.com/software-dtc.html
 			$out .= "<td>@</td>";
 			$out .= "<td><input type=\"text\" name=\"mail_from_domain\" value=\"".$a["mail_from_domain"]."\"></td>";
 			$out .= "<td><input type=\"text\" size=\"30\" name=\"mail_to\" value=\"".$a["mail_to"]."\"></td>";
-			$out .= "<td><input type=\"submit\"  value=\"Save\"></form>
+			$out .= "<td><input type=\"submit\"  value=\"". _("Save") . "\"></form>
 			$frm_start<input type=\"hidden\" name=\"ruleid\" value=\"".$a["id"]."\">
 			<input type=\"hidden\" name=\"action\" value=\"delete_whitelist_rule\">
-			<input type=\"submit\" value=\"Delete\"></form></td></tr>";
+			<input type=\"submit\" value=\"". _("Delete") . "\"></form></td></tr>";
 		}
 		$out .= "<tr>$frm_start
 			<input type=\"hidden\" name=\"action\" value=\"add_whitelist_rule\">
@@ -238,11 +152,11 @@ http://www.gplhost.com/software-dtc.html
 		$out .= "<td>@</td>";
 		$out .= "<td><input type=\"text\" name=\"mail_from_domain\" value=\"\"></td>";
 		$out .= "<td><input type=\"text\" size=\"30\" name=\"mail_to\" value=\"\"></td>";
-		$out .= "<td><input type=\"submit\" value=\"Save\"></form></td></tr>";
+		$out .= "<td><input type=\"submit\" value=\"" . _("Save") . "\"></form></td></tr>";
 		$out .= "</table>";
 	}
 	if($mailbox["data"]["clamav_protect"] == "yes")	$checked = " checked "; else $checked = "";
-	$out .= $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_clamav\"><input type=\"checkbox\" name=\"clamav_on\" value=\"yes\"$checked>Activate Clamav antivirus
+	$out .= $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_clamav\"><input type=\"checkbox\" name=\"clamav_on\" value=\"yes\"$checked>" . _("Activate Clamav antivirus") . "
 	". drawSubmitButton( _("Ok") ) ."</form>";
 	return $out;
 }
@@ -253,15 +167,15 @@ function drawQuarantine($mailbox){
 
 	$out = "";
 
-	$url_start = "<a href=\"".$_SERVER["PHP_SELF"]."?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
-	$form_start = "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$url_start = "<a href=\"?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
+	$form_start = "<form action=\"?\">
 <input type=\"hidden\" name=\"adm_email_login\" value=\"$adm_email_login\">
 <input type=\"hidden\" name=\"adm_email_pass\" value=\"$adm_email_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">";
 
 //	$out = $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_antispam\"><input type=\"checkbox\" name=\"iwall_on\" value=\"yes\"$checked>Activate iGlobalWall protection
 //	<input type=\"submit\" value=\"Ok\"></form>";
-	$out = "Here will go quarantinized messages";
+	$out = _("Here will go quarantinized messages");
 
 	return $out;
 }
@@ -269,9 +183,10 @@ function drawQuarantine($mailbox){
 function drawAdminTools_emailAccount($mailbox){	
 	global $adm_email_login;
 	global $adm_email_pass;
+	global $cyrus_used;
 
-	$url_start = "<a href=\"".$_SERVER["PHP_SELF"]."?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
-	$form_start = "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$url_start = "<a href=\"?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass&addrlink=".$_REQUEST["addrlink"];
+	$form_start = "<form action=\"?\">
 <input type=\"hidden\" name=\"adm_email_login\" value=\"$adm_email_login\">
 <input type=\"hidden\" name=\"adm_email_pass\" value=\"$adm_email_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">";
@@ -298,48 +213,53 @@ function drawAdminTools_emailAccount($mailbox){
 		$use_vacation_msg_no_checked = " checked ";
 	}
 
-	$left .= "<h3>Vacation message</h3>
-	".$form_start."<input type=\"hidden\" name=\"action\" value=\"dtcemail_vacation_msg\">
-<input type=\"radio\" name=\"use_vacation_msg\" value=\"yes\" $use_vacation_msg_yes_checked>"._("Yes")."<input type=\"radio\" name=\"use_vacation_msg\" value=\"no\" $use_vacation_msg_no_checked>"._("No")."
-<br>
-<textarea cols=\"40\" rows=\"7\" name=\"vacation_msg_txt\">".$mailbox["data"]["vacation_text"]."</textarea><br>
-". drawSubmitButton( _("Ok") ) ."</form>";
-
+	if (!$cyrus_used){
+  	$left .= "<h3>" . _("Vacation message") . "</h3>
+  	".$form_start."<input type=\"hidden\" name=\"action\" value=\"dtcemail_vacation_msg\">
+  <input type=\"radio\" name=\"use_vacation_msg\" value=\"yes\" $use_vacation_msg_yes_checked>"._("Yes")."<input type=\"radio\" name=\"use_vacation_msg\" value=\"no\" $use_vacation_msg_no_checked>"._("No")."
+  <br>
+  <textarea cols=\"40\" rows=\"7\" name=\"vacation_msg_txt\">".$mailbox["data"]["vacation_text"]."</textarea><br>
+  ". drawSubmitButton( _("Ok") ) ."</form>";
+  }
 	if($mailbox["data"]["localdeliver"] == "yes"){
 		$deliverUrl = "$url_start&action=dtcemail_set_deliver_local&setval=no\"><font color=\"green\">"._("Yes")."</font></a>";
 	}else{
 		$deliverUrl = "$url_start&action=dtcemail_set_deliver_local&setval=yes\"><font color=\"red\">"._("No")."</font></a>";
 	}
-	$right = "<h3>". _("Edit your mailbox redirections:") ."</h3>
-". _("Deliver messages locally in INBOX: ") ." $deliverUrl
-<table cellpadding=\"0\" cellspacing=\"0\">
-<tr>
-	<td align=\"right\">".$form_start. _("Redirection 1: ") ."</td>
-	<td><input type=\"hidden\" name=\"action\" value=\"dtcemail_edit_redirect\"><input type=\"text\" name=\"redirect1\" value=\"".$mailbox["data"]["redirect1"]."\"></td>
-</tr><tr>
-	<td>". _("Redirection 2: ") ."</td>
-	<td><input type=\"text\" name=\"redirect2\" value=\"".$mailbox["data"]["redirect2"]."\"></td>
-</tr><tr>
-	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td>
-</tr></table><br><br>";
+	if (!$cyrus_used){
+    	$right = "<h3>". _("Edit your mailbox redirections:") ."</h3>
+    ". _("Deliver messages locally in INBOX: ") ." $deliverUrl
+    <table cellpadding=\"0\" cellspacing=\"0\">
+    <tr>
+    	<td align=\"right\">".$form_start. _("Redirection 1: ") ."</td>
+    	<td><input type=\"hidden\" name=\"action\" value=\"dtcemail_edit_redirect\"><input type=\"text\" name=\"redirect1\" value=\"".$mailbox["data"]["redirect1"]."\"></td>
+    </tr><tr>
+    	<td>". _("Redirection 2: ") ."</td>
+    	<td><input type=\"text\" name=\"redirect2\" value=\"".$mailbox["data"]["redirect2"]."\"></td>
+    </tr><tr>
+    	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td>
+    </tr></table><br><br>";
 
-	if($mailbox["data"]["spam_mailbox_enable"] == "yes"){
-		$spambox_yes_checked = " checked ";
-		$spambox_no_checked = " ";
-	}else{
-		$spambox_yes_checked = " ";
-		$spambox_no_checked = " checked ";
+    	if($mailbox["data"]["spam_mailbox_enable"] == "yes"){
+    		$spambox_yes_checked = " checked ";
+    		$spambox_no_checked = " ";
+    	}else{
+    		$spambox_yes_checked = " ";
+    		$spambox_no_checked = " checked ";
+    	}
+
+    	$right .= "<h3>" . _("Anti-SPAM control") . "</h3>
+    <table cellpadding=\"0\" cellspacing=\"0\">
+    <tr>
+    	<td align=\"right\">Deliver spam to spambox:</td><td>".$form_start."<input type=\"hidden\" name=\"action\" value=\"dtcemail_spambox\">
+    <input type=\"radio\" name=\"spam_mailbox_enable\" value=\"yes\" $spambox_yes_checked>"._("Yes")."<input type=\"radio\" name=\"spam_mailbox_enable\" value=\"no\" $spambox_no_checked>"._("No")."</td>
+    </tr><tr>
+    	<td align=\"right\">" . _("SPAM box name") . ":</td><td><input type=\"text\" name=\"spam_mailbox\" value=\"".$mailbox["data"]["spam_mailbox"]."\"></td>
+    </tr><tr>
+    	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td></tr></table>";
 	}
-
-	$right .= "<h3>Anti-SPAM control</h3>
-<table cellpadding=\"0\" cellspacing=\"0\">
-<tr>
-	<td align=\"right\">Deliver spam to spambox:</td><td>".$form_start."<input type=\"hidden\" name=\"action\" value=\"dtcemail_spambox\">
-<input type=\"radio\" name=\"spam_mailbox_enable\" value=\"yes\" $spambox_yes_checked>"._("Yes")."<input type=\"radio\" name=\"spam_mailbox_enable\" value=\"no\" $spambox_no_checked>"._("No")."</td>
-</tr><tr>
-	<td align=\"right\">SPAM box name:</td><td><input type=\"text\" name=\"spam_mailbox\" value=\"".$mailbox["data"]["spam_mailbox"]."\"></td>
-</tr><tr>
-	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td></tr></table>";
+	else { $right=""; }
+	
 	// Output the form
 	$out = "<table width=\"100%\" heigh=\"1\">
 <tr>
@@ -370,8 +290,8 @@ function drawAdminTools_emailPanel($mailbox){
 		"type" => "link",
 		"link" => "fetchmail");
 
-	$logout = "<a href=\"".$_SERVER["PHP_SELF"]."?action=logout\">". _("Logout") ."</a>";
-	$mymenu = makeTreeMenu($user_menu,$addrlink,"".$_SERVER["PHP_SELF"]."?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass","addrlink");
+	$logout = "<a href=\"?action=logout\">". _("Logout") ."</a>";
+	$mymenu = makeTreeMenu($user_menu,$addrlink,"?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass","addrlink");
 
 	switch($addrlink){
 	case "My Email":
@@ -724,7 +644,7 @@ function drawAdminTools_Emails($domain){
 		$catch_popup .= "<option value=\"".$a["id"]."\" $selected>".$a["id"]."</option>";
         }
 	$out .= "<b><u>". _("Catch-all email set to deliver to") .":</u></b><br>";
-	$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+	$out .= "<form action=\"?\">
 	<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
 	<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
