@@ -1,7 +1,6 @@
 <?php
 
 function drawAdminTools_MyAccount($admin){
-	global $PHP_SELF;
 	global $adm_login;
 	global $adm_pass;
 	global $addrlink;
@@ -11,10 +10,14 @@ function drawAdminTools_MyAccount($admin){
 	global $pro_mysql_client_table;
 	global $pro_mysql_ssl_ips_table;
 	global $pro_mysql_product_table;
+	global $pro_mysql_pending_renewal_table;
+	global $secpayconf_currency_letters;
 
 	global $cc_code_array;
 
-	$frm_start = "<form action=\"$PHP_SELF\">
+	get_secpay_conf();
+
+	$frm_start = "<form action=\"?\">
 <input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 <input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
@@ -32,7 +35,7 @@ function drawAdminTools_MyAccount($admin){
 
 	if(isset($_REQUEST["action"]) && $id_client != 0 && $_REQUEST["action"] == "refund_myaccount"){
 		if(isset($_REQUEST["inneraction"]) && $_REQUEST["inneraction"] == "return_from_paypal_refund_my_account"){
-			$ze_refund = isPayIDValidated(addslashes($_REQUEST["payid"]));
+			$ze_refund = isPayIDValidated(mysql_real_escape_string($_REQUEST["payid"]));
 			if($ze_refund == 0){
 				$out .= "<font color=\"red\">The transaction failed, please try again!</font>";
 				return $out;
@@ -45,11 +48,21 @@ function drawAdminTools_MyAccount($admin){
 				return $out;
 			}
 		}else{
-			$payid = createCreditCardPaiementID(addslashes($_REQUEST["refund_amount"]),$admin["info"]["id_client"],
-				"Refund my account","no");
-			$return_url = $_SERVER["PHP_SELF"]."?adm_login=$adm_login&adm_pass=$adm_pass"
+			// Save the values in SQL and process the paynow buttons
+			$q = "INSERT INTO $pro_mysql_pending_renewal_table (id,adm_login,renew_date,renew_time,product_id,renew_id,heb_type,country_code)
+			VALUES ('','".$_REQUEST["adm_login"]."',now(),now(),'".$ro["id"]."','".$rocli["id"]."','shared-upgrade','$country');";
+			$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+			$renew_id = mysql_insert_id();
+
+			$payid = createCreditCardPaiementID(mysql_real_escape_string($_REQUEST["refund_amount"]),$admin["info"]["id_client"],
+				"Refund my account","no",$prod_id,$vat_rate);
+
+			$q = "UPDATE $pro_mysql_pending_renewal_table SET pay_id='$payid' WHERE id='$renew_id';";
+			$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+
+			$return_url = htmlentities($_SERVER["PHP_SELF"])."?adm_login=$adm_login&adm_pass=$adm_pass"
 				."&addrlink=$addrlink&action=refund_myaccount&inneraction=return_from_paypal_refund_my_account&payid=$payid";
-			$paybutton = paynowButton($payid,addslashes($_REQUEST["refund_amount"]),"Refund my account",$return_url);
+			$paybutton = paynowButton($payid,mysql_real_escape_string($_REQUEST["refund_amount"]),"Refund my account",$return_url);
 			$out .= "<b><u>Pay \$".$_REQUEST["refund_amount"]." on my account:</u></b><br>";
 			$out .=" Please click on the button below to pay your acount.<br><br>$paybutton";
 			return $out;
@@ -61,7 +74,7 @@ function drawAdminTools_MyAccount($admin){
 	}
 
 	if(isset($admin["data"])){
-		$out .= "<h3>". _("Transfer and disk usage:") ."</h3>";
+		$out .= "<br><h3>". _("Transfer and disk usage:") ."</h3>";
 		// Draw overall this month usage
 		// if there is no usage, set to 0
 		if (!isset($stats["total_transfer"]))
@@ -82,7 +95,7 @@ function drawAdminTools_MyAccount($admin){
 		}
 
 		if($id_client != 0){
-			$out .= '<table><td>'.$overall.'</td><td><img src="bw_per_month.php?cid='.$id_client.'&adm_login='.$adm_login.'"></td></tr></table>';
+			$out .= '<table><td>'.$overall.'</td><td><img src="bw_per_month.php?cid='.$id_client.'&adm_login='.$adm_login.'&adm_pass='.$adm_pass.'"></td></tr></table>';
 		}else{
 			$out .= $overall;
 		}
@@ -140,13 +153,13 @@ function drawAdminTools_MyAccount($admin){
 							}
 						}
 					}
-					$q = "SELECT * FROM $pro_mysql_product_table WHERE heb_type='ssl';";
-					$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
-					$n = mysql_num_rows($r);
-					if($n != 1){
+					$prodq = "SELECT * FROM $pro_mysql_product_table WHERE heb_type='ssl';";
+					$prodr = mysql_query($prodq)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+					$prodn = mysql_num_rows($prodr);
+					if($prodn != 1){
 						$ssl_renew_form = _("No ssl product defined.") ;
 					}else{
-						$prod = mysql_fetch_array($r);
+						$prod = mysql_fetch_array($prodr);
 						$ssl_renew_form = "<form action=\"/dtc/new_account.php\">
 <input type=\"hidden\" name=\"action\" value=\"contract_renewal\">
 <input type=\"hidden\" name=\"renew_type\" value=\"ssl_renew\">
@@ -185,23 +198,18 @@ function drawAdminTools_MyAccount($admin){
 				}
 			}
 
-/*			$out .=  "<h3>". _("Remaining money on my account:") ."</h3><br>
-<table width=\"100%\" height=\"1\" cellpadding=\"4\" cellspacing=\"0\" border=\"0\">
-<tr>
-	<td><font size=\"+1\">\$".$client["dollar"]."</font></td>
-	<td><font size=\"-1\">". _("Refund my account:") ."</font><br>
-$frm_start<input type=\"hidden\" name=\"action\" value=\"refund_myaccount\">
-\$<input size=\"8\" type=\"text\" name=\"refund_amount\" value=\"\">
-<input type=\"submit\" value=\"". _("Ok") ."\">
-</form></td></tr>
-</table>
-<hr width=\"90%\">
-";*/
+			$out .=  "<h3>". _("Remaining money on my account:") ."</h3>";
+			$out .= dtcFormTableAttrs();
+			$out .= dtcFormLineDraw( _("Money remaining: "), $client["dollar"]." $secpayconf_currency_letters",1);
+			$out .= dtcFormLineDraw( _("Refund my account:"), "$frm_start<input type=\"hidden\" name=\"action\" value=\"refund_myaccount\">
+<input size=\"8\" type=\"text\" name=\"refund_amount\" value=\"\"> $secpayconf_currency_letters",0);
+			$out .= dtcFormLineDraw( "", submitButtonStart()._("Add money").submitButtonEnd()."</form>",1);
+			$out .= "</table>";
 
 		}
 
 
-		$out .= "<center><b>". _("Please tell us if the following is not correct:") ."</b></center>";
+		$out .= "<h3>". _("Your address (please tell us if the following is not correct):") ."</h3>";
 
 		if($client["is_company"] == "yes"){
 			$out .= _("Company name:") .$client["company_name"]."<br>";
@@ -238,11 +246,10 @@ $frm_start<input type=\"hidden\" name=\"action\" value=\"refund_myaccount\">
 
 		}
 
-		$out .= "<br>If you want to earn money with GPLHost, all you have to do is place a link on your site, pointing to:
-
-		<pre>https://{$_SERVER['SERVER_NAME']}/dtc/affiliation.php?affiliate={$adm_login}&amp;return=/hosting-vps.html</pre>
-
-		You can customize the <code>return</code> variable to redirect the user to any particular landing page that exists on our Web site (though we recommend the product page as per the example).  Then, when one of your visitors clicks on that link to buy a product from us, he will be redirected to our Web site.  Once he buys, you will automatically be credited a payment depending on the product that your visitor bought.";
+		$out .= "<h3>"._("Affiliation")."</h3>";
+		$out .= _("If you want to earn money, all you have to do is place a link on your site, pointing to:").
+		"<pre>https://{$_SERVER['SERVER_NAME']}/dtc/affiliation.php?affiliate={$adm_login}&amp;return=/hosting-vps.html</pre>"
+		._("You can customize the <code>return</code> variable to redirect the user to any particular landing page that exists on our Web site (though we recommend the product page as per the example).  Then, when one of your visitors clicks on that link to buy a product from us, he will be redirected to our Web site.  Once he buys, you will automatically be credited a payment depending on the product that your visitor bought.");
 
 	}else{
 		$out .= "<br>" . _("You do not have a client account, so there is no money in your account.");
