@@ -32,6 +32,11 @@ function drawEditAdmin($admin){
 	$prod_id = $info["prod_id"];
 
 	$allow_add_domain = $info["allow_add_domain"];
+	$max_domain = $info["max_domain"];
+	$restricted_ftp_path = $info["restricted_ftp_path"];
+	$allow_dns_and_mx_change = $info["allow_dns_and_mx_change"];
+	$allow_mailing_list_edit = $info["allow_mailing_list_edit"];
+	$allow_subdomain_edit = $info["allow_subdomain_edit"];
 	$resseller_flag = $info["resseller_flag"];
 	$ssh_login_flag = $info["ssh_login_flag"];
 	$ftp_login_flag = $info["ftp_login_flag"];
@@ -81,12 +86,56 @@ function drawEditAdmin($admin){
 	if($allow_add_domain == "check")$adcheck = "selected='selected'";	else $adcheck = "";
 	if($allow_add_domain == "no")	$adno = "selected='selected'";	else $adno = "";
 	$aldom_popup = "<select class=\"dtcDatagrid_input_color\" name=\"allow_add_domain\">
-<option value=\"yes\" $adyes>Yes</option>
-<option value=\"check\" $adcheck>Check</option>
-<option value=\"no\" $adno>No</option>
+<option value=\"yes\" $adyes>" . _("Yes") ."</option>
+<option value=\"check\" $adcheck>" . _("Check") . "</option>
+<option value=\"no\" $adno>". _("No") . "</option>
 </select>
 ";
 
+	// Restriction of FTP path selection
+	if($restricted_ftp_path == "yes"){
+		$restricted_ftp_path_yes = " checked='checked' ";
+		$restricted_ftp_path_no = "";
+	}else{
+		$restricted_ftp_path_yes = "";
+		$restricted_ftp_path_no = " checked='checked' ";
+	}
+	$restricted_ftp_path_selector = "<input type=\"radio\" name=\"restricted_ftp_path\" value=\"yes\"$restricted_ftp_path_yes> "._("Yes")."
+<input type=\"radio\" name=\"restricted_ftp_path\" value=\"no\"$restricted_ftp_path_no> "._("No");
+
+	// Allowing change of DNS and MX
+	if($allow_dns_and_mx_change == "yes"){
+		$allow_dns_and_mx_change_yes = " checked='checked' ";
+		$allow_dns_and_mx_change_no = "";
+	}else{
+		$allow_dns_and_mx_change_yes = "";
+		$allow_dns_and_mx_change_no = " checked='checked' ";
+	}
+	$allow_dns_and_mx_change_selector = "<input type=\"radio\" name=\"allow_dns_and_mx_change\" value=\"yes\"$allow_dns_and_mx_change_yes> "._("Yes")."
+<input type=\"radio\" name=\"allow_dns_and_mx_change\" value=\"no\"$allow_dns_and_mx_change_no> "._("No");
+
+	// Allow users to edit mailing lists
+	if($allow_mailing_list_edit == "yes"){
+		$allow_mailing_list_edit_yes = " checked='checked' ";
+		$allow_mailing_list_edit_no = "";
+	}else{
+		$allow_mailing_list_edit_yes = "";
+		$allow_mailing_list_edit_no = " checked='checked' ";
+	}
+	$allow_mailing_list_edit_selector = "<input type=\"radio\" name=\"allow_mailing_list_edit\" value=\"yes\"$allow_mailing_list_edit_yes> "._("Yes")."
+<input type=\"radio\" name=\"allow_mailing_list_edit\" value=\"no\"$allow_mailing_list_edit_no> "._("No");
+
+	// Allow users to edit subdomains
+	if($allow_subdomain_edit == "yes"){
+		$allow_subdomain_edit_yes = " checked='checked' ";
+		$allow_subdomain_edit_no = "";
+	}else{
+		$allow_subdomain_edit_yes = "";
+		$allow_subdomain_edit_no = " checked='checked' ";
+	}
+	$allow_subdomain_edit_selector = "<input type=\"radio\" name=\"allow_subdomain_edit\" value=\"yes\"$allow_subdomain_edit_yes> "._("Yes")."
+<input type=\"radio\" name=\"allow_subdomain_edit\" value=\"no\"$allow_subdomain_edit_no> "._("No");
+
 	// Generate the user configuration form
 	$user_data = "
 <form name=\"admattrbfrm\" action=\"?\" methode=\"post\">
@@ -99,7 +148,7 @@ function drawEditAdmin($admin){
 	if ($conf_hide_password == "yes"){
 		$ctrl = "<input class=\"dtcDatagrid_input_color\" type=\"password\" name=\"changed_pass\" value=\"$adm_cur_pass\">$genpass";
 	} else {
-		$ctrl = "<input type=\"text\" name=\"changed_pass\" value=\"$adm_cur_pass\">$genpass";
+		$ctrl = "<input class=\"dtcDatagrid_input_color\" type=\"text\" name=\"changed_pass\" value=\"$adm_cur_pass\">$genpass";
 	}
 	$user_data .= dtcFormLineDraw( _("Password:") ,$ctrl);
 
@@ -128,15 +177,20 @@ function drawEditAdmin($admin){
 	$user_data .= dtcFormLineDraw( _("Product ID:") ,$prodsid);
 	$user_data .= dtcFormLineDraw( _("Number of databases:") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"nbrdb\" value=\"".$info["nbrdb"]."\">",0);
 	$user_data .= dtcFormLineDraw( _("Allow to add domains:") ,$aldom_popup);
-	$user_data .= dtcFormLineDraw( _("Grant sub-account addition rights (reseller):") ,$res_selector,0);
-	$user_data .= dtcFormLineDraw( _("Allow addition of SSH logins:") ,$sshlog_selector);
-	$user_data .= dtcFormLineDraw( _("Allow addition of FTP logins:") ,$ftplog_selector,0);
-	$user_data .= dtcFormLineDraw( _("Allow the use of the package installer:") ,$pkg_install_selector);
+	$user_data .= dtcFormLineDraw( _("Max domain:") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"max_domain\" value=\"$max_domain\">",0);
+	$user_data .= dtcFormLineDraw( _("Grant sub-account addition rights (reseller):") ,$res_selector);
+	$user_data .= dtcFormLineDraw( _("Allow addition of SSH logins:") ,$sshlog_selector,0);
+	$user_data .= dtcFormLineDraw( _("Allow addition of FTP logins:") ,$ftplog_selector);
+	$user_data .= dtcFormLineDraw( _("Restrict FTP to the html folder:") ,$restricted_ftp_path_selector,0);
+	$user_data .= dtcFormLineDraw( _("Allow addition of mailing lists and mail groups:") ,$allow_mailing_list_edit_selector);
+	$user_data .= dtcFormLineDraw( _("Allow edition of DNS and MX:") ,$allow_dns_and_mx_change_selector,0);
+	$user_data .= dtcFormLineDraw( _("Allow edition subdomains:") ,$allow_subdomain_edit_selector);
+	$user_data .= dtcFormLineDraw( _("Allow the use of the package installer:") ,$pkg_install_selector,0);
 	$user_data .= dtcFromOkDraw()."</table></form>";
 
 	// Generate the admin tool configuration module
 	// Deletion of domains :
-	$url = "".$_SERVER["PHP_SELF"]."?delete_admin_user=$adm_login&rub=$rub";
+	$url = "?delete_admin_user=$adm_login&rub=$rub";
 	$confirmed_url = dtcJavascriptConfirmLink( _("Are your sure you want to delete this user? This will erase all his hosted domain names, files, and databases !!!") ,$url);
 	$domain_conf = "<a href=\"$confirmed_url\"><b>". _("Delete the user") ."</b></a><br><br>";
 	if(isset($data)){
@@ -211,7 +265,7 @@ function drawEditAdmin($admin){
 		$vps_prods .= "<option value=\"".$a["id"]."\">".$a["name"]."</option>";
 	}
 
-	$q = "SELECT * FROM $pro_mysql_vps_ip_table WHERE available='yes' ORDER BY vps_server_hostname;";
+	$q = "SELECT * FROM $pro_mysql_vps_ip_table WHERE available='yes' ORDER BY vps_server_hostname,vps_xen_name;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	$vps_srvs = "";
@@ -308,6 +362,8 @@ function drawDomainConfig($admin){
 	global $pro_mysql_subdomain_table;
 
 	global $conf_site_addrs;
+	global $conf_use_shared_ssl;
+
 	$site_addrs = explode("|",$conf_site_addrs);
 
 	global $adm_login;
@@ -387,6 +443,10 @@ function drawDomainConfig($admin){
 					"type" => "popup",
 					"legend" => _("IP address") ,
 					"values" => $site_addrs),
+				"expiration_date" => array(
+					"type" => "text",
+					"legend" => _("Expiration") ,
+					"size" => "6"),
 				"backup_ip_addr" => array(
 					"type" => "text",
 					"legend" => _("Backup Vhost IP address") ,
@@ -395,7 +455,7 @@ function drawDomainConfig($admin){
 			);
 		$ret .= dtcDatagrid($dsc);
 		if( isset($_REQUEST["edithost"]) && isHostname($_REQUEST["edithost"]) ){
-			$ret .= "<h3>Custom Apache directives for ".$_REQUEST["edithost"]."</h3>";
+			$ret .= "<h3>". _("Custom Apache directives for") ." ".$_REQUEST["edithost"]."</h3>";
 			$q = "SELECT subdomain_name FROM $pro_mysql_subdomain_table WHERE domain_name='".$_REQUEST["edithost"]."';";
 			$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 			$n = mysql_num_rows($r);
@@ -405,12 +465,12 @@ function drawDomainConfig($admin){
 					$ret .= " - ";
 				}
 				$subname = $a["subdomain_name"];
-				$ret .= "<a href=\"".$_SERVER["PHP_SELF"]."?adm_login=$adm_login&adm_pass=$adm_pass&rub=$rub&edithost=".$_REQUEST["edithost"]."&subdomain=$subname\">$subname</a>";
+				$ret .= "<a href=\"?adm_login=$adm_login&adm_pass=$adm_pass&rub=$rub&edithost=".$_REQUEST["edithost"]."&subdomain=$subname\">$subname</a>";
 			}
 			$ret .= "<br><br>";
 			if( isset($_REQUEST["subdomain"]) && isHostname($_REQUEST["subdomain"]) ){
-				$ret .= "<u>Subdomain: ".$_REQUEST["subdomain"].":</u><br>";
-				$ret .= "Take care: no syntax checkings are done on your custom directives, doing a mistake here could lead to your web server not being able to restart!<br>";
+				$ret .= "<u>". _("Subdomain") .": ".$_REQUEST["subdomain"].":</u><br>";
+				$ret .= _("Take care: no syntax checkings are done on your custom directives, doing a mistake here could lead to your web server not being able to restart!")."<br>";
 				$q = "SELECT customize_vhost FROM $pro_mysql_subdomain_table WHERE subdomain_name='".$_REQUEST["subdomain"]."' AND domain_name='".$_REQUEST["edithost"]."';";
 				$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 				$n = mysql_num_rows($r);
@@ -419,7 +479,7 @@ function drawDomainConfig($admin){
 				}
 				$ze_dom = mysql_fetch_array($r);
 				$customization = $ze_dom["customize_vhost"];
-				$ret .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+				/*$ret .= "<form action=\"?\">
 				<input type=\"hidden\" name=\"rub\" value=\"$rub\">
 				<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 				<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -432,7 +492,84 @@ function drawDomainConfig($admin){
  <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" value=\"Ok\"></div>
  <div class=\"input_btn_right\"></div>
 </div>
-				</form><br><br><br>";
+				</form><br><br><br>";*/
+
+		$cols=array(	"id" => array(
+					"type" => "id",
+					"display" => "no",
+					"legend" => _("ID")),
+				"customize_vhost" => array(
+					"type"=> "textarea",
+					"help"=> _("Custom apache directives. There is *no* syntax checking on this field!"),
+					"cols"=> "40",
+					"rows"=> "30",
+					"legend" => _("Custom apache directives")),
+				"redirect_url" => array(
+					"type" => "text",
+					"help" => _("Redirect URL"),
+					"size" => 50,
+					"legend" => _("Redirect to:")),
+				"php_memory_limit" => array(
+					"type" => "text",
+					"help" => _("Maximum memory used by PHP session"),
+					"size" => 3,
+					"legend" => _("PHP memory limit")),
+				"php_max_execution_time" => array(
+					"type" => "text",
+					"help" => _("Maximum time a PHP script can execute"),
+					"size" => 3,
+					"legend" => _("Execution time")),
+				"php_upload_max_filesize" => array(
+					"type" => "text",
+					"help" => _("Maximum allowed size of uploaded file"),
+					"size" => 2,
+					"legend" => _("Max upload file size")),
+				"php_post_max_size" => array(
+					"type" => "text",
+					"help" => _("Maximum allowed size of POST"),
+					"size" => 2,
+					"legend" => _("Max POST file size")),
+				"php_session_auto_start" => array(
+					"type" => "checkbox",
+					"help" => _("Auto start of php sessions"),
+					"size" => 2,
+					"legend" => _("Session autostart"),
+					"values" => array("yes","no"),
+					"display_replace" => array( _("No") , _("Yes") )),
+				"php_allow_url_fopen" => array(
+					"type" => "checkbox",
+					"help" => _("Allows to open URLs with PHP's fopen() function."),
+					"size" => 2,
+					"legend" => _("Allow URL fOpen()"),
+					"values" => array("yes","no"),
+					"display_replace" => array( _("No") , _("Yes") ))
+		);
+		if ($conf_use_shared_ssl=="yes") {
+		    $cols["use_shared_ssl"] = array(
+					"type" => "checkbox",
+					"help" => _("Use a shared SSL certificate for this subdomain."),
+					"size" => 2,
+					"legend" => _("SSL"),
+					"values" => array("yes","no"),
+					"display_replace" => array( _("No") , _("Yes") ));
+		}
+
+
+
+		$dsc = array(
+			"table_name" => $pro_mysql_subdomain_table,
+			"title" => _("Configuration of the subdomain"),
+			"action" => "change_domain_config",
+			"forward" => array("subdomain","edithost","rub","adm_login","adm_pass"),
+			"skip_deletion" => "yes",
+			"skip_creation" => "yes",
+			"where_condition" => "subdomain_name='".$_REQUEST["subdomain"]."' AND domain_name='".$_REQUEST["edithost"]."'",
+			"cols" => $cols
+			);
+			
+			$ret.=dtcDatagrid($dsc);
+				
+				
 			}
 		}
 	}
