@@ -187,10 +187,28 @@ function drawAdminTools_Subdomain($admin,$domain){
 				"can_be_empty" => "yes",
 				"empty_makes_default" => "yes",
 				"legend" => _("IP address or CNAME: ") ),
+			"ipv4_round_robin" => array(
+				"type" => "text",
+				"check" => "list_of_ip",
+				"can_be_empty" => "yes",
+				"legend" => _("Supplementary IP list for round robin: ") ),
+			"ttl" => array(
+				"type" => "text",
+				"check" => "number",
+				"can_be_empty" => "no",
+				"default" => "7200",
+				"legend" => _("TTL"),
+				),
+                        "ip6" => array(
+                                "type" => "text",
+                                "check" => "ip6",
+                                "can_be_empty" => "yes",
+                                "empty_makes_default" => "yes",
+                                "legend" => _("IPv6 address: ") ),
 			"generate_vhost" => array(
 				"type" => "radio",
 				"values" => array("yes","no"),
-				"display_replace" => array ( _("Yes") , _("No") ),
+				"display_replace" => array(_("Yes"),_("No")),
 				"legend" => _("Generate a vhost entry for this subdomain:") ),
 			"add_default_charset" => array(
 				"type" => "popup",
@@ -200,11 +218,16 @@ function drawAdminTools_Subdomain($admin,$domain){
 				"type" => "text",
 				"can_be_empty" => "yes",
 				"legend" => _("This subdomain is a service (SRV)<br>entry for the following port: ") ),
+			"srv_record_protocol" => array(
+				"type" => "radio",
+				"values" => array("tcp","udp","sctp"),
+				"default" => "tcp",
+				"legend" => _("SRV protocol: ") ),
 			"register_globals" => array(
 				"type" => "radio",
 				"values" => array("yes","no"),
 				"default" => "no",
-				"display_replace" => array ( _("Yes") , _("No") ),
+				"display_replace" => array(_("Yes"),_("No")),
 				"legend" => _("Use register_globals=1: ") ),
 			"associated_txt_record" => array(
 				"type" => "text",
@@ -220,12 +243,14 @@ function drawAdminTools_Subdomain($admin,$domain){
 		$dsc["cols"]["safe_mode"] = array(
 				"type" => "radio",
 				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No")),
 				"legend" => "PHP safe mode: ");
 	}
 	if($domain["sbox_protect"] == "no"){
 		$dsc["cols"]["sbox_protect"] = array(
 				"type" => "radio",
 				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No")),
 				"legend" => _("Sbox cgi-bin protection: ") );
 	}
 
