@@ -10,7 +10,7 @@ if(!isset($commit_flag)){
 function checkDedicatedAdmin($adm_login,$adm_pass,$dedicated_server_hostname){
 	global $pro_mysql_dedicated_table;
 	checkLoginPass($adm_login,$adm_pass);
-	$q = "SELECT * FROM $pro_mysql_dedicated_table WHERE owner='$adm_login' AND server_hostname='".addslashes($dedicated_server_hostname)."';";
+	$q = "SELECT * FROM $pro_mysql_dedicated_table WHERE owner='$adm_login' AND server_hostname='".mysql_real_escape_string($dedicated_server_hostname)."';";
 	$r = mysql_query($q)or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n == 1){
@@ -29,6 +29,7 @@ function validateRenewal($renew_id){
 	global $pro_mysql_completedorders_table;
 	global $pro_mysql_client_table;
 	global $pro_mysql_ssl_ips_table;
+	global $pro_mysql_pay_table;
 
 	global $commit_flag;
 	global $submit_err;
@@ -51,7 +52,7 @@ function validateRenewal($renew_id){
 	$q = "SELECT * FROM $pro_mysql_product_table WHERE id='".$renew_entry["product_id"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
-	if($n != 1){
+	if($n != 1 && $renew_entry["heb_type"] != 'add-money'){
 		$submit_err = "Could not find product in table line ".__LINE__." file ".__FILE__;
 		$commit_flag = "no";
 		return false;
@@ -73,6 +74,11 @@ function validateRenewal($renew_id){
 		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_vps_table SET expire_date='$date_expire' WHERE id='".$renew_entry["renew_id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A renewal have been paid! Here is the details of the renewal:
+
+login: ";
 		break;
 	case "shared":
 		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."';";
@@ -88,6 +94,70 @@ function validateRenewal($renew_id){
 		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_admin_table SET expire='$date_expire' WHERE adm_login='".$renew_entry["adm_login"]."'";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A renewal have been paid! Here is the details of the renewal:
+
+login: ";
+		break;
+	case "add-money":
+		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$submit_err = "Could not find admin login in table line ".__LINE__." file ".__FILE__;
+			$commit_flag = "no";
+			return false;
+		}
+		$admin = mysql_fetch_array($r);
+		$q = "SELECT * FROM $pro_mysql_pay_table WHERE id='".$renew_entry["pay_id"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$submit_err = "Could not find payment in table line ".__LINE__." file ".__FILE__;
+			$commit_flag = "no";
+			return false;
+		}
+		$old_expire = date("Y-m-d");
+		$payment = mysql_fetch_array($r);
+		$q = "UPDATE $pro_mysql_client_table SET dollar = dollar+".$payment["refund_amount"]." WHERE id='".$admin["id_client"]."';";
+		$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+		$txt_renewal_approved = "
+
+Money has been added to an account! Here is the details:
+
+login: ";
+		break;
+	case "shared-upgrade":
+		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$submit_err = "Could not find admin login in table line ".__LINE__." file ".__FILE__;
+			$commit_flag = "no";
+			return false;
+		}
+		$admin = mysql_fetch_array($r);
+
+		$q = "SELECT * FROM $pro_mysql_product_table WHERE id='".$renew_entry["product_id"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$submit_err = "Could not find product in table line ".__LINE__." file ".__FILE__;
+			$commit_flag = "no";
+			return false;
+		}
+		$product = mysql_fetch_array($r);
+
+		$old_expire = date("Y-m-d");
+		$date_expire = calculateExpirationDate(date("Y-m-d"),$product["period"]);
+		$q = "UPDATE $pro_mysql_admin_table SET expire='$date_expire',prod_id='".$renew_entry["product_id"]."',max_email=".$product["nbr_email"].",nbrdb=".$product["nbr_database"].",quota=".$product["quota_disk"].",bandwidth_per_month_mb=".$product["bandwidth"].",allow_add_domain='".$product["allow_add_domain"]."',max_domain=".$product["max_domain"]." WHERE adm_login='".$renew_entry["adm_login"]."'";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A Product Upgrade have been paid! Here is the details:
+
+login: ";
 		break;
 	case "ssl":
 		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."';";
@@ -111,6 +181,11 @@ function validateRenewal($renew_id){
 		$date_expire = calculateExpirationDate(date("Y-m-d"),$product["period"]);
 		$q = "UPDATE $pro_mysql_ssl_ips_table SET available='no',adm_login='".$admin["adm_login"]."',expire='$date_expire' WHERE id='".$ssl_token["id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A SSL-token have been paid! Here is the details:
+
+login: ";
 		break;
 	case "server":
 		$q = "SELECT * FROM $pro_mysql_dedicated_table WHERE id='".$renew_entry["renew_id"]."';";
@@ -126,6 +201,11 @@ function validateRenewal($renew_id){
 		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_dedicated_table SET expire_date='$date_expire' WHERE id='".$renew_entry["renew_id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A renewal have been paid! Here is the details of the renewal:
+
+login: ";
 		break;
 	case "ssl_renew":
 		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."';";
@@ -150,6 +230,11 @@ function validateRenewal($renew_id){
 		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_ssl_ips_table SET expire='$date_expire' WHERE  id='".$ssl_ip["id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$txt_renewal_approved = "
+
+A renewal have been paid! Here is the details of the renewal:
+
+login: ";
 		break;
 	default:
 		die("Unknown heb type line ".__LINE__." file ".__FILE__);
@@ -157,15 +242,21 @@ function validateRenewal($renew_id){
 	}
 
 	global $secpayconf_currency_letters;
-	$txt_renewal_approved = "
+	$txt_renewal_approved .= $renew_entry["adm_login"];
+	if($renew_entry["heb_type"] == 'add-money') {
+	$txt_renewal_approved .= "
+Amount added: " . $payment["refund_amount"]."
 
-A renewal have been paid! Here is the details of the renewal:
-
-login: ".$renew_entry["adm_login"]."
+";
+	}
+	else
+	{
+	$txt_renewal_approved .= "
 Product: ".$product["name"]."(".$product["price_dollar"]." ".$secpayconf_currency_letters.")
 Date: ".$renew_entry["renew_date"]." ".$renew_entry["renew_time"]."
 
 ";
+	}
 
 	$headers = $send_email_header;
 	$headers .= "From: ".$conf_webmaster_email_addr;
@@ -275,13 +366,16 @@ function validateWaitingUser($waiting_login_id){
 	if($a["add_service"] != "yes"){
 		$adm_query = "INSERT INTO $pro_mysql_client_table
 (id,is_company,company_name,vat_num,familyname,christname,addr1,addr2,addr3,
+customfld,
 city,zipcode,state,country,phone,fax,email,
-disk_quota_mb,bw_quota_per_month_gb,special_note) VALUES ('','".$a["iscomp"]."',
-'".addslashes($a["comp_name"])."','".addslashes($a["vat_num"])."','".addslashes($a["family_name"])."','".addslashes($a["first_name"])."',
-'".addslashes($a["addr1"])."','".addslashes($a["addr2"])."','".addslashes($a["addr3"])."','".addslashes($a["city"])."',
-'".addslashes($a["zipcode"])."','".addslashes($a["state"])."','".addslashes($a["country"])."','".addslashes($a["phone"])."',
-'".addslashes($a["fax"])."','".addslashes($a["email"])."','".$a2["quota_disk"]."','". $a2["bandwidth"]/1024 ."',
-'".addslashes($a["custom_notes"])."');";
+disk_quota_mb,bw_quota_per_month_gb,
+special_note) VALUES ('','".$a["iscomp"]."',
+'".mysql_real_escape_string($a["comp_name"])."','".mysql_real_escape_string($a["vat_num"])."','".mysql_real_escape_string($a["family_name"])."','".mysql_real_escape_string($a["first_name"])."',
+'".mysql_real_escape_string($a["addr1"])."','".mysql_real_escape_string($a["addr2"])."','".mysql_real_escape_string($a["addr3"])."',
+'".mysql_real_escape_string($a["customfld"])."',
+'".mysql_real_escape_string($a["city"])."','".mysql_real_escape_string($a["zipcode"])."','".mysql_real_escape_string($a["state"])."','".mysql_real_escape_string($a["country"])."','".mysql_real_escape_string($a["phone"])."',
+'".mysql_real_escape_string($a["fax"])."','".mysql_real_escape_string($a["email"])."','".$a2["quota_disk"]."','". $a2["bandwidth"]/1024 ."',
+'".mysql_real_escape_string($a["custom_notes"])."');";
 		$r = mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 		$cid = mysql_insert_id();
 	}
@@ -300,14 +394,19 @@ disk_quota_mb,bw_quota_per_month_gb,special_note) VALUES ('','".$a["iscomp"]."',
         }
         if($a["add_service"] != "yes"){
 		$adm_query = "INSERT INTO $pro_mysql_admin_table
-(adm_login        ,adm_pass              ,last_used_lang   ,path            ,id_client,bandwidth_per_month_mb,quota,nbrdb,allow_add_domain,max_email$admtbl_added1) VALUES
-('$waiting_login','".$a["reqadm_pass"]."','$last_used_lang','$newadmin_path','$cid','".$a2["bandwidth"]."','".$a2["quota_disk"]."','".$a2["nbr_database"]."','".$a2["allow_add_domain"]."','".$a2["nbr_email"]."'$admtbl_added2);";
+(adm_login        ,adm_pass              ,
+last_used_lang   ,path            ,id_client,bandwidth_per_month_mb,quota,nbrdb,allow_add_domain,max_domain,restricted_ftp_path,allow_dns_and_mx_change,ftp_login_flag,allow_mailing_list_edit,allow_subdomain_edit,max_email$admtbl_added1) VALUES
+('$waiting_login','".$a["reqadm_pass"]."',
+'$last_used_lang','$newadmin_path','$cid','".$a2["bandwidth"]."','".$a2["quota_disk"]."','".$a2["nbr_database"]."','".$a2["allow_add_domain"]."','".$a2["max_domain"]."',
+'".$a2["restricted_ftp_path"]."','".$a2["allow_dns_and_mx_change"]."','".$a2["ftp_login_flag"]."','".$a2["allow_mailing_list_edit"]."','".$a2["allow_subdomain_edit"]."','".$a2["nbr_email"]."'$admtbl_added2);";
 		mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 	}else{
 		if($a2["heb_type"] == "shared"){
 			$adm_query = "UPDATE $pro_mysql_admin_table
 			SET bandwidth_per_month_mb='".$a2["bandwidth"]."', quota='".$a2["quota_disk"]."', nbrdb='".$a2["nbr_database"]."',
-			allow_add_domain='".$a2["allow_add_domain"]."', max_email='".$a2["nbr_email"]."' $admtbl_added3
+			allow_add_domain='".$a2["allow_add_domain"]."', max_domain='".$a2["max_domain"]."', restricted_ftp_path='".$a2["restricted_ftp_path"]."',
+			allow_dns_and_mx_change='".$a2["allow_dns_and_mx_change"]."', ftp_login_flag='".$a2["ftp_login_flag"]."', allow_mailing_list_edit='".$a2["allow_mailing_list_edit"]."',
+			allow_subdomain_edit='".$a2["allow_subdomain_edit"]."', max_email='".$a2["nbr_email"]."' $admtbl_added3
 			WHERE adm_login='$waiting_login';";
 			mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 		}
@@ -558,7 +657,6 @@ if($panel_type!="email"){
 	require("$dtcshared_path/inc/sql/domain_info.php");
 	require("$dtcshared_path/inc/sql/domain_stats.php");
 	require("$dtcshared_path/inc/sql/subdomain.php");
-	require("$dtcshared_path/inc/sql/ssh.php");
 	require("$dtcshared_path/inc/sql/email.php");
 	require("$dtcshared_path/inc/sql/lists.php");
 	require("$dtcshared_path/inc/sql/reseller.php");
